<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_3DSwap_Title extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = '3d-swap-title';
  public $icon         = 'ti-text';
  public $tag      = 'h3';
  public $css_selector = '';
  public $scripts      = ['threed_swap_title'];

  public function get_label() {
    return esc_html__( '3D Swap Hover', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['gradient'] = [
      'title' => esc_html__( 'Gradient', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
      'tab'            => 'content',
      'type'           => 'text',
	    'hasDynamicData' => 'text',
      'default'        => esc_html__( '3D Swap Hover', 'bricks' ),
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['titleTypography'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Typography', 'bricks' ),
        'type'    => 'typography',
              'css'     => [
          [
            'property' => 'typography',
            'selector' => '.bc-3dswap-title__title',
          ],
        ],
    ];
    $this->controls['tag'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'HTML tag', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'h1' => 'h1',
            'h2' => 'h2',
            'h3' => 'h3',
            'h4' => 'h4',
            'h5' => 'h5',
            'h6' => 'h6',
            'p' => 'p',
            'span' => 'span',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'h3',
        'default'     => 'h3',
    ];
    $this->controls['link'] = [
        'tab'   => 'content',
        'label' => esc_html__( 'Link to', 'bricks' ),
        'type'  => 'link',
    ];

    $this->controls['animationSeparator'] = [
        'label'      => esc_html__( 'Animation', 'bricks' ),
        'type'       => 'separator',
    ];
    $this->controls['stagger'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Stagger', 'bricks' ),
        'type' => 'number',
        'inline' => true,
        'placeholder' => '0.08',
    ];
    $this->controls['duration'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Duration', 'bricks' ),
        'type' => 'number',
        'unit' => 's',
        'inline' => true,
        'placeholder' => '0.7s',
    ];
    $this->controls['ease'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'GSAP easing', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'power3',
    ];

    //Gradient
    $this->controls['titleGradient'] = [
      'group' => 'gradient',
      'tab' => 'content',
      'type' => 'gradient',
      'css' => [
        [
          'property' => 'background-image',
          'selector' => '.char',
        ],
      ],
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'bc_threed_swap_title', plugin_dir_url( __FILE__ ) . 'js/bc_3d_swap_title.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $stagger    = ! empty( $settings['stagger'] ) ? $settings['stagger'] : 0.08;
    $duration    = ! empty( $settings['duration'] ) ? $settings['duration'] : 0.7;
    $ease    = ! empty( $settings['ease'] ) ? $settings['ease'] : 'power3';

    if ( ! empty( $settings['link'] ) ) {
        $this->set_link_attributes( '_root', $settings['link'] );
    }
    $this->set_attribute( '_root', 'class', 'bc-3dswap-title' );
    $this->set_attribute( '_root', 'data-stagger', $stagger );
    $this->set_attribute( '_root', 'data-duration', $duration );
    $this->set_attribute( '_root', 'data-ease', $ease );

    $output = "<a {$this->render_attributes( '_root' )}>";
    $output .="
    <{$this->tag} class='bc-3dswap-title__title bc-3dswap-title__title--front'>$inner_title</{$this->tag}>
    <{$this->tag} class='bc-3dswap-title__title bc-3dswap-title__title--back'>$inner_title</{$this->tag}>";
    $output .= '</a>';


		echo $output;
  }
}