<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class B_3DHover extends \Bricks\Element {
  public $category     = 'Brickscore - Core';
  public $name         = '3dhover';
  public $icon         = 'ti-layout-media-right-alt';
  public $scripts      = ['threedhover'];
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'Parallax Hover', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['rotate'] = [
      'title' => esc_html__( 'Rotate', 'bricks' ),
      'tab'   => 'content',
    ];
    $this->control_groups['stretch'] = [
      'title' => esc_html__( 'Stretch', 'bricks' ),
      'tab'   => 'content',
    ];
    $this->control_groups['shadow'] = [
      'title' => esc_html__( 'Shadow', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['offset'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Offset', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 50,
    ];
    $this->controls['alwaysActive'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Always Active', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => false,
    ];
    $this->controls['duration'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Duration', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 300,
    ];

    /*Rotate*/
    $this->controls['rotate'] = [
      'group' => 'rotate',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Rotate', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => true,
    ];
    $this->controls['rotatetouch'] = [
      'group' => 'rotate',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Rotate Touch', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => true,
    ];
    $this->controls['rotateXMax'] = [
      'group' => 'rotate',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Max X Rotation', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 15,
    ];
    $this->controls['rotateYMax'] = [
      'group' => 'rotate',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Max Y Rotation', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 15,
    ];
    $this->controls['rotateXInvert'] = [
      'group' => 'rotate',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Invert X Rotation', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => false,
    ];
    $this->controls['rotateYInvert'] = [
      'group' => 'rotate',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Invert Y Rotation', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => false,
    ];

    /*Stretch*/
    $this->controls['stretchX'] = [
      'group' => 'stretch',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'X Stretch', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 0,
    ];
    $this->controls['stretchY'] = [
      'group' => 'stretch',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Y Stretch', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 0,
    ];
    $this->controls['stretchZ'] = [
      'group' => 'stretch',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Z Stretch', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 0,
    ];

    /*Shadow*/
    $this->controls['shadow'] = [
      'group' => 'shadow',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Shadow', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => true,
    ];
    $this->controls['shadowOffset'] = [
      'group' => 'shadow',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Shadow Offset', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 50,
    ];
    $this->controls['shadowScale'] = [
      'group' => 'shadow',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Shadow Scale', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 1,
    ];
    $this->controls['highlight'] = [
      'group' => 'shadow',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Highlight', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => true,
    ];
  }

  /*Render sliders & children*/
public function get_nestable_item() {
  return [
      'name'     => '3dhoverchild',
      'settings' => [
        '_hidden' => [
            '_cssClasses' => 'bc-parallax-hover__wrapper',
        ],
    ],
    'children' => [
      [
        'name'     => 'marqueebutton',
      ],
      [
        'name'     => 'text-basic',
        'label'    => esc_html__( 'Paragraph', 'bricks' ),
        'settings' => [
            'text' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. In id ipsum velit. Pellentesque faucibus magna arcu, et laoreet ligula lobortis eu. Interdum et malesuada fames ac ante ipsum primis in faucibus', 'bricks' ),
            'tag'  => 'p',
            '_hidden' => [
                '_cssClasses' => 'bc-parallax-hover__heading',
            ],
        ],
      ],
    ],
  ];
}

public function get_nestable_children() {
  $children = [];

  for ( $i = 0; $i < 1; $i++ ) { /*Cantidad de item a generar*/
      $item = $this->get_nestable_item();

      // Replace {item_index} with $index
      $item       = json_encode( $item );
      $item       = str_replace( '{item_index}', $i + 1, $item );
      $item       = json_decode( $item, true );
      $children[] = $item;
  }

  return $children;
}

  public function enqueue_scripts() {
    wp_enqueue_style( 'atropos-css', plugin_dir_url( __FILE__ ) . '../local_assets/bc_atropos.min.css', array(), get_option('brickscore_element_version'), false);
    wp_enqueue_script( 'atropos-js', plugin_dir_url( __FILE__ ) . '../local_assets/bc_atropos.min.js', array(), get_option('brickscore_element_version'), false);

    wp_enqueue_script( '3dhover-js', plugin_dir_url( __FILE__ ) . 'js/bc_3dhover.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    /*Default*/
    $offset = ! empty( $settings['offset'] ) ? $settings['offset'] : 50;
    $alwaysActive = ! empty( $settings['alwaysActive'] ) ? $settings['alwaysActive'] : false;
    $duration = ! empty( $settings['duration'] ) ? $settings['duration'] : 300;
    /*Rotate*/
    $rotate = ! empty( $settings['rotate'] ) ? $settings['rotate'] : false;
    $rotatetouch = ! empty( $settings['rotatetouch'] ) ? $settings['rotatetouch'] : false;
    $rotateXMax = ! empty( $settings['rotateXMax'] ) ? $settings['rotateXMax'] : 15;
    $rotateYMax = ! empty( $settings['rotateYMax'] ) ? $settings['rotateYMax'] : 15;
    $rotateXInvert = ! empty( $settings['rotateXInvert'] ) ? $settings['rotateXInvert'] : false;
    $rotateYInvert = ! empty( $settings['rotateYInvert'] ) ? $settings['rotateYInvert'] : false;
    /*Stretch*/
    $stretchX = ! empty( $settings['stretchX'] ) ? $settings['stretchX'] : 0;
    $stretchY = ! empty( $settings['stretchY'] ) ? $settings['stretchY'] : 0;
    $stretchZ = ! empty( $settings['stretchZ'] ) ? $settings['stretchZ'] : 0;
    /*Shadow*/
    $shadow = ! empty( $settings['shadow'] ) ? $settings['shadow'] : false;
    $shadowOffset = ! empty( $settings['shadowOffset'] ) ? $settings['shadowOffset'] : 50;
    $shadowScale = ! empty( $settings['shadowScale'] ) ? $settings['shadowScale'] : 1;
    $highlight = ! empty( $settings['highlight'] ) ? $settings['highlight'] : false;


    $this->set_attribute( '_root', 'class', "atropos-inner"); /*el root es atropos-inner que es el que tiene que recibir los estilos del tab "STYLE"*/
    $this->set_attribute( '_datas', 'data-offset', $offset);
    $this->set_attribute( '_datas', 'data-alwaysActive', $alwaysActive);
    $this->set_attribute( '_datas', 'data-duration', $duration);
    $this->set_attribute( '_datas', 'data-rotate', $rotate);
    $this->set_attribute( '_datas', 'data-rotatetouch', $rotatetouch);
    $this->set_attribute( '_datas', 'data-rotateXMax', $rotateXMax);
    $this->set_attribute( '_datas', 'data-rotateYMax', $rotateYMax);
    $this->set_attribute( '_datas', 'data-rotateXInvert', $rotateXInvert);
    $this->set_attribute( '_datas', 'data-rotateYInvert', $rotateYInvert);
    $this->set_attribute( '_datas', 'data-stretchX', $stretchX);
    $this->set_attribute( '_datas', 'data-stretchY', $stretchY);
    $this->set_attribute( '_datas', 'data-stretchZ', $stretchZ);
    $this->set_attribute( '_datas', 'data-shadow', $shadow);
    $this->set_attribute( '_datas', 'data-shadowOffset', $shadowOffset);
    $this->set_attribute( '_datas', 'data-shadowScale', $shadowScale);
    $this->set_attribute( '_datas', 'data-highlight', $highlight);
    $output = "<div class='atropos bc-parallax-hover' {$this->render_attributes( '_datas' )}>

      <div class='atropos-scale'>
        <div class='atropos-rotate'>
          <div {$this->render_attributes( '_root' )}>";
            $output .= \Bricks\Frontend::render_children( $this );
          $output .= "</div>
        </div>
      </div>

    </div>";

  echo $output;
  }
}