<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Arrowbutton extends \Bricks\Element {
  public $category     = 'Brickscore - Buttons';
  public $name         = 'arrowbutton';
  public $icon         = 'fa-solid fa-square-minus';
  public $scripts      = ['arrowbutton'];

  public function get_label() {
    return esc_html__( 'Arrow Button', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['title'] = [
      'title' => esc_html__( 'Title', 'bricks' ),
      'tab'   => 'content',
    ];
    $this->control_groups['arrow'] = [
      'title' => esc_html__( 'Arrow', 'bricks' ),
      'tab'   => 'content',
    ];
    $this->control_groups['animation'] = [
      'title' => esc_html__( 'Animation', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Arrow Button', 'bricks' ),
        'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['link'] = [
        'tab'   => 'content',
        'label' => esc_html__( 'Link to', 'bricks' ),
        'type'  => 'link',
    ];
    $this->controls['whitespace'] = [
      'group' => 'title',
      'tab'         => 'content',
      'label'       => esc_html__( 'White space', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'wrap' => 'wrap',
          'nowrap' => 'nowrap',
      ],
      'inline'      => true,
      'css'     => [
          [
            'property' => 'white-space',
            'selector' => '',
          ],
        ],
      'placeholder'        => 'wrap',
  ];
  $this->controls['typography'] = [
    'group' => 'title',
      'tab'         => 'content',
      'label'       => esc_html__( 'Typography', 'bricks' ),
      'type'        => 'typography',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'typography',
            'selector' => '.bc-arrow-button_title-wrapper',
          ],
        ],
  ];
    $this->controls['background'] = [
      'group' => 'title',
        'tab'         => 'content',
        'label'       => esc_html__( 'Background', 'bricks' ),
        'type'        => 'background',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-arrow-button_title-wrapper',
            ],
          ],
    ];
    $this->controls['paddingaux'] = [
      'group' => 'title',
      'tab'         => 'content',
      'label'       => esc_html__( 'Padding', 'bricks' ),
      'type'        => 'dimensions',
      'css'     => [
          [
            'property' => 'padding',
            'selector' => '.bc-arrow-button_title-wrapper',
          ],
        ],
        'placeholder' => [
          'top' => 10,
          'right' => 13,
          'bottom' => 16,
          'left' => 13,
        ],
    ];
    $this->controls['border'] = [
      'group' => 'title',
        'tab'         => 'content',
        'label'       => esc_html__( 'Border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '.bc-arrow-button_title-wrapper',
            ],
          ],
    ];
    $this->controls['swaptitleseparator'] = [
      'group'   => 'title',
      'label'      => esc_html__( 'SWAP TITLE', 'bricks' ),
      'type'       => 'separator',
    ];
    $this->controls['swaptitleenable'] = [
      'group'   => 'title',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label'    => esc_html__( 'Enable Swap Title', 'bricks' ),
      'type'     => 'checkbox',
    ];
    $this->controls['swaptitlecontent'] = [
      'group'   => 'title',
      'tab'            => 'content',
      'type'           => 'text',
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
      'required' => [ 'swaptitleenable', '=', true],
    ];
    $this->controls['transitiondurationswap'] = [
      'group'   => 'title',
      'tab'         => 'content',
      'label'       => esc_html__( 'Duration', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--transitiondurationswap',
            'selector' => '',
          ],
      ],
      'placeholder'        => '0.5s',
      'required' => [ 'swaptitleenable', '=', true],
    ];
    $this->controls['transitioneaseswap'] = [
      'group'   => 'title',
      'tab'         => 'content',
      'label'       => esc_html__( 'Easing', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--easeswap',
            'selector' => '',
          ],
      ],
      'placeholder'        => 'cubic-bezier(0.1, 0, 0.3, 1)',
      'required' => [ 'swaptitleenable', '=', true],
    ];


    $this->controls['arrowtype'] = [
      'group' => 'arrow',
      'tab' => 'content',
      'label' => esc_html__( 'Icon', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'type1' => 'Arrow 1',
          'type2' => 'Arrow 2',
          'type3' => 'Angle',
          'type4' => 'Angles',
      ],
      'inline' => true,
      'placeholder' => 'Arrow',
      'default' => 'type1',
  ];
    $this->controls['arrowposition'] = [
      'group'   => 'arrow',
        'tab'         => 'content',
        'label'       => esc_html__( 'Position', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'row-reverse' => 'Right',
            'row' => 'Left',
        ],
        'inline'      => true,
        'css'     => [
            [
              'property' => 'flex-direction',
              'selector' => '',
            ],
          ],
        'placeholder' => 'Right',
        'default' => 'Right',
    ];
    $this->controls['arrowweight'] = [
      'group'   => 'arrow',
        'tab'         => 'content',
        'label'       => esc_html__( 'Weight', 'bricks' ),
        'type' => 'number',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'stroke-width',
              'selector' => '.bc-arrow-button__arrow',
            ],
        ],
        'placeholder'        => '0.1',
    ];
    $this->controls['arrowrotation'] = [
      'group'   => 'arrow',
        'tab'         => 'content',
        'label'       => esc_html__( 'Rotation', 'bricks' ),
        'type' => 'number',
        'unit' => 'deg',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'rotate',
              'selector' => '.bc-arrow-button__arrow',
            ],
        ],
        'placeholder'        => '-45deg',
    ];
    $this->controls['arrowdimensions'] = [
      'group'   => 'arrow',
        'tab'         => 'content',
        'label'       => esc_html__( 'Dimensions', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => '--dimensions',
              'selector' => '',
            ],
        ],
        'placeholder'        => '23px',
    ];
    $this->controls['arrowseparator'] = [
      'group'   => 'arrow',
      'label'      => esc_html__( 'Styling', 'bricks' ),
      'type'       => 'separator',
    ];
    $this->controls['arrowcolor'] = [
      'group'   => 'arrow',
        'tab'         => 'content',
        'label'       => esc_html__( 'Color', 'bricks' ),
        'type'        => 'color',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--fill',
              'selector' => '.bc-arrow-button__arrow',
            ],
        ],
    ];
    $this->controls['arrowbackground'] = [
      'group'   => 'arrow',
        'tab'         => 'content',
        'label'       => esc_html__( 'Background', 'bricks' ),
        'type'        => 'background',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-arrow-button__circle',
            ],
          ],
    ];
    $this->controls['padding'] = [
      'tab'         => 'content',
      'group'   => 'arrow',
      'label'       => esc_html__( 'Padding', 'bricks' ),
      'type'        => 'dimensions',
      'css'     => [
          [
            'property' => 'padding',
            'selector' => '.bc-arrow-button__circle',
          ],
        ],
        'placeholder' => [
          'top' => 25,
          'right' => 25,
          'bottom' => 25,
          'left' => 25,
        ],
    ];
    $this->controls['arrowborder'] = [
      'group'   => 'arrow',
        'tab'         => 'content',
        'label'       => esc_html__( 'Border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '.bc-arrow-button__circle',
            ],
        ],
    ];
    $this->controls['arrowdistance'] = [
      'group'   => 'animation',
      'tab'         => 'content',
      'label'       => esc_html__( 'Distance between arrows', 'bricks' ),
      'type' => 'number',
      'units' => true,
      'inline'      => true,
      'css'     => [
          [
            'property' => '--arrow-distance',
            'selector' => '',
          ],
      ],
      'placeholder'        => '300%',
    ];
    $this->controls['arrowscale'] = [
      'group'   => 'animation',
        'tab'         => 'content',
        'label'       => esc_html__( 'Arrow scale', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'small'      => true,
        'css'     => [
            [
              'property' => '--scale',
              'selector' => '',
            ],
        ],
        'placeholder'        => '1.25',
    ];
    $this->controls['transitionduration'] = [
      'group'   => 'animation',
      'tab'         => 'content',
      'label'       => esc_html__( 'Duration', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--transitionduration',
            'selector' => '',
          ],
      ],
      'placeholder'        => '0.5s',
    ];
    $this->controls['transitionease'] = [
      'group'   => 'animation',
      'tab'         => 'content',
      'label'       => esc_html__( 'Easing', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--ease',
            'selector' => '',
          ],
      ],
      'placeholder'        => 'cubic-bezier(0.1, 0, 0.3, 1)',
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'arrowbutton', plugin_dir_url( __FILE__ ) . 'js/bc_arrow_button.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $arrowtype = ! empty( $settings['arrowtype'] ) ? $settings['arrowtype'] : 'type1';
    $swaptitleenable = ! empty( $settings['swaptitleenable'] ) ? $settings['swaptitleenable'] : false;
    $swaptitlecontent = ! empty( $settings['swaptitlecontent'] ) ? $settings['swaptitlecontent'] : 'Arrow Button';


		if ( ! empty( $settings['link'] ) ) {
			$this->set_link_attributes( '_root', $settings['link'] );
		}

    /*Enable Swap Title*/
    if($swaptitleenable == 1){
      $this->set_attribute( '_root', 'data-swap', "enable" );
      $this->set_attribute( '_swap', 'data-content', "$swaptitlecontent" );
    }else{
      $this->set_attribute( '_root', 'data-swap', 'disable' );
    }

    /*Arrow Icons*/
    if($arrowtype == 'type1'){
      $arrow = 
      "<svg class='bc-arrow-button__arrow bc-arrow-button__arrow-left' xmlns='http://www.w3.org/2000/svg' viewBox='0 0 25 25'>
        <path d='m17.5 5.999-.707.707 5.293 5.293H1v1h21.086l-5.294 5.295.707.707L24 12.499l-6.5-6.5z'/>
      </svg>
      <svg class='bc-arrow-button__arrow bc-arrow-button__arrow-right' xmlns='http://www.w3.org/2000/svg' viewBox='0 0 25 25'>
        <path d='m17.5 5.999-.707.707 5.293 5.293H1v1h21.086l-5.294 5.295.707.707L24 12.499l-6.5-6.5z'/>
      </svg>";
    }
    if($arrowtype == 'type2'){
      $arrow = 
      "<svg class='bc-arrow-button__arrow bc-arrow-button__arrow-left' xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'>
        <path d='M11.293 4.707 17.586 11H4v2h13.586l-6.293 6.293 1.414 1.414L21.414 12l-8.707-8.707-1.414 1.414z'/>
      </svg>
      <svg class='bc-arrow-button__arrow bc-arrow-button__arrow-right' xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'>
        <path d='M11.293 4.707 17.586 11H4v2h13.586l-6.293 6.293 1.414 1.414L21.414 12l-8.707-8.707-1.414 1.414z'/>
      </svg>";
    }
    if($arrowtype == 'type3'){
      $arrow = 
      "<svg class='bc-arrow-button__arrow bc-arrow-button__arrow-left' xmlns='http://www.w3.org/2000/svg' viewBox='0 0 320 512'>
        <path d='M310.6 233.4c12.5 12.5 12.5 32.8 0 45.3l-192 192c-12.5 12.5-32.8 12.5-45.3 0s-12.5-32.8 0-45.3L242.7 256 73.4 86.6c-12.5-12.5-12.5-32.8 0-45.3s32.8-12.5 45.3 0l192 192z'/>
      </svg>
      <svg class='bc-arrow-button__arrow bc-arrow-button__arrow-right' xmlns='http://www.w3.org/2000/svg' viewBox='0 0 320 512'>
        <path d='M310.6 233.4c12.5 12.5 12.5 32.8 0 45.3l-192 192c-12.5 12.5-32.8 12.5-45.3 0s-12.5-32.8 0-45.3L242.7 256 73.4 86.6c-12.5-12.5-12.5-32.8 0-45.3s32.8-12.5 45.3 0l192 192z'/>
      </svg>";
    }
    if($arrowtype == 'type4'){
      $arrow = 
      "<svg class='bc-arrow-button__arrow bc-arrow-button__arrow-left' xmlns='http://www.w3.org/2000/svg' viewBox='0 0 512 512'>
        <path d='M470.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L402.7 256 265.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0l160-160zm-352 160l160-160c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L210.7 256 73.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0z'/>
      </svg>
      <svg class='bc-arrow-button__arrow bc-arrow-button__arrow-right' xmlns='http://www.w3.org/2000/svg' viewBox='0 0 512 512'>
        <path d='M470.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L402.7 256 265.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0l160-160zm-352 160l160-160c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L210.7 256 73.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0z'/>
      </svg>";
    }

    $this->set_attribute( '_root', 'class', 'bc-arrow-button' );

    $output = "<a {$this->render_attributes( '_root' )}>
    <div class='bc-arrow-button__circle'>
        $arrow
    </div>
    <div class='bc-arrow-button_title-wrapper'>
      <div class='bc-arrow-button_title-wrap'>
        <button class='bc-arrow-button__title' {$this->render_attributes( '_swap' )}>$inner_title</button>
      </div>
    </div>
    ";

    $output .= '</a>';

	echo $output;
  }
}



