<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Back_To_Top extends \Bricks\Element {
  public $category     = 'Brickscore - Core';
  public $name         = 'back-to-top';
  public $icon         = 'ti-arrow-circle-up';
  public $scripts      = ['backtotop'];

  public function get_label() {
    return esc_html__( 'Back to Top', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['arrow'] = [
      'title' => esc_html__( 'Arrow', 'bricks' ),
        'tab'   => 'content',
    ];
    $this->control_groups['animation'] = [
      'title' => esc_html__( 'Animation', 'bricks' ),
        'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['right'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Right', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline' => true,
        'css' => [
          [
            'property' => 'right',
            'selector' => '',
          ]
        ],
        'placeholder' => '50px',
    ];
    $this->controls['sbottom'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Bottom', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline' => true,
        'css' => [
          [
            'property' => 'bottom',
            'selector' => '',
          ]
        ],
        'placeholder' => '50px',
    ];
    $this->controls['circlecolor'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Circle color', 'bricks' ),
        'type'  => 'background',
        'units' => true,
        'inline' => true,
        'css' => [
          [
            'property' => 'background',
            'selector' => '',
          ]
        ],
    ];
    $this->controls['insidecolor'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Path color', 'bricks' ),
        'type'  => 'color',
        'units' => true,
        'inline' => true,
        'css' => [
          [
            'property' => 'color',
            'selector' => '',
          ]
        ],
    ];
    $this->controls['progresscolor'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Progress color', 'bricks' ),
        'type'  => 'color',
        'units' => true,
        'inline' => true,
        'css' => [
          [
            'property' => 'stroke',
            'selector' => '.bc-back-to-top__circle-path',
          ]
        ],
    ];
    $this->controls['arrowtype'] = [
      'group' => 'arrow',
      'tab' => 'content',
      'label' => esc_html__( 'Arrow type', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'type1' => 'Arrow',
          'type2' => 'Angle',
          'type3' => 'Angles',
      ],
      'inline' => true,
      'placeholder' => 'Arrow',
      'default' => 'type1',
  ];
    $this->controls['arrowcolor'] = [
      'group' => 'arrow',
      'tab' => 'content',
      'label' => esc_html__( 'Arrow color', 'bricks' ),
      'type' => 'color',
      'inline' => true,
      'css' => [
        [
          'property' => 'fill',
          'selector' => '.bc-back-to-top__arrow-svg',
        ]
      ],
    ];
    $this->controls['arrowdimensions'] = [
      'group' => 'arrow',
      'tab' => 'content',
      'label' => esc_html__( 'Arrow dimensions', 'bricks' ),
      'type'  => 'number',
      'units' => true,
      'inline' => true,
      'css' => [
        [
          'property' => 'width',
          'selector' => '.bc-back-to-top__arrow-svg',
        ]
      ],
      'placeholder' => '25px',
  ];
    $this->controls['speed'] = [
      'group'   => 'animation',
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Progress speed', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '10',
    ];
    $this->controls['ease'] = [
      'group'   => 'animation',
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Progress ease', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'linear',
    ];
    $this->controls['entrancespeed'] = [
      'group'   => 'animation',
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Entrance speed', 'bricks' ),
        'type' => 'number',
        'unit' => 'ms',
        'units' => true,
        'inline' => true,
        'css' => [
          [
            'property' => 'transition-duration',
            'selector' => '',
          ]
        ],
        'placeholder' => '200ms',
    ];
    $this->controls['entranceease'] = [
      'group'   => 'animation',
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Entrance ease', 'bricks' ),
        'type'  => 'text',
        'units' => true,
        'inline' => true,
        'css' => [
          [
            'property' => 'transition-timing-function',
            'selector' => '',
          ]
        ],
        'placeholder' => 'linear',
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'back_to_top', plugin_dir_url( __FILE__ ) . 'js/bc_back_to_top.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $speed = ! empty( $settings['speed'] ) ? $settings['speed'] : '10';
    $ease = ! empty( $settings['ease'] ) ? $settings['ease'] : 'linear';
    $arrowtype = ! empty( $settings['arrowtype'] ) ? $settings['arrowtype'] : 'type1';

    if($arrowtype == 'type1'){
      $arrow = 
      "<svg class='bc-back-to-top__arrow-svg' xmlns='http://www.w3.org/2000/svg' data-name='Layer 1' viewBox='0 0 24 24' id='arrow-up'>
        <path class='bc-back-to-top__arrow-path' d='M17.71,11.29l-5-5a1,1,0,0,0-.33-.21,1,1,0,0,0-.76,0,1,1,0,0,0-.33.21l-5,5a1,1,0,0,0,1.42,1.42L11,9.41V17a1,1,0,0,0,2,0V9.41l3.29,3.3a1,1,0,0,0,1.42,0A1,1,0,0,0,17.71,11.29Z'/>
      </svg>";
    }
    if($arrowtype == 'type2'){
      $arrow = 
      "<svg class='bc-back-to-top__arrow-svg' xmlns='http://www.w3.org/2000/svg' data-name='Layer 1' viewBox='0 0 512 512' id='arrow-up'>
        <path d='M233.4 105.4c12.5-12.5 32.8-12.5 45.3 0l192 192c12.5 12.5 12.5 32.8 0 45.3s-32.8 12.5-45.3 0L256 173.3 86.6 342.6c-12.5 12.5-32.8 12.5-45.3 0s-12.5-32.8 0-45.3l192-192z'/>
      </svg>";
    }
    if($arrowtype == 'type3'){
      $arrow = 
      "<svg class='bc-back-to-top__arrow-svg' xmlns='http://www.w3.org/2000/svg' data-name='Layer 1' viewBox='0 0 24 24' id='arrow-up'>
        <path d='m12 6.414 7.293 7.293 1.414-1.414L12 3.586l-8.707 8.707 1.414 1.414L12 6.414z'/><path d='m3.293 18.293 1.414 1.414L12 12.414l7.293 7.293 1.414-1.414L12 9.586l-8.707 8.707z'/>
      </svg>";
    }

    $this->set_attribute( '_root', 'data-speed', "$speed");
    $this->set_attribute( '_root', 'data-ease', "$ease");

    $this->set_attribute( '_root', 'class', 'bc-back-to-top' );
    $this->set_attribute( '_root', 'class', 'bc-to-hide' );

    $output = "<div {$this->render_attributes( '_root' )}>
    <svg class='bc-back-to-top__progress-circle bc-back-to-top__svg-content' width='100%' height='100%' viewBox='-1 -1 102 102'>
      <path class='bc-back-to-top__circle-path' d='M50,1 a49,49 0 0,1 0,98 a49,49 0 0,1 0,-98'/>
    </svg>
    $arrow
    ";
    $output .= '</div>';

	echo $output;
  }
}