<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Blade_Title extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'blade-title';
  public $icon         = 'ti-text';
  public $tag      = 'h3';
  public $css_selector = '';
  public $scripts      = ['blade_title'];

  public function get_label() {
    return esc_html__( 'Blade Reveal', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['animation'] = [
        'title' => esc_html__( 'Animation', 'bricks' ),
        'tab'   => 'content',
    ];
    $this->control_groups['gradient'] = [
      'title' => esc_html__( 'Gradient', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
      'tab'            => 'content',
      'type'           => 'text',
	    'hasDynamicData' => 'text',
      'default'        => esc_html__( 'Blade Reveal', 'bricks' ),
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];

    $this->controls['titleTypography'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Typography', 'bricks' ),
        'type'    => 'typography',
              'css'     => [
          [
            'property' => 'typography',
            'selector' => '.bc-blade-title__span',
          ],
        ],
    ];

    $this->controls['tag'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'HTML tag', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'h1' => 'h1',
            'h2' => 'h2',
            'h3' => 'h3',
            'h4' => 'h4',
            'h5' => 'h5',
            'h6' => 'h6',
            'p' => 'p',
            'span' => 'span',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'h3',
        'default'     => 'h3',
    ];

    $this->controls['type'] = [
      'tab' => 'content',
      'group'   => 'animation',
      'label' => esc_html__( 'Split type', 'bricks' ),
      'type' => 'select',
      'options'     => [
        'chars' => 'chars',
        'words' => 'words',
        'lines' => 'lines',
    ],
      'inline' => true,
      'placeholder' => 'chars',
  ];

    $this->controls['from'] = [
      'tab' => 'content',
      'group'   => 'animation',
      'label' => esc_html__( 'From', 'bricks' ),
      'type' => 'select',
      'options'     => [
        '1' => 'bottom',
        '-1' => 'top',
    ],
      'inline' => true,
      'placeholder' => 'bottom',
  ];

  $this->controls['distance'] = [
    'tab' => 'content',
    'group'   => 'animation',
    'label' => esc_html__( 'Distance', 'bricks' ),
    'type' => 'number',
    'unit' => '%',
    'inline' => true,
    'placeholder' => '100%',
  ];

  $this->controls['skew'] = [
    'hasDynamicData' => false,
    'tab' => 'content',
    'group'   => 'animation',
    'label' => esc_html__( 'Skew', 'bricks' ),
    'type' => 'text',
    'inline' => true,
    'placeholder' => '0',
  ];

  $this->controls['stagger'] = [
    'hasDynamicData' => false,
    'tab' => 'content',
    'group'   => 'animation',
    'label' => esc_html__( 'Stagger', 'bricks' ),
    'type' => 'text',
    'inline' => true,
    'placeholder' => '0.05',
];

    $this->controls['duration'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Duration', 'bricks' ),
        'type' => 'number',
        'unit' => 's',
        'inline' => true,
        'placeholder' => '0.6s',
    ];

    $this->controls['ease'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'GSAP easing', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'power1.out',
    ];

    $this->controls['scrolltrigger'] = [
      'group'   => 'animation',
      'label'      => esc_html__( 'SrollTrigger', 'bricks' ),
      'type'       => 'separator',
      'description' => sprintf(esc_html__( 'Scrolltrigger %s', 'bricks' ), '<a href="https://greensock.com/docs/v3/Plugins/ScrollTrigger" target="_blank">documentation</a>'),
    ];

    $this->controls['trigger'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Trigger', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'this',
    ];

    $this->controls['start'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Start', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'top bottom',
    ];

    $this->controls['end'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'group'   => 'animation',
      'label' => esc_html__( 'End', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 'unset',
  ];

  $this->controls['delay'] = [
    'hasDynamicData' => false,
      'tab' => 'content',
      'group'   => 'animation',
      'label' => esc_html__( 'Delay', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => '0.2',
  ];

  $this->controls['scrub'] = [
    'hasDynamicData' => false,
      'tab' => 'content',
      'group'   => 'animation',
      'label' => esc_html__( 'Scrub', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 'false',
  ];

  $this->controls['toggleActions'] = [
    'hasDynamicData' => false,
      'tab' => 'content',
      'group'   => 'animation',
      'label' => esc_html__( 'toggleActions', 'bricks' ),
      'type' => 'text',
      'placeholder' => 'play none none none',
  ];

  //Gradient
  $this->controls['titleGradient'] = [
    'group' => 'gradient',
    'tab' => 'content',
    'type' => 'gradient',
    'css' => [
      [
        'property' => 'background-image',
        'selector' => '.bc-blade-title__span .line, .bc-blade-title__span .word, .bc-blade-title__span .char',
      ],
    ],
  ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'blade_title', plugin_dir_url( __FILE__ ) . 'js/bc_blade_title.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $start = ! empty( $settings['start'] ) ? $settings['start'] : 'top bottom';
    $end = ! empty( $settings['end'] ) ? $settings['end'] : 'unset';
    $duration = ! empty( $settings['duration'] ) ? $settings['duration'] : 0.6;
    $delay = ! empty( $settings['delay'] ) ? $settings['delay'] : 0.2;
    $trigger = ! empty( $settings['trigger'] ) ? $settings['trigger'] : 'this';
    $ease = ! empty( $settings['ease'] ) ? $settings['ease'] : 'power1.out';
    $type = ! empty( $settings['type'] ) ? $settings['type'] : 'chars';
    $skew = ! empty( $settings['skew'] ) ? $settings['skew'] : 0;
    $stagger = ! empty( $settings['stagger'] ) ? $settings['stagger'] : '0.05';
    $from = ! empty( $settings['from'] ) ? $settings['from'] : '1';
    $distance = ! empty( $settings['distance'] ) ? $settings['distance'] : '100%';
    $scrub = ! empty( $settings['scrub'] ) ? $settings['scrub'] : 'false';
    $toggleActions = ! empty( $settings['toggleActions'] ) ? $settings['toggleActions'] : 'play none none none';

    if ( ! $inner_title ) {
      return $this->render_element_placeholder( [
        'icon-class'  => 'ti-paragraph',
        'inner_title'       => esc_html__( 'Please add a title.', 'bricks' ),
		    'description' => esc_html__( 'Here goes the element placeholder description (optional).', 'bricks' ),
      ] );
    }

    $this->set_attribute( '_root', 'class', 'bc-blade-title' );
    $output = "<div {$this->render_attributes( '_root' )}>";

    if ( $inner_title ) {
      $this->set_attribute( 'inner_title', 'class', 'bc-blade-title__span' );
      $this->set_attribute( 'inner_title', 'class', 'bc-blade-title__to-hide' );
      $this->set_attribute( 'inner_title', 'data-start', "$start");
      $this->set_attribute( 'inner_title', 'data-end', "$end");
      $this->set_attribute( 'inner_title', 'data-duration', "$duration");
      $this->set_attribute( 'inner_title', 'data-delay', "$delay");
      $this->set_attribute( 'inner_title', 'data-trigger', "$trigger");
      $this->set_attribute( 'inner_title', 'data-ease', "$ease");
      $this->set_attribute( 'inner_title', 'data-type', "$type");
      $this->set_attribute( 'inner_title', 'data-skew', $skew);
      $this->set_attribute( 'inner_title', 'data-stagger', "$stagger");
      $this->set_attribute( 'inner_title', 'data-from', "$from");
      $this->set_attribute( 'inner_title', 'data-distance', "$distance");
      $this->set_attribute( 'inner_title', 'data-scrub', "$scrub");
      $this->set_attribute( 'inner_title', 'data-toggleActions', "$toggleActions");


      $output .=
      "<{$this->tag} {$this->render_attributes( 'inner_title' )}>$inner_title</{$this->tag}>";
    }
    $output .= '</div>';


		echo $output;
  }
}