<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Bubbles extends \Bricks\Element {
    public $category     = 'Brickscore - Core';
    public $name         = 'bubbles';
    public $icon         = 'fa-solid fa-soap';
    public $scripts      = ['bubbles'];
    public $nestable     = true;

    public function get_label() {
        return esc_html__( 'Bubbles', 'bricks' );
    }

    public function set_controls() {
        $this->controls['note1'] = [
            'tab' => 'content',
            'description' => sprintf(html_entity_decode(esc_html__( 'NOTE: <br>Reload canvas if you obtain an unexpected behaviour.', 'bricks' )))
          ];
        $this->controls['separator'] = [
            'label'      => esc_html__( 'Style', 'bricks' ),
            'type'       => 'separator',
        ];
        $this->controls['width'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Width', 'bricks' ),
            'type'  => 'number',
            'units' => true,
            'inline' => true,
            'css'     => [
              [
                  'property' => 'width',
                  'selector' => '',
              ],
            ],
            'placeholder' => '100%',
        ];
        $this->controls['height'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Height', 'bricks' ),
            'type'  => 'number',
            'units' => true,
            'inline' => true,
            'css'     => [
              [
                  'property' => 'height',
                  'selector' => '',
              ],
            ],
            'placeholder' => '100vh',
        ];
        $this->controls['background'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Background', 'bricks' ),
            'type'  => 'background',
            'inline' => true,
            'css'     => [
              [
                  'property' => 'background',
                  'selector' => '',
              ],
            ],
        ];

        $this->controls['bubblesblurseparator'] = [
            'label'      => esc_html__( 'Bubbles blur', 'bricks' ),
            'type'       => 'separator',
        ];
        $this->controls['note'] = [ 
            'tab' => 'content',
            'description' => sprintf(esc_html__( 'Blur must be set here. The rest of Bubble settings can be set at each Bubble.', 'bricks' ))
        ];
        $this->controls['blur'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Blur', 'bricks' ),
            'type'  => 'number',
            'units' => true,
            'inline' => true,
            'css'     => [
              [
                  'property' => '--blur',
                  'selector' => '.bc-bubbles__wrapper',
              ],
            ],
            'placeholder' => '40px',
        ];

        $this->controls['cursorseparator'] = [
            'label'      => esc_html__( 'Cursor Bubble', 'bricks' ),
            'type'       => 'separator',
        ];
        $this->controls['enablecursor'] = [
            'label' => esc_html__( 'Enable Cursor Bubble', 'bricks' ),
            'type' => 'checkbox',
            'inline' => true,
            'small' => true,
            'default' => true,
        ];
        $this->controls['attachment'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label'    => esc_html__( 'Attachment', 'bricks' ),
            'type'     => 'text',
            'inline'  => true,
            'small'  => true,
            'placeholder' => '20',
            'required' => [ 'enablecursor', '=', true],
        ];
        $this->controls['dimensions'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Dimensions', 'bricks' ),
            'type'  => 'number',
            'units' => true,
            'inline' => true,
            'css'     => [
              [
                  'property' => '--dimensions',
                  'selector' => '.bc-bubbles__bubble--cursor',
              ],
            ],
            'placeholder' => '100%',
            'required' => [ 'enablecursor', '=', true],
        ];
        $this->controls['bubbleBackground'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Background', 'bricks' ),
            'type'  => 'color',
            'inline' => true,
            'css'     => [
              [
                  'property' => '--inner-background',
                  'selector' => '.bc-bubbles__bubble--cursor',
              ],
            ],
            'required' => [ 'enablecursor', '=', true],
        ];
        $this->controls['blendmode'] = [
			'tab'     => 'content',
			'label'   => 'Mix blend mode',
			'type'    => 'select',
			'inline'  => true,
			'options' => Setup::$control_options['blendMode'],
			'css'     => [
				[
					'property' => '--blending',
                    'selector' => '.bc-bubbles__bubble--cursor',
				]
			],
            'placeholder' => 'hard-light',
            'required' => [ 'enablecursor', '=', true],
		];
        $this->controls['opacity'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label'    => esc_html__( 'Opacity', 'bricks' ),
            'type'     => 'text',
            'inline' => true,
            'small'  => true,
			'css'     => [
				[
					'property' => 'opacity',
                    'selector' => '.bc-bubbles__bubble--cursor',
				]
			],
            'placeholder' => '0.7',
            'required' => [ 'enablecursor', '=', true],
        ];
    }

    /*Render children*/
    public function get_nestable_children() {
        return [
            [
                'name'     => 'block',
                'label'    => esc_html__( 'Content', 'bricks' ),
                'settings' => [
                    '_hidden'  => [
                        '_cssClasses' => 'bc-bubbles__content',
                    ],
                ],
                'children' => [
                    [
                        'name'     => 'heading',
                        'label'    => esc_html__( 'Heading', 'bricks' ),
                        'settings' => [
                            'text' => esc_html__( 'Wonderful Heading', 'bricks' ),
                            'tag'  => 'h3',
                        ],
                    ],
                ],
            ],

            [
                'name'     => 'bubbles_wrapper',
                'children' => [
                    [
                        'name'     => 'bubble',
                        'label'    => esc_html__( 'Bubble', 'bricks' ),
                        'settings' => [
                            '_hidden'  => [
                                '_cssClasses' => 'bc-bubbles__bubble--1',
                            ],
                        ],
                    ],
        
                    [
                        'name'     => 'bubble',
                        'label'    => esc_html__( 'Bubble', 'bricks' ),
                        'settings' => [
                            '_hidden'  => [
                                '_cssClasses' => 'bc-bubbles__bubble--2',
                            ],
                        ],
                    ],
        
                    [
                        'name'     => 'bubble',
                        'label'    => esc_html__( 'Bubble', 'bricks' ),
                        'settings' => [
                            '_hidden'  => [
                                '_cssClasses' => 'bc-bubbles__bubble--3',
                            ],
                        ],
                    ],
        
                    [
                        'name'     => 'bubble',
                        'label'    => esc_html__( 'Bubble', 'bricks' ),
                        'settings' => [
                            '_hidden'  => [
                                '_cssClasses' => 'bc-bubbles__bubble--4',
                            ],
                        ],
                    ],
        
                    [
                        'name'     => 'bubble',
                        'label'    => esc_html__( 'Bubble', 'bricks' ),
                        'settings' => [
                            '_hidden'  => [
                                '_cssClasses' => 'bc-bubbles__bubble--5',
                            ],
                        ],
                    ],
                ],
            ],
        ];
    }

    public function enqueue_scripts() {
        wp_enqueue_script( 'bc-bubbles-js', plugin_dir_url( __FILE__ ) . 'js/bc_bubbles.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
    }

    public function render() {
        $settings = $this->settings;
        $enablecursor = ! empty( $settings['enablecursor'] ) ? $settings['enablecursor'] : 0;
        $attachment = ! empty( $settings['attachment'] ) ? $settings['attachment'] : 20;

        $this->set_attribute( '_root', 'class', "bc-bubbles");
        $this->set_attribute( '_root', 'data-bubble-cursor', $enablecursor);
        $this->set_attribute( '_root', 'data-attachment', $attachment);

        $output = "
        <div {$this->render_attributes( '_root' )}>";
            $output .= \Bricks\Frontend::render_children( $this );
        $output .= "</div>";

        echo $output;
    }
}