<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Circular_Title extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'circular-title';
  public $icon         = 'ti-text';
  public $css_selector = '';
  public $scripts      = ['circular_title'];

  public function get_label() {
    return esc_html__( 'Circular Title', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['animation'] = [
      'title' => esc_html__( 'Animation', 'bricks' ),
      'tab'   => 'content',
    ];
    $this->control_groups['gradient'] = [
      'title' => esc_html__( 'Gradient', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['apply'] = [
      'tab' => 'content',
      'type' => 'apply',
      'reload' => true,
      'label' => esc_html__( 'Reload changes', 'bricks' ),
  ];
    $this->controls['inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'circular·title·circular·title·circular·title·', 'bricks' ),
        'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['link'] = [
        'tab'   => 'content',
        'label' => esc_html__( 'Link to', 'bricks' ),
        'type'  => 'link',
    ];
    $this->controls['typography'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Typography', 'bricks' ),
      'type'        => 'typography',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'typography',
            'selector' => '.bc-circular-title__span-wrapper',
          ],
        ],
      ];
      $this->controls['animationduration'] = [
        'group'   => 'animation',
        'tab'         => 'content',
        'label'       => esc_html__( 'Animation duration', 'bricks' ),
        'type' => 'number',
        'unit' => 's',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'animation-duration',
              'selector' => '.bc-circular-title__span-wrapper',
            ],
        ],
        'placeholder'    => esc_html__( '15s', 'bricks' ),
    ];
    $this->controls['easing'] = [
      'group'   => 'animation',
      'tab'         => 'content',
      'label'       => esc_html__( 'Easing', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'animation-timing-function',
            'selector' => '.bc-circular-title__span-wrapper',
          ],
      ],
      'placeholder'    => esc_html__( 'linear', 'bricks' ),
    ];
    $this->controls['width'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Width', 'bricks' ),
      'type'  => 'number',
      'units' => true,
      'inline'      => true,
      'css'     => [
          [
            'property' => 'width',
            'selector' => '.bc-circular-title__element',
          ],
      ],
      'placeholder'    => esc_html__( '200px', 'bricks' ),
    ];
    $this->controls['height'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Height', 'bricks' ),
      'type'  => 'number',
      'units' => true,
      'inline'      => true,
      'css'     => [
          [
            'property' => 'height',
            'selector' => '.bc-circular-title__element',
          ],
      ],
      'placeholder'    => esc_html__( '200px', 'bricks' ),
    ];
    $this->controls['radio'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Radius', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'placeholder'    => esc_html__( '40', 'bricks' ),
    ];

    //Gradient
    $this->controls['titleGradient'] = [
      'group' => 'gradient',
      'tab' => 'content',
      'type' => 'gradient',
      'css' => [
        [
          'property' => 'background-image',
          'selector' => '.bc-circular-title__span span',
        ],
      ],
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'circular_title', plugin_dir_url( __FILE__ ) . 'js/bc_circular_title.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);

    wp_enqueue_script( 'circulartitle-js', plugin_dir_url( __FILE__ ) . '../local_assets/bc_circletype.min.js', array(), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'circular·title·circular·title·circular·title·';
    $radio = ! empty( $settings['radio'] ) ? $settings['radio'] : 40;

    $this->set_attribute( 'inner_data', 'data-radio', "$radio");

    if ( isset( $settings['link'] ) ) {
        $this->set_link_attributes( 'a', $settings['link'] );
        $output .= "<a {$this->render_attributes( 'a' )}>";
    }

    $this->set_attribute( '_root', 'class', 'bc-circular-title' );
    $output = "<div {$this->render_attributes( '_root' )}>
    <div class='bc-circular-title__element' {$this->render_attributes( 'inner_data' )}>
        <div class='bc-circular-title__span-wrapper'>
            <span class='bc-circular-title__span'>$inner_title</span>
        </div>
    </div>
    ";

    $output .= '</div>';

    if ( isset( $settings['link'] ) ) {
		$output .= '</a>';
	}

	echo $output;
  }
}


