<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Core_Tabs extends \Bricks\Element {
    public $category     = 'Brickscore - Core';
    public $name         = 'coretabs';
    public $icon         = 'ti-layout-tab';
    public $scripts      = ['coretabs'];
    public $nestable     = true;

    public function get_label() {
        return esc_html__( 'Core Tabs', 'bricks' );
    }

    public function set_control_groups() {

    }

    public function set_controls() {
        $this->controls['note'] = [ 
            'tab' => 'content',
            'description' => sprintf(esc_html__( 'Active Tab should match Morphing Nav´s Active Item for a proper navigation understanding.', 'bricks' ))
        ];
        $this->controls['activetab'] = [
            'tab'         => 'content',
            'label'       => esc_html__( 'Active Tab', 'bricks' ),
            'type'        => 'text',
            'inline'      => true,
            'placeholder' => '1',
        ];
        $this->controls['animationSeparator'] = [
            'label'      => esc_html__( 'Fade Animation', 'bricks' ),
            'type'       => 'separator',
        ];
        $this->controls['duration'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Duration', 'bricks' ),
            'type'  => 'number',
            'unit' => 's',
            'inline'      => true,
            'css'     => [
            [
                'property' => '--fade-duration',
                'selector' => '',
            ],
            ],
            'placeholder' => '0.4s',
        ];
        $this->controls['ease'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Easing', 'bricks' ),
            'type'  => 'text',
            'inline'      => true,
            'css'     => [
            [
                'property' => '--fade-ease',
                'selector' => '',
            ],
            ],
            'placeholder' => 'ease',
        ];
    }

    public function get_nestable_children() {
        return [
            [
                'name'     => 'morphingmenu',
                'settings' => [
                    'trigger' => 'click',
                ],
                'children' => [
                    [
                        'name'     => 'morphingmenuitem',
                        'label'    => esc_html__( 'Morphing Item', 'bricks' ),
                        'settings' => [
                            '_hidden'  => [
                                '_cssClasses' => 'bc-core-tabs__tab',
                            ],
                        ],
                    ],
                    [
                        'name'     => 'morphingmenuitem',
                        'label'    => esc_html__( 'Morphing Item', 'bricks' ),
                        'settings' => [
                            '_hidden'  => [
                                '_cssClasses' => 'bc-core-tabs__tab',
                            ],
                        ],
                    ],
                    [
                        'name'     => 'morphingmenuitem',
                        'label'    => esc_html__( 'Morphing Item', 'bricks' ),
                        'settings' => [
                            '_hidden'  => [
                                '_cssClasses' => 'bc-core-tabs__tab',
                            ],
                        ],
                    ],
                ]
            ],

            [
                'name'     => 'block',
                'label'    => esc_html__( 'Core Tab', 'bricks' ),
                'settings' => [
                    '_hidden'  => [
                        '_cssClasses' => 'bc-core-tabs__tab-content',
                    ],
                    '_attributes' => [
                        [
                        'name' => 'data-show',
                        'value' => '',
                        ],
                    ]
                ],
                'children' => [
                    [
                        'name'     => 'heading',
                    ]
                ]
            ],
            [
                'name'     => 'block',
                'label'    => esc_html__( 'Core Tab', 'bricks' ),
                'settings' => [
                    '_hidden'  => [
                        '_cssClasses' => 'bc-core-tabs__tab-content',
                    ],
                    '_attributes' => [
                        [
                        'name' => 'data-show',
                        'value' => '',
                        ],
                    ]
                ],
                'children' => [
                    [
                        'name'     => 'heading',
                    ]
                ]
            ],
            [
                'name'     => 'block',
                'label'    => esc_html__( 'Core Tab', 'bricks' ),
                'settings' => [
                    '_hidden'  => [
                        '_cssClasses' => 'bc-core-tabs__tab-content',
                    ],
                    '_attributes' => [
                        [
                        'name' => 'data-show',
                        'value' => '',
                        ],
                    ]
                ],
                'children' => [
                    [
                        'name'     => 'heading',
                    ]
                ]
            ],
        ];
    }

    public function enqueue_scripts() {
        wp_enqueue_script( 'bc-core-tabs', plugin_dir_url( __FILE__ ) . 'js/bc_core_tabs.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
    }

    public function render() {
        $settings = $this->settings;
        $activetab    = ! empty( $settings['activetab'] ) ? $settings['activetab'] : '1';

        $this->set_attribute( '_root', 'class', 'bc-core-tabs' );
        $this->set_attribute( '_root', 'data-to-hide', '' );
        $this->set_attribute( '_root', 'data-activetab', $activetab );

        $output = "<div {$this->render_attributes( '_root' )}>";
        $output .= Frontend::render_children( $this );
        $output .= "</div>";

        echo $output;
    }
}