<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Counter extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'bc-counter';
  public $icon         = 'ion-ios-timer';
  public $tag      = 'h3';
  public $scripts      = ['bc_counter'];

  public function get_label() {
    return esc_html__( 'Counter', 'bricks' );
  }

  public function set_controls() {
    $this->controls['tag'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'HTML tag', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'h1' => 'h1',
          'h2' => 'h2',
          'h3' => 'h3',
          'h4' => 'h4',
          'h5' => 'h5',
          'h6' => 'h6',
          'p' => 'p',
          'span' => 'span',
      ],
      'clearable'   => false,
      'inline'      => true,
      'placeholder' => 'h3',
      'default'     => 'h3',
  ];
    $this->controls['titleTypography'] = [
      'tab'     => 'content',
      'label'   => esc_html__( 'Typography', 'bricks' ),
      'type'    => 'typography',
        'css'     => [
        [
          'property' => 'typography',
          'selector' => '.bc-counter__counter',
        ],
      ],
    ];

    $this->controls['counterSeparator'] = [
      'label'      => esc_html__( 'Counter', 'bricks' ),
      'type'       => 'separator',
    ];
    $this->controls['startfrom'] = [
      'label'   => esc_html__( 'Count from', 'bricks' ),
      'tab'            => 'content',
      'type'           => 'number',
	    'hasDynamicData' => true,
      'placeholder'    => esc_html__( '0', 'bricks' ),
    ];
    $this->controls['inner_title'] = [
      'label'   => esc_html__( 'Count to', 'bricks' ),
      'tab'            => 'content',
      'type'           => 'number',
	    'hasDynamicData' => true,
      'placeholder'    => esc_html__( '5000', 'bricks' ),
    ];
    $this->controls['enableseparator'] = [
      'label' => esc_html__( 'Enable thousands', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => false,
  ];
    $this->controls['separator'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Separator', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'placeholder' => ',',
      'required' => [ 'enableseparator', '=', true],
    ];

    $this->controls['prefixsufixSeparator'] = [
      'label'      => esc_html__( 'Prefix & Sufix', 'bricks' ),
      'type'       => 'separator',
  ];
    $this->controls['prefix'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Prefix', 'bricks' ),
      'type' => 'text',
      'inline'      => true,
      'hasDynamicData' => true,
      'placeholder' => '',
    ];
    $this->controls['prefixTypography'] = [
      'tab'     => 'content',
      'label'   => esc_html__( 'Prefix typography', 'bricks' ),
      'type'    => 'typography',
        'css'     => [
        [
          'property' => 'typography',
          'selector' => '.bc-counter__prefix',
        ],
      ],
    ];
    $this->controls['sufix'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Sufix', 'bricks' ),
      'type' => 'text',
      'inline'      => true,
      'hasDynamicData' => true,
      'placeholder' => '',
    ];
    $this->controls['sufixTypography'] = [
      'tab'     => 'content',
      'label'   => esc_html__( 'Sufix typography', 'bricks' ),
      'type'    => 'typography',
        'css'     => [
        [
          'property' => 'typography',
          'selector' => '.bc-counter__sufix',
        ],
      ],
    ];

    $this->controls['animationSeparator'] = [
        'label'      => esc_html__( 'Animation', 'bricks' ),
        'type'       => 'separator',
    ];
    $this->controls['trigger'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Trigger', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 'this',
    ];
    $this->controls['start'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Start', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 'top bottom',
    ];
    $this->controls['end'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'End', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 'false',
    ];
    $this->controls['trigger'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Trigger', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 'this',
    ];
    $this->controls['easing'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Easing', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'Default' => 'Default',
          'outQuintic' => 'outQuintic',
          'outCubic' => 'outCubic',
      ],
      'placeholder' => 'Default',
      'inline' => true,
    ];
    $this->controls['duration'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Duration', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'inline' => true,
      'placeholder' => '1s',
    ];
    $this->controls['replay'] = [
      'label' => esc_html__( 'Replay on enter back', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => false,
    ];
  }

  public function enqueue_scripts() {
    wp_enqueue_script( 'bc-counter', plugin_dir_url( __FILE__ ) . 'js/bc_counter.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);

    wp_enqueue_script( 'bc-countup', plugin_dir_url( __FILE__ ) . '../local_assets/bc_countup.min.js', array(), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $startfrom    = ! empty( $settings['startfrom'] ) ? $settings['startfrom'] : '0';
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : '5000';
    $enableseparator    = ! empty( $settings['enableseparator'] ) ? $settings['enableseparator'] : 0;
    $separator    = ! empty( $settings['separator'] ) ? $settings['separator'] : ',';
    $prefix    = ! empty( $settings['prefix'] ) ? $settings['prefix'] : '';
    $sufix    = ! empty( $settings['sufix'] ) ? $settings['sufix'] : '';

    $trigger    = ! empty( $settings['trigger'] ) ? $settings['trigger'] : 'this';
    $start    = ! empty( $settings['start'] ) ? $settings['start'] : 'top bottom';
    $end    = ! empty( $settings['end'] ) ? $settings['end'] : 'false';
    $duration    = ! empty( $settings['duration'] ) ? $settings['duration'] : 1;
    $easing    = ! empty( $settings['easing'] ) ? $settings['easing'] : 'Default';
    $replay    = ! empty( $settings['replay'] ) ? $settings['replay'] : 0;

    $this->set_attribute( '_root', 'class', 'bc-counter' );
    $this->set_attribute( '_inner', 'class', 'bc-counter__counter' );
    $this->set_attribute( '_inner', 'data-value', $inner_title );
    $this->set_attribute( '_inner', 'data-startfrom', $startfrom );
    $this->set_attribute( '_inner', 'data-enableseparator', $enableseparator );
    $this->set_attribute( '_inner', 'data-separator', $separator );
    $this->set_attribute( '_inner', 'data-prefix', $prefix );
    $this->set_attribute( '_inner', 'data-sufix', $sufix );
    $this->set_attribute( '_inner', 'data-trigger', $trigger );
    $this->set_attribute( '_inner', 'data-start', $start );
    $this->set_attribute( '_inner', 'data-end', $end );
    $this->set_attribute( '_inner', 'data-duration', $duration );
    $this->set_attribute( '_inner', 'data-easing', $easing );
    $this->set_attribute( '_inner', 'data-replay', $replay );

    $output = "<{$this->tag} {$this->render_attributes( '_root' )}>";
    if($prefix != ''){
      $output .= "<span class='bc-counter__prefix'>$prefix</span>";
    }
    $output .= "<span {$this->render_attributes( '_inner' )}>$startfrom</span>";
    if($sufix != ''){
      $output .= "<span class='bc-counter__sufix'>$sufix</span>";
    }
    $output .= "</{$this->tag}>";

    echo $output;
  }
}

