<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Crystalbutton extends \Bricks\Element {
  public $category     = 'Brickscore - Buttons';
  public $name         = 'crystalbutton';
  public $icon         = 'fa-solid fa-square-minus';
  public $scripts      = ['crystalbutton'];

  public function get_label() {
    return esc_html__( 'Crystal Button', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['crystal'] = [
      'title' => esc_html__( 'Crystal', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Crystal Button', 'bricks' ),
        'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['link'] = [
        'tab'   => 'content',
        'label' => esc_html__( 'Link to', 'bricks' ),
        'type'  => 'link',
    ];
    $this->controls['whitespace'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'White space', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'wrap' => 'wrap',
          'nowrap' => 'nowrap',
      ],
      'inline'      => true,
      'css'     => [
          [
            'property' => 'white-space',
            'selector' => '',
          ],
        ],
      'placeholder'        => 'wrap',
  ];
    $this->controls['typography'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Typography', 'bricks' ),
      'type'        => 'typography',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'typography',
            'selector' => '',
          ],
        ],
      ];
      $this->controls['background'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Background', 'bricks' ),
        'type'        => 'color',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-crystal-button__backdrop',
            ],
          ],
      ];
      $this->controls['border'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Border radius', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => '--radius',
              'selector' => '',
            ],
          ],
          'placeholder'    => esc_html__( '15px', 'bricks' ),
    ];
    $this->controls['bordermain'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Border', 'bricks' ),
      'type'        => 'border',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'border',
            'selector' => '',
          ],
        ],
      'exclude' => [
        'radius',
      ],
  ];
  $this->controls['padding'] = [
    'tab'         => 'content',
    'label'       => esc_html__( 'Padding', 'bricks' ),
    'type'        => 'dimensions',
    'css'     => [
        [
          'property' => 'padding',
          'selector' => '',
        ],
      ],
      'placeholder' => [
        'top' => 12,
        'right' => 36,
        'bottom' => 12,
        'left' => 36,
      ],
];
$this->controls['filter'] = [
  'group'   => 'crystal',
  'tab'         => 'content',
  'label'       => esc_html__( 'Filter', 'bricks' ),
  'type'        => 'text',
  'inline'      => true,
  'css'     => [
      [
        'property' => '--filter',
        'selector' => '',
      ],
    ],
    'placeholder'    => esc_html__( '0.7', 'bricks' ),
];
$this->controls['blur'] = [
  'group'   => 'crystal',
  'tab'         => 'content',
  'label'       => esc_html__( 'Blur', 'bricks' ),
  'type'  => 'number',
  'units' => true,
  'inline'      => true,
  'css'     => [
      [
        'property' => '--blur',
        'selector' => '.bc-crystal-button__backdrop',
      ],
    ],
    'placeholder'    => esc_html__( '20px', 'bricks' ),
];
$this->controls['brightness'] = [
  'group'   => 'crystal',
  'tab'         => 'content',
  'label'       => esc_html__( 'Brightness', 'bricks' ),
  'type'        => 'text',
  'inline'      => true,
  'css'     => [
      [
        'property' => '--brightness',
        'selector' => '.bc-crystal-button__backdrop',
      ],
    ],
    'placeholder'    => esc_html__( '1.2', 'bricks' ),
];
$this->controls['saturate'] = [
  'group'   => 'crystal',
  'tab'         => 'content',
  'label'       => esc_html__( 'Saturate', 'bricks' ),
  'type'        => 'text',
  'inline'      => true,
  'css'     => [
      [
        'property' => '--saturate',
        'selector' => '.bc-crystal-button__backdrop',
      ],
    ],
    'placeholder'    => esc_html__( '1', 'bricks' ),
];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'crystalbutton', plugin_dir_url( __FILE__ ) . 'js/bc_crystal_button.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';

		if ( ! empty( $settings['link'] ) ) {
			$this->set_link_attributes( '_root', $settings['link'] );
		}


    $this->set_attribute( '_root', 'class', 'bc-crystal-button' );
    $this->set_attribute( '_root', 'class', 'bc-crystal-button--dark' );
    $this->set_attribute( '_root', 'class', 'bc-crystal-button--control' );

    $output = "
    <a {$this->render_attributes( '_root' )}>
        <div class='bc-crystal-button__backdrop'></div>
        <div class='bc-crystal-button__title'>$inner_title</div>
    </a>
    ";

    $output .= '</a>';

	echo $output;
  }
}



