<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Decode_Hover extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'decode-hover';
  public $icon         = 'ti-text';
  public $tag      = 'h3';
  public $css_selector = '';
  public $scripts      = ['decodehover'];

  public function get_label() {
    return esc_html__( 'Decode Hover', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['gradient'] = [
      'title' => esc_html__( 'Gradient', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
      'tab'            => 'content',
      'type'           => 'text',
	    'hasDynamicData' => 'text',
      'default'        => esc_html__( 'Decode Hover', 'bricks' ),
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['titleTypography'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Typography', 'bricks' ),
        'type'    => 'typography',
              'css'     => [
          [
            'property' => 'typography',
            'selector' => '',
          ],
        ],
    ];
    $this->controls['tag'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'HTML tag', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'h1' => 'h1',
            'h2' => 'h2',
            'h3' => 'h3',
            'h4' => 'h4',
            'h5' => 'h5',
            'h6' => 'h6',
            'p' => 'p',
            'span' => 'span',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'h3',
        'default'     => 'h3',
    ];
    $this->controls['link'] = [
        'tab'   => 'content',
        'label' => esc_html__( 'Link to', 'bricks' ),
        'type'  => 'link',
    ];

    $this->controls['animationSeparator'] = [
        'label'      => esc_html__( 'Animation', 'bricks' ),
        'type'       => 'separator',
    ];

    $this->controls['decodealphabet'] = [
      'hasDynamicData' => false,
      'tab'         => 'content',
      'label'       => esc_html__( 'Decode alphabet', 'bricks' ),
      'type' => 'textarea',
      'placeholder' => 'abcdefghijklmnopqrstuvwxyz1234567890!@#$^&*()…æ_+-=;[]/~`',
  ];
    $this->controls['from'] = [
        'hasDynamicData' => false,
        'tab'         => 'content',
        'label'       => esc_html__( 'From', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            '-1' => 'left',
            '1' => 'right',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'left',
    ];
    $this->controls['duration'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Duration', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '20',
    ];
    $this->controls['delay'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Delay', 'bricks' ),
        'type' => 'number',
        'unit' => 's',
        'inline' => true,
        'placeholder' => '0.1s',
    ];
    $this->controls['ease'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'GSAP easing', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'power4',
    ];

    //Gradient
    $this->controls['titleGradient'] = [
      'group' => 'gradient',
      'tab' => 'content',
      'type' => 'gradient',
      'css' => [
        [
          'property' => 'background-image',
          'selector' => '',
        ],
      ],
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'bc_decode_hover', plugin_dir_url( __FILE__ ) . 'js/bc_decode_hover.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $delay    = ! empty( $settings['delay'] ) ? $settings['delay'] : 0.1;
    $duration    = ! empty( $settings['duration'] ) ? $settings['duration'] : 20;
    $ease    = ! empty( $settings['ease'] ) ? $settings['ease'] : 'power4';
    $from    = ! empty( $settings['from'] ) ? $settings['from'] : -1;
    $decodealphabet    = ! empty( $settings['decodealphabet'] ) ? $settings['decodealphabet'] : 'abcdefghijklmnopqrstuvwxyz1234567890!@#$^&*()…æ_+-=;[]/~`';

    if ( ! empty( $settings['link'] ) ) {
        $this->set_link_attributes( '_inner', $settings['link'] );
    }
    if($from == -1){
        $this->set_attribute( '_root', 'data-from-left', '' );
    }else if($from == 1){
        $this->set_attribute( '_root', 'data-from-right', '' );
    }
    $this->set_attribute( '_root', 'class', 'bc-decode-hover' );
    $this->set_attribute( '_root', 'data-delay', $delay );
    $this->set_attribute( '_root', 'data-duration', $duration );
    $this->set_attribute( '_root', 'data-ease', $ease );
    $this->set_attribute( '_root', 'data-decodealphabet', $decodealphabet );
    $this->set_attribute( '_inner', 'class', 'bc-decode-hover__wrapper-link' );
    
    $output = "<a {$this->render_attributes( '_inner' )}><{$this->tag} {$this->render_attributes( '_root' )}>$inner_title</{$this->tag}></a>";

	echo $output;
  }
}