<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Decode_Reveal extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'decode-reveal';
  public $icon         = 'ti-text';
  public $tag      = 'h3';
  public $css_selector = '';
  public $scripts      = ['decode_reveal'];

  public function get_label() {
    return esc_html__( 'Decode Reveal', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['gradient'] = [
      'title' => esc_html__( 'Gradient', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
      'tab'            => 'content',
      'type'           => 'text',
	    'hasDynamicData' => 'text',
      'default'        => esc_html__( 'Decode Reveal', 'bricks' ),
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['titleTypography'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Typography', 'bricks' ),
        'type'    => 'typography',
              'css'     => [
          [
            'property' => 'typography',
            'selector' => '',
          ],
        ],
    ];
    $this->controls['tag'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'HTML tag', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'h1' => 'h1',
            'h2' => 'h2',
            'h3' => 'h3',
            'h4' => 'h4',
            'h5' => 'h5',
            'h6' => 'h6',
            'p' => 'p',
            'span' => 'span',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'h3',
        'default'     => 'h3',
    ];
    $this->controls['link'] = [
        'tab'   => 'content',
        'label' => esc_html__( 'Link to', 'bricks' ),
        'type'  => 'link',
    ];

    $this->controls['animationSeparator'] = [
        'label'      => esc_html__( 'Animation', 'bricks' ),
        'type'       => 'separator',
    ];

    $this->controls['decodealphabet'] = [
        'hasDynamicData' => false,
        'tab'         => 'content',
        'label'       => esc_html__( 'Decode alphabet', 'bricks' ),
        'type' => 'textarea',
        'placeholder' => 'abcdefghijklmnopqrstuvwxyz1234567890!@#$^&*()…æ_+-=;[]/~`',
    ];
    $this->controls['from'] = [
          'hasDynamicData' => false,
          'tab'         => 'content',
          'label'       => esc_html__( 'From', 'bricks' ),
          'type'        => 'select',
          'options'     => [
              '-1' => 'left',
              '1' => 'right',
          ],
          'clearable'   => false,
          'inline'      => true,
          'placeholder' => 'left',
    ];
    $this->controls['delay'] = [
          'hasDynamicData' => false,
          'tab' => 'content',
          'label' => esc_html__( 'Delay', 'bricks' ),
          'type' => 'number',
          'unit' => 's',
          'inline' => true,
          'placeholder' => '0s',
    ];
    $this->controls['delayletters'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Delay letters', 'bricks' ),
        'type' => 'number',
        'unit' => 's',
        'inline' => true,
        'placeholder' => '0.07s',
    ];

    $this->controls['scrolltrigger'] = [
        'label'      => esc_html__( 'SrollTrigger', 'bricks' ),
        'type'       => 'separator',
        'description' => sprintf(esc_html__( 'Scrolltrigger %s', 'bricks' ), '<a href="https://greensock.com/docs/v3/Plugins/ScrollTrigger" target="_blank">documentation</a>'),
    ];
  
    $this->controls['trigger'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Trigger', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'this',
    ];
  
    $this->controls['start'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Start', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'top bottom',
    ];

    //Gradient
    $this->controls['titleGradient'] = [
      'group' => 'gradient',
      'tab' => 'content',
      'type' => 'gradient',
      'css' => [
        [
          'property' => 'background-image',
          'selector' => '.char',
        ],
      ],
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'bc-decode-reveal', plugin_dir_url( __FILE__ ) . 'js/bc_decode_reveal.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $delay    = ! empty( $settings['delay'] ) ? $settings['delay'] : 0;
    $delayletters    = ! empty( $settings['delayletters'] ) ? $settings['delayletters'] : 0.07;
    $from    = ! empty( $settings['from'] ) ? $settings['from'] : -1;
    $decodealphabet    = ! empty( $settings['decodealphabet'] ) ? $settings['decodealphabet'] : 'abcdefghijklmnopqrstuvwxyz1234567890!@#$^&*()…æ_+-=;[]/~`';
    $trigger    = ! empty( $settings['trigger'] ) ? $settings['trigger'] : 'this';
    $start    = ! empty( $settings['start'] ) ? $settings['start'] : 'top bottom';

    if($from == -1){
        $this->set_attribute( '_root', 'data-from-left', '' );
    }else if($from == 1){
        $this->set_attribute( '_root', 'data-from-right', '' );
    }

    $this->set_attribute( '_root', 'class', 'bc-decode-reveal' );
    $this->set_attribute( '_root', 'data-hide', '' );
    $this->set_attribute( '_root', 'data-delay', $delay );
    $this->set_attribute( '_root', 'data-delayletters', $delayletters );
    $this->set_attribute( '_root', 'data-decodealphabet', "$decodealphabet" );
    $this->set_attribute( '_root', 'data-trigger', "$trigger" );
    $this->set_attribute( '_root', 'data-start', "$start"  );

    $output = "<{$this->tag} {$this->render_attributes( '_root' )}>$inner_title</{$this->tag}>";

    echo $output;
  }
}