<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Drawer extends \Bricks\Element {
  public $category     = 'Brickscore - Core';
  public $name         = 'bc_drawer';
  public $icon         = 'ion-ios-archive';
  public $scripts      = ['bc_drawer'];
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'Drawer', 'bricks' );
  }

  public function set_controls() {
    $this->controls['show'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label'    => esc_html__( 'Show at builder', 'bricks' ),
      'type'     => 'checkbox',
    ];
    $this->controls['trigger'] = [
      'hasDynamicData' => true,
      'tab' => 'content',
      'label' => esc_html__( 'Trigger element', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => '.className',
    ];

    $this->controls['drawerSeparator'] = [
      'label'      => esc_html__( 'Drawer', 'bricks' ),
      'type'       => 'separator',
    ];
    $this->controls['drawerwidth'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Width', 'bricks' ),
      'type' => 'number',
      'units' => true,
      'inline' => true,
      'css' => [
        [
          'property' => 'width',
          'selector' => '',
        ]
      ],
      'required' => [ 'drag', '=', true],
      'placeholder' => '100%',
    ];
    $this->controls['drawerheight'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Height', 'bricks' ),
      'type' => 'number',
      'units' => true,
      'inline' => true,
      'css' => [
        [
          'property' => 'height',
          'selector' => '',
        ]
      ],
      'required' => [ 'drag', '=', true],
      'placeholder' => '500px',
    ];
    $this->controls['drawerpadding'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Padding', 'bricks' ),
      'type' => 'spacing',
      'css' => [
        [
          'property' => 'padding',
          'selector' => '',
        ]
      ],
    ];
    $this->controls['drawerbackground'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Background', 'bricks' ),
      'type' => 'background',
      'inline' => true,
      'css' => [
        [
          'property' => 'background',
          'selector' => '',
        ]
      ],
    ];
    $this->controls['drawerborder'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Border', 'bricks' ),
      'type' => 'border',
      'inline' => true,
      'css' => [
        [
          'property' => 'border',
          'selector' => '',
        ]
      ],
    ];
    $this->controls['drawerboxshadow'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Box shadow', 'bricks' ),
      'type' => 'box-shadow',
      'inline' => true,
      'css' => [
        [
          'property' => 'box-shadow',
          'selector' => '',
        ]
      ],
    ];
    $this->controls['drawerduration'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Translate duration', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'inline' => true,
      'css' => [
        [
          'property' => '--drawer-duration',
          'selector' => '',
        ]
      ],
      'placeholder' => '.4s',
    ];
    $this->controls['drawereasing'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Translate easing', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'css' => [
        [
          'property' => '--drawer-easing',
          'selector' => '',
        ]
      ],
      'placeholder' => 'cubic-bezier(.32,.72,0,1)',
    ];
    $this->controls['drawerindex'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'zIndex', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'css' => [
        [
          'property' => 'z-index',
          'selector' => '',
        ]
      ],
      'placeholder' => '99999',
    ];

    $this->controls['drag'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label'    => esc_html__( 'Enable mini drag', 'bricks' ),
      'type'     => 'checkbox',
      'default'       => true,
    ];
    $this->controls['dragSeparator'] = [
      'label'      => esc_html__( 'Mini drag', 'bricks' ),
      'type'       => 'separator',
      'required' => [ 'drag', '=', true],
    ];
    $this->controls['dragmargin'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Margin', 'bricks' ),
      'type' => 'spacing',
      'css' => [
        [
          'property' => 'margin',
          'selector' => '.bc-drawer__drag',
        ]
      ],
    ];
    $this->controls['dragheight'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Height', 'bricks' ),
      'type' => 'number',
      'units' => true,
      'inline' => true,
      'css' => [
        [
          'property' => 'height',
          'selector' => '.bc-drawer__drag',
        ]
      ],
      'required' => [ 'drag', '=', true],
      'placeholder' => '8px',
    ];
    $this->controls['dragwidth'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Width', 'bricks' ),
      'type' => 'number',
      'units' => true,
      'inline' => true,
      'css' => [
        [
          'property' => 'width',
          'selector' => '.bc-drawer__drag',
        ]
      ],
      'required' => [ 'drag', '=', true],
      'placeholder' => '100px',
    ];
    $this->controls['dragbackground'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Background', 'bricks' ),
      'type' => 'background',
      'inline' => true,
      'css' => [
        [
          'property' => 'background',
          'selector' => '.bc-drawer__drag',
        ]
      ],
      'required' => [ 'drag', '=', true],
    ];

    $this->controls['overlaySeparator'] = [
      'label'      => esc_html__( 'Overlay', 'bricks' ),
      'type'       => 'separator',
    ];
    $this->controls['overlaybackground'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Background', 'bricks' ),
      'type' => 'background',
      'inline' => true,
      'css' => [
        [
          'property' => 'background',
          'selector' => '~ .bc-drawer__overlay',
        ]
      ],
    ];
    $this->controls['overlayduration'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Fade duration', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'inline' => true,
      'css' => [
        [
          'property' => '--overlay-duration',
          'selector' => '~ .bc-drawer__overlay',
        ]
      ],
      'placeholder' => '.4s',
    ];
    $this->controls['overlayeasing'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Fade easing', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'css' => [
        [
          'property' => '--overlay-easing',
          'selector' => '~ .bc-drawer__overlay',
        ]
      ],
      'placeholder' => 'cubic-bezier(.32,.72,0,1)',
    ];
    $this->controls['overlayindex'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'zIndex', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'css' => [
        [
          'property' => 'z-index',
          'selector' => '~ .bc-drawer__overlay',
        ]
      ],
      'placeholder' => '99998',
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'bc-drawer', plugin_dir_url( __FILE__ ) . 'js/bc_drawer.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $trigger = ! empty( $settings['trigger'] ) ? $settings['trigger'] : '';
    $show = ! empty( $settings['show'] ) ? $settings['show'] : false;
    $drag = ! empty( $settings['drag'] ) ? $settings['drag'] : 0;

    $this->set_attribute( '_root', 'class', 'bc-drawer__drawer' );
    $this->set_attribute( '_root', 'data-trigger', $trigger );
    $this->set_attribute( '_root', 'data-show', $show );

    $output = "<div class='bc-drawer'>";

    $output .= "<div {$this->render_attributes( '_root' )}>";
    if($drag == 1){
      $output .= "<div class='bc-drawer__drag'></div>";
    }
    // Render children elements (= individual items)
    $output .= Frontend::render_children( $this );
    $output .= "</div>";

    $output .= "<div class='bc-drawer__overlay'></div>";
    $output .= "</div>";

	echo $output;
  }
}