<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Exchange_Title extends \Bricks\Element {
    public $category     = 'Brickscore - Titles';
    public $name         = 'exchange_title';
    public $icon         = 'ti-layout-width-default';
    public $scripts      = ['exchange_title'];
    public $nestable     = true;

    public function get_label() {
    return esc_html__( 'Exchange Title', 'bricks' );
    }

    public function set_controls() {
        $this->controls['_children'] = [
            'type'          => 'repeater',
            'titleProperty' => 'label',
            'items'         => 'children',
        ];

        $this->controls['styleseparator'] = [
            'label'      => esc_html__( 'Style', 'bricks' ),
            'type'       => 'separator',
        ];
        $this->controls['note'] = [
            'tab' => 'content',
            'description' => sprintf(html_entity_decode(esc_html__( 'In case you don´t define fixed dimensions then the first title will determine the dimensions and you may want to reload canvas when changing a title size.', 'bricks' )))
        ];
        $this->controls['height'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Height', 'bricks' ),
            'type'  => 'number',
            'unit' => 'px',
            'placeholder' => 'fit-content',
        ];
        $this->controls['width'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Width', 'bricks' ),
            'type'  => 'number',
            'units' => true,
            'css'     => [
              [
                  'property' => 'width',
                  'selector' => '.bc-exchange-title__wrapper',
              ],
            ],
            'placeholder' => 'fit-content',
        ];
        $this->controls['typography'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Titles typography', 'bricks' ),
            'type'  => 'typography',
            'inline' => true,
            'css'     => [
              [
                  'property' => 'typography',
                  'selector' => '.bc-exchange-title__wrapper',
              ],
            ],
        ];

        $this->controls['animationseparator'] = [
            'label'      => esc_html__( 'Animation', 'bricks' ),
            'type'       => 'separator',
        ];
        $this->controls['duration'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Exchange duration', 'bricks' ),
            'type'  => 'number',
            'unit'  => 's',
            'inline' => true,
            'placeholder' => '0.2s',
        ];
        $this->controls['easing'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Easing', 'bricks' ),
            'type'  => 'text',
            'inline' => true,
            'placeholder' => 'none',
        ];
        $this->controls['delay'] = [
            'hasDynamicData' => false,
            'tab' => 'content',
            'label' => esc_html__( 'Delay between Exchanges', 'bricks' ),
            'type'  => 'number',
            'unit'  => 's',
            'inline' => true,
            'placeholder' => '2s',
        ];
    }

    /*Render children*/
    public function get_nestable_children() {
        return [
            [
                'name'     => 'heading',
                'label'    => esc_html__( 'Title', 'bricks' ),
                'settings' => [
                    'text' => esc_html__( 'Ready to invest in art?', 'bricks' ),
                    'tag'  => 'h3',
                ],
            ],

            [
                'name'     => 'heading',
                'label'    => esc_html__( 'Title', 'bricks' ),
                'settings' => [
                    'text' => esc_html__( 'How can we help?', 'bricks' ),
                    'tag'  => 'h3',
                ],
            ],

            [
                'name'     => 'heading',
                'label'    => esc_html__( 'Title', 'bricks' ),
                'settings' => [
                    'text' => esc_html__( 'Need help choosing?', 'bricks' ),
                    'tag'  => 'h3',
                ],
            ],
        ];
      }

    public function enqueue_scripts() {
        wp_enqueue_script( 'bc_exchange_title', plugin_dir_url( __FILE__ ) . 'js/bc_exchange_title.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
    }

    public function render() {
        $settings = $this->settings;
        $duration    = ! empty( $settings['duration'] ) ? $settings['duration'] : '0.2s';
        $delay    = ! empty( $settings['delay'] ) ? $settings['delay'] : '2s';
        $easing    = ! empty( $settings['easing'] ) ? $settings['easing'] : 'none';
        $height    = ! empty( $settings['height'] ) ? $settings['height'] : '';

        $this->set_attribute( '_root', 'class', 'bc-exchange-title' );

        $this->set_attribute( '_inner', 'class', 'bc-exchange-title__wrapper' );
        $this->set_attribute( '_inner', 'data-duration', $duration);
        $this->set_attribute( '_inner', 'data-delay', $delay);
        $this->set_attribute( '_inner', 'data-easing', $easing);
        $this->set_attribute( '_inner', 'data-height', $height);
        
        $output = "<div {$this->render_attributes( '_root' )}>";
        $output .= "<div {$this->render_attributes( '_inner' )}>";
        $output .= Frontend::render_children( $this );
        $output .= "</div>";
        $output .= "</div>";

        echo $output;
    }
}