<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Expander extends Element {
  public $category     = 'Brickscore - Core';
  public $name         = 'expander';
  public $icon         = 'fa-solid fa-expand';
  public $tag      = 'h3';
  public $scripts      = ['bcexpander'];
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'Expanders', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['expandersettings'] = [
        'title' => esc_html__( 'Expander settings', 'bricks' ),
        'tab'   => 'content',
    ];
    $this->control_groups['labelsettings'] = [
        'title' => esc_html__( 'Label settings', 'bricks' ),
        'tab'   => 'content',
    ];
    $this->control_groups['contentsettings'] = [
        'title' => esc_html__( 'Content settings', 'bricks' ),
        'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['_children'] = [
        'type'          => 'repeater',
        'titleProperty' => 'label',
        'items'         => 'children',
    ];
    $this->controls['mode'] = [
        'hasDynamicData' => false,
        'tab'         => 'content',
        'label'       => esc_html__( 'Mode', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'click' => 'click',
            'hover' => 'hover',
        ],
        'inline'      => true,
        'small'      => true,
        'placeholder' => 'click',
    ];
    $this->controls['singleopen'] = [
        'hasDynamicData' => false,
        'tab'         => 'content',
        'label'       => esc_html__( 'Single Open', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'true' => 'true',
            'false' => 'false',
        ],
        'inline'      => true,
        'small'      => true,
        'placeholder' => 'true',
    ];
    $this->controls['openall'] = [
        'hasDynamicData' => false,
        'tab'         => 'content',
        'label'       => esc_html__( 'Open by Default', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'true' => 'true',
            'false' => 'false',
        ],
        'inline'      => true,
        'small'      => true,
        'placeholder' => 'false',
    ];
    /*Expander*/
    $this->controls['expanderwidth'] = [
        'inline' => true,
        'tab'     => 'content',
        'label'   => esc_html__( 'Width', 'bricks' ),
        'type'    => 'number',
        'units'    => true,
        'css'     => [
          [
            'property' => 'width',
            'selector' => '.bc-expander-container',
          ],
        ],
        'placeholder'    => '600px',
        'group'    => 'expandersettings'
    ];
    $this->controls['expanderborder'] = [
        'inline' => true,
        'tab'     => 'content',
        'label'   => esc_html__( 'Border', 'bricks' ),
        'type'    => 'border',
        'css'     => [
          [
            'property' => 'border',
            'selector' => '.bc-expander-container',
          ],
        ],
        'group'    => 'expandersettings'
    ];
    $this->controls['expanderbackground'] = [
        'inline' => true,
        'tab'     => 'content',
        'label'   => esc_html__( 'Background', 'bricks' ),
        'type'    => 'background',
        'css'     => [
          [
            'property' => 'background',
            'selector' => '.bc-expander-container',
          ],
        ],
        'group'    => 'expandersettings'
    ];

    /*Label*/
    $this->controls['labeldirection'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Direction', 'bricks' ),
        'type'    => 'direction',
        'css'     => [
          [
            'property' => 'flex-direction',
            'selector' => '.bc-expander-question',
          ],
        ],
        'group'    => 'labelsettings',
    ];
    $this->controls['labeljustify'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Justify content', 'bricks' ),
        'type'    => 'justify-content',
        'css'     => [
          [
            'property' => 'justify-content',
            'selector' => '.bc-expander-question',
          ],
        ],
        'group'    => 'labelsettings'
    ];
    $this->controls['labelalign'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Align items', 'bricks' ),
        'type'    => 'align-items',
        'css'     => [
          [
            'property' => 'align-items',
            'selector' => '.bc-expander-question',
          ],
        ],
        'group'    => 'labelsettings'
    ];
    $this->controls['labelpadding'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Padding', 'bricks' ),
        'type'    => 'dimensions',
        'css'     => [
          [
            'property' => 'padding',
            'selector' => '.bc-expander-question',
          ],
        ],
        'group'    => 'labelsettings'
    ];
    $this->controls['labeltypography'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Typography', 'bricks' ),
        'type'    => 'typography',
        'css'     => [
          [
            'property' => 'typography',
            'selector' => '.bc-expander-question-heading',
          ],
        ],
        'group'    => 'labelsettings'
    ];
    $this->controls['labelicontypography'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Icon Typography', 'bricks' ),
        'type'    => 'typography',
        'css'     => [
          [
            'property' => 'typography',
            'selector' => '.bc-expander-question .bc-expander-question-icon',
          ],
        ],
        'group'    => 'labelsettings'
    ];
    $this->controls['labelrotation'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Icon Rotation', 'bricks' ),
        'type'    => 'number',
        'unit'    => 'deg',
        'css'     => [
          [
            'property' => '--rotate-degree',
            'selector' => '.bc-expander-question-icon',
          ],
        ],
        'group'    => 'labelsettings',
        'placeholder'    => '180deg'
    ];
    $this->controls['labelicontransitionduration'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Icon Transition Duration', 'bricks' ),
        'type'    => 'number',
        'unit'    => 's',
        'css'     => [
          [
            'property' => '--icon-transition-duration',
            'selector' => '.bc-expander-question-icon',
          ],
        ],
        'group'    => 'labelsettings',
        'placeholder'    => '0.2s'
    ];

    /*Content*/
    $this->controls['contenttypography'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Typography', 'bricks' ),
        'type'    => 'typography',
        'css'     => [
          [
            'property' => 'typography',
            'selector' => '.bc-expander-answer',
          ],
        ],
        'group'    => 'contentsettings'
    ];
    $this->controls['contentpadding'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Padding', 'bricks' ),
        'type'    => 'dimensions',
        'css'     => [
          [
            'property' => 'padding',
            'selector' => '.bc-expander-answer',
          ],
        ],
        'group'    => 'contentsettings'
    ];
    $this->controls['contenttransitionduration'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Transition Duration', 'bricks' ),
        'type'    => 'number',
        'unit'    => 's',
        'css'     => [
          [
            'property' => 'transition',
            'selector' => '.bc-expander-answercont',
          ],
        ],
        'group'    => 'contentsettings',
        'placeholder'    => '0.3s'
    ];
  }

  public function get_nestable_item() {
		return [
			'name'     => 'block',
			'label'    => esc_html__( 'Individual Expander', 'bricks' ),
            'settings' => [
                '_hidden' => [
                '_cssClasses' => 'bc-expander-container',
                ],
            ],
			'children' => [
          [
          'name'     => 'block',
					'label'    => esc_html__( 'Label Wrapper', 'bricks' ),
					'settings' => [
						'_hidden'  => [
							'_cssClasses' => 'bc-expander-question',
						],
					],
                    'children' => [
                        [
                            'name'     => 'heading',
                            'label'    => esc_html__( 'Label Heading', 'bricks' ),
                            'settings' => [
                                'text' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.', 'bricks' ),
                                'tag'  => 'h3',
                                '_hidden' => [
                                    '_cssClasses' => 'bc-expander-question-heading',
                                ],
                            ],
                        ],
                        [
                            'name'     => 'icon',
                            'label'    => esc_html__( 'Label Icon', 'bricks' ),
                            'settings' => [
                                'text' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.', 'bricks' ),
                                '_hidden' => [
                                    '_cssClasses' => 'bc-expander-question-icon',
                                ],
                                'icon'     => [
									'icon'    => 'ti-angle-down',
									'library' => 'themify',
								],
                            ],
                        ],
                    ],
                ],
				[
					'name'     => 'block',
					'label'    => esc_html__( 'Content Wrapper', 'bricks' ),
					'settings' => [
						'_hidden'  => [
							'_cssClasses' => 'bc-expander-answercont',
						],
					],
                    'children' => [
                        [
                            'name'     => 'text-basic',
                            'label'    => esc_html__( 'Content', 'bricks' ),
                            'settings' => [
                                'text' => esc_html__( 'Phasellus vestibulum justo laoreet odio vehicula porttitor. Quisque nec volutpat mauris. Donec eu magna nec diam consequat auctor.
                                Cras mollis congue libero, non eleifend sapien faucibus eget. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas', 'bricks' ),
                                'tag'  => 'div',
                                '_hidden' => [
                                    '_cssClasses' => 'bc-expander-answer',
                                ],
                            ],
                        ],
                    ],
				],
			],
		];
}

public function get_nestable_children() {
    $item = $this->get_nestable_item();
    return [$item];
}


public function enqueue_scripts() {
  wp_enqueue_script( 'expander', plugin_dir_url( __FILE__ ) . 'js/bc_expander.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
}

  public function render() {
    $settings = $this->settings;

    $mode = ! empty( $settings['mode'] ) ? $settings['mode'] : 'click';
    $singleopen = ! empty( $settings['singleopen'] ) ? $settings['singleopen'] : 'true';
    $openall = ! empty( $settings['openall'] ) ? $settings['openall'] : 'false';

    $this->set_attribute( '_root', 'class', 'wrapper-bc-expander' );
    $this->set_attribute( '_root', 'data-mode', "$mode" );
    $this->set_attribute( '_root', 'data-singleopen', "$singleopen" );
    $this->set_attribute( '_root', 'data-openall', "$openall" );

    $output = "<div {$this->render_attributes( '_root' )}>";
    $output .= Frontend::render_children( $this );
    $output .= '</div>';

	echo $output;
  }
}