<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Expanding_Menu extends \Bricks\Element {
  public $category     = 'Brickscore - Menus';
  public $name         = 'expandingmenu';
  public $icon         = 'ti-menu-alt';
  public $scripts      = ['expanding_menu'];
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'Expanding Menu', 'bricks' );
  }

  public function set_controls() {    
    $this->controls['expandingtype'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Type', 'bricks' ),
        'type'        => 'select',
        'options'     => [
          'fromTopLeft' => 'From Top Left',
          'fromTopRight' => 'From Top Right',
          'fromBottomLeft' => 'From Bottom Left',
          'fromBottomRight' => 'From Bottom Right',
        ],
        'inline'      => true,
        'placeholder' => 'From Top Left',
        'default' => 'fromTopLeft',
    ];
    $this->controls['expandingduration'] = [
        'label'       => esc_html__( 'Duration', 'bricks' ),
        'type'        => 'number',
        'unit'      => 's',
        'inline'      => true,
        'placeholder' => '.4s',
    ];
    $this->controls['expandingeasing'] = [
        'label'       => esc_html__( 'Easing', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'placeholder' => 'power1',
    ];
    $this->controls['enablefade'] = [
        'label' => esc_html__( 'Enable fade', 'bricks' ),
        'type' => 'checkbox',
        'inline' => true,
        'small' => true,
        'default' => true,
    ];

    $this->controls['separator'] = [
        'description' => sprintf(html_entity_decode(esc_html__( '<br>All elements with this Custom Toggle className will toggle the Menu alongside all its Core Burgers.', 'bricks' ))),
        'type'       => 'separator',
    ];
    $this->controls['customtoggle'] = [
        'label'       => esc_html__( 'Custom Toggle', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'placeholder' => '.bc-core-burguer',
    ];

    $this->controls['contentseparator'] = [
        'label'       => esc_html__( 'Content Style', 'bricks' ),
        'description' => sprintf(html_entity_decode(esc_html__( 'Edit Expanding Content styles at its element or directly from here.', 'bricks' ))),
        'type'       => 'separator',
    ];
    $this->controls['margin'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Margin', 'bricks' ),
        'type'  => 'spacing',
        'units' => true,
        'css'     => [
          [
              'property' => 'margin',
              'selector' => '.bc-expanding-menu__expanding',
          ],
        ],
    ];
    $this->controls['padding'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Padding', 'bricks' ),
        'type'  => 'spacing',
        'units' => true,
        'css'     => [
          [
              'property' => 'padding',
              'selector' => '.bc-expanding-menu__expanding',
          ],
        ],
    ];
    $this->controls['width'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Width', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline' => true,
        'css'     => [
          [
              'property' => 'width',
              'selector' => '.bc-expanding-menu__expanding',
          ],
        ],
        'placeholder' => 'fit-content',
    ];
    $this->controls['height'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Height', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline' => true,
        'css'     => [
          [
              'property' => 'height',
              'selector' => '.bc-expanding-menu__expanding',
          ],
        ],
        'placeholder' => 'fit-content',
    ];
    $this->controls['background'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Background', 'bricks' ),
        'type'  => 'background',
        'units' => true,
        'css'     => [
          [
              'property' => 'background',
              'selector' => '.bc-expanding-menu__expanding',
          ],
        ],
    ];
    $this->controls['border'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Border', 'bricks' ),
        'type'  => 'border',
        'units' => true,
        'css'     => [
          [
              'property' => 'border',
              'selector' => '.bc-expanding-menu__expanding',
          ],
        ],
    ];
  }
  
/*Render children*/
public function get_nestable_children() {
return [
    [
      'name'     => 'coreburguer',
      'label'    => esc_html__( 'Core Burguer', 'bricks' ),
      'settings' => [
        '_hidden' => [
            '_cssClasses' => 'bc-core-burguer--expanding-menu',
        ],
      ],
    ],

    [
        'name'     => 'block',
        'label'    => esc_html__( 'Expanding Content', 'bricks' ),
        'settings' => [
          '_hidden'  => [
              '_cssClasses' => 'bc-expanding-menu__expanding',
          ],
        ],
        'children' => [
            [
                'name'     => 'swap-hover',
            ],
            [
                'name'     => 'swap-hover',
            ],
            [
                'name'     => 'swap-hover',
            ],
        ],

    ]
];
}

  public function enqueue_scripts() {
    wp_enqueue_script( 'expanding-menu-js', plugin_dir_url( __FILE__ ) . 'js/bc_expanding_menu.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $expandingtype = ! empty( $settings['expandingtype'] ) ? $settings['expandingtype'] : 'fromTopLeft';
    $expandingduration = ! empty( $settings['expandingduration'] ) ? $settings['expandingduration'] : '0.4s';
    $expandingeasing = ! empty( $settings['expandingeasing'] ) ? $settings['expandingeasing'] : 'power1';
    $enablefade = ! empty( $settings['enablefade'] ) ? $settings['enablefade'] : 0;
    $customtoggle = ! empty( $settings['customtoggle'] ) ? $settings['customtoggle'] : '';

    $this->set_attribute( '_root', 'class', 'bc-core-menu' );
    $this->set_attribute( '_root', 'class', 'bc-expanding-menu' );
    $this->set_attribute( '_root', 'data-duration', $expandingduration );
    $this->set_attribute( '_root', 'data-easing', $expandingeasing );
    $this->set_attribute( '_root', 'data-fade', $enablefade );
    $this->set_attribute( '_root', 'data-customtoggle', $customtoggle );

    if($expandingtype === 'fromTopLeft'){
        $this->set_attribute( '_root', 'data-type', 'bc-expanding-menu--fromtopleft' );
    }else if($expandingtype === 'fromTopRight'){
        $this->set_attribute( '_root', 'data-type', 'bc-expanding-menu--fromtopright' );
    }else if($expandingtype === 'fromBottomLeft'){
        $this->set_attribute( '_root', 'data-type', 'bc-expanding-menu--frombottomleft' );
    }else if($expandingtype === 'fromBottomRight'){
        $this->set_attribute( '_root', 'data-type', 'bc-expanding-menu--frombottomright' );
    }

    $output = "<div {$this->render_attributes( '_root' )}>";
    $output .= Frontend::render_children( $this );
    $output .= '</div>';

    echo $output;
  }
}