<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Glowing_Button extends \Bricks\Element {
  public $category     = 'Brickscore - Buttons';
  public $name         = 'glowingbutton';
  public $icon         = 'fa-solid fa-square-minus';
  public $scripts      = ['glowing_button'];

  public function get_label() {
    return esc_html__( 'Glowing Button', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['spark'] = [
      'title' => esc_html__( 'Spark', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Glowing Button', 'bricks' ),
        'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['link'] = [
        'tab'   => 'content',
        'label' => esc_html__( 'Link to', 'bricks' ),
        'type'  => 'link',
    ];
    $this->controls['padding'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Padding', 'bricks' ),
      'type'        => 'spacing',
      'css'     => [
          [
            'property' => 'padding',
            'selector' => '.bc-glowing-button__background',
          ],
      ],
      'placeholder' => [
        'top' => 20,
        'right' => 40,
        'bottom' => 20,
        'left' => 40,
      ],
  ];
    $this->controls['textcolor'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Color', 'bricks' ),
      'type'        => 'color',
      'css'     => [
          [
            'property' => '--color',
            'selector' => '.bc-glowing-button__title',
          ],
      ],
  ];
    $this->controls['typography'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Typography', 'bricks' ),
        'type'        => 'typography',
        'css'     => [
            [
              'property' => 'typography',
              'selector' => '.bc-glowing-button__title',
            ],
        ],
    ];
    $this->controls['background'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Background', 'bricks' ),
        'type'        => 'background',
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-glowing-button__background',
            ],
        ],
    ];
    $this->controls['borderradius'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Border radius', 'bricks' ),
      'type'        => 'border',
      'css'     => [
          [
            'property' => '--border-radius',
            'selector' => '&, .bc-glowing-button__background',
          ],
      ],
      'exclude' => [
        'width',
        'style',
        'color',
      ],
    ];
    $this->controls['border'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Border', 'bricks' ),
      'type'        => 'border',
      'css'     => [
          [
            'property' => 'border',
            'selector' => '',
          ],
      ],
      'exclude' => [
        'radius',
      ],
    ];
    $this->controls['sparkdimensions'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Dimensions', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline'        => true,
        'small'        => true,
        'css'     => [
            [
              'property' => '--dimensions',
              'selector' => '',
            ],
        ],
        'placeholder' => '1px',
        'group' => 'spark',
    ];
    $this->controls['sparkduration'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Animation duration', 'bricks' ),
        'type' => 'number',
        'unit' => 's',
        'inline'        => true,
        'small'        => true,
        'css'     => [
            [
              'property' => '--animation-duration',
              'selector' => '.bc-glowing-button__border-gradient',
            ],
        ],
        'placeholder' => '3s',
        'group' => 'spark',
    ];
    $this->controls['sparkfirstcolor'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Color', 'bricks' ),
        'type'        => 'color',
        'css'     => [
            [
              'property' => '--first-color',
              'selector' => '.bc-glowing-button__border-gradient',
            ],
        ],
        'group' => 'spark',
    ];
    $this->controls['sparksecondcolor'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Path color', 'bricks' ),
        'type'        => 'color',
        'css'     => [
            [
              'property' => '--second-color',
              'selector' => '.bc-glowing-button__border-gradient',
            ],
        ],
        'group' => 'spark',
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'bcglowingbutton', plugin_dir_url( __FILE__ ) . 'js/bc_glowing_button.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';

    if ( ! empty( $settings['link'] ) ) {
        $this->set_link_attributes( '_root', $settings['link'] );
    }

    $this->set_attribute( '_root', 'class', 'bc-glowing-button' );

    $output = "<a {$this->render_attributes( '_root' )}>
    <div class='bc-glowing-button__background'>
        <span class='bc-glowing-button__title'>$inner_title</span>
    </div>
    <div class='bc-glowing-button__border-gradient'></div>
    ";

    $output .= '</a>';

	echo $output;
  }
}



