<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Grained extends \Bricks\Element {
  public $category     = 'Brickscore - Core';
  public $name         = 'grained';
  public $icon         = 'fa-solid fa-square-full';
  public $scripts      = ['grained'];
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'Grainy', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['animation'] = [
        'title' => esc_html__( 'Animation', 'bricks' ),
        'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['width'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Width', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline' => true,
        'css' => [
          [
            'property' => 'width',
            'selector' => ' ',
          ]
        ],
        'placeholder' => '100%',
    ];
    $this->controls['height'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Height', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline' => true,
        'css' => [
          [
            'property' => 'height',
            'selector' => '.bc-grained__element',
          ]
        ],
        'placeholder' => '500px',
    ];
    $this->controls['background'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Background', 'bricks' ),
        'type' => 'background',
        'inline' => true,
        'css' => [
          [
            'property' => 'background',
            'selector' => '.bc-grained__element',
          ]
        ],
    ];
    $this->controls['opacity'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Grain opacity', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'css' => [
          [
            'property' => 'opacity',
            'selector' => '.bc-grained__child',
          ]
        ],
        'placeholder' => '0.05',
    ];
    $this->controls['speed'] = [
        'group'   => 'animation',
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Speed', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '25',
    ];
    $this->controls['grainDimension'] = [
        'group'   => 'animation',
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Grain Dimensions', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '1000',
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'grained', plugin_dir_url( __FILE__ ) . 'js/bc_grained.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $speed = ! empty( $settings['speed'] ) ? $settings['speed'] : 25;
    $grainDimension = ! empty( $settings['grainDimension'] ) ? $settings['grainDimension'] : '1000';

    $this->set_attribute( '_root', 'class', "bc-grained");
    $this->set_attribute( 'inner_data', 'data-speed', "$speed");
    $this->set_attribute( 'inner_data', 'data-grainDimension', "$grainDimension");

    $output = "<div {$this->render_attributes( '_root' )}>";

    $output .= "<div role='main' class='bc-grained__element bc-grained__to-hide' {$this->render_attributes( 'inner_data' )}>
    <canvas id='bc-noise' class='bc-grained__child'></canvas>";

    // Render children elements (= individual items)
    $output .= Frontend::render_children( $this );

    $output .= "</div>";

    $output .= '</div>';

	echo $output;
  }
}