<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Highlight_Hover extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'highlight-hover';
  public $icon         = 'ti-text';
  public $tag      = 'h3';
  public $css_selector = '';
  public $scripts      = ['highlight_hover'];

  public function get_label() {
    return esc_html__( 'Highlight Hover', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['separatorgroup'] = [
      'title' => esc_html__( 'Highlight', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Highlight Hover', 'bricks' ),
        'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['tag'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'HTML tag', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'h1' => 'h1',
            'h2' => 'h2',
            'h3' => 'h3',
            'h4' => 'h4',
            'h5' => 'h5',
            'h6' => 'h6',
            'p' => 'p',
            'span' => 'span',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'h3',
        'default'     => 'h3',
    ];
    $this->controls['link'] = [
      'tab'   => 'content',
      'label' => esc_html__( 'Link to', 'bricks' ),
      'type'  => 'link',
   ];
    $this->controls['titleTypography'] = [
      'tab'     => 'content',
      'label'   => esc_html__( 'Title typography', 'bricks' ),
      'type'    => 'typography',
			'css'     => [
        [
          'property' => 'typography',
          'selector' => '.bc-highlight-title__element',
        ],
      ],
    ];
    $this->controls['type'] = [
        'group'			=> 'separatorgroup',
        'tab'         => 'content',
        'label'       => esc_html__( 'Type', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'Bottom to Full' => 'Bottom to Full',
            'Full to Bottom' => 'Full to Bottom',
            'Left to Full' => 'Left to Full',
            'Full to Left' => 'Full to Left',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'Bottom to Full',
    ];
    $this->controls['height'] = [
        'group'			=> 'separatorgroup',
      'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Thickness', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'css'     => [
          [
            'property' => '--height',
            'selector' => '.bc-highlight-title__element',
          ],
        ],
        'inline' => true,
        'placeholder' => '7px',
    ];
    $this->controls['duration'] = [
        'group'			=> 'separatorgroup',
        'hasDynamicData' => false,
          'tab' => 'content',
          'label' => esc_html__( 'Duration', 'bricks' ),
          'type'  => 'number',
          'unit' => 's',
          'css'     => [
            [
              'property' => '--duration',
              'selector' => '.bc-highlight-title__element',
            ],
          ],
          'inline' => true,
          'placeholder' => '0.3s',
      ];
    $this->controls['background'] = [
        'group'			=> 'separatorgroup',
        'tab'     => 'content',
        'label'   => esc_html__( 'Background', 'bricks' ),
        'type'    => 'color',
        'css'     => [
          [
            'property' => '--after-background',
            'selector' => '.bc-highlight-title__element',
          ],
        ],
    ];
    $this->controls['ease'] = [
      'group'			=> 'separatorgroup',
      'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Ease', 'bricks' ),
        'type'  => 'text',
        'inline' => true,
        'css'     => [
          [
            'property' => '--ease',
            'selector' => '.bc-highlight-title__element',
          ],
        ],
        'placeholder' => 'cubic-bezier(0.16, 1, 0.3, 1)',
    ];
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $type    = ! empty( $settings['type'] ) ? $settings['type'] : 'Bottom to Full';

		if ( ! empty( $settings['link'] ) ) {
			$this->set_link_attributes( '_root', $settings['link'] );
		}


    $this->set_attribute( '_root', 'class', 'bc-highlight-title' );

    $output = "<a {$this->render_attributes( '_root' )}>";

    if ( $inner_title ) {
      $this->set_attribute( 'inner_title', 'class', 'bc-highlight-title__element' );
      if ($type === 'Bottom to Full') {
        $this->set_attribute( 'inner_title', 'class', 'bc-highlight-title__bottom-to-full' );
      }
      if ($type === 'Full to Bottom') {
        $this->set_attribute( 'inner_title', 'class', 'bc-highlight-title__full-to-bottom' );
      }
      if ($type === 'Left to Full') {
        $this->set_attribute( 'inner_title', 'class', 'bc-highlight-title__left-to-full' );
      }
      if ($type === 'Full to Left') {
        $this->set_attribute( 'inner_title', 'class', 'bc-highlight-title__full-to-left' );
      }

      $output .=
      "<{$this->tag} {$this->render_attributes( 'inner_title' )}>$inner_title</{$this->tag}>";
    }
    $output .= '</a>';

	echo $output;
  }
}

