<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Image_Hotspots extends Element {
  public $category     = 'Brickscore - Core';
  public $name         = 'imagehotspots';
  public $icon         = 'ti-notepad';
  public $nestable     = true;

public function get_label() {
    return esc_html__( 'Image Hotspots', 'bricks' );
}

public function set_control_groups() {

}

public function set_controls() {
  $this->controls['image'] = [
    'hasDynamicData' => true,
    'tab' => 'content',
    'label' => esc_html__( 'Image', 'bricks' ),
    'type' => 'image',
  ];
  $this->controls['alt'] = [
    'hasDynamicData' => false,
    'tab' => 'content',
    'label' => esc_html__( 'Custom alt text', 'bricks' ),
    'type' => 'text',
    'inline' => true,
  ];
  $this->controls['separator'] = [
    'label'      => esc_html__( 'Hotspots', 'bricks' ),
    'type'       => 'separator',
];
  $this->controls['_children'] = [
    'type'          => 'repeater',
    'titleProperty' => 'label',
    'items'         => 'children',
  ];
}

public function get_nestable_item() {
  return [
    'name'     => 'imagehotspot',
    'label'    => esc_html__( 'Hotspot', 'bricks' ),
    'children' => [
      [
        'name'     => 'heading',
        'label'    => esc_html__( 'Heading', 'bricks' ),
        'settings' => [
            'text' => esc_html__( 'Hotspot', 'bricks' ),
            'tag'  => 'span',
        ],
      ],

      [
        'name'     => 'block',
        'label'    => esc_html__( 'Tooltip', 'bricks' ),
        'settings' => [
            '_hidden' => [
              '_cssClasses' => 'bc-image-hotspots__tooltip',
          ],
        ],
        'children' => [
          [
            'name'     => 'heading',
            'label'    => esc_html__( 'Heading', 'bricks' ),
            'settings' => [
                'text' => esc_html__( 'Heading', 'bricks' ),
                'tag'  => 'span',
            ],
          ]
        ],
      ],
    ],
  ];
}

public function get_nestable_children() {
  $children = [];

  for ( $i = 0; $i < 1; $i++ ) { /*Cantidad de item a generar*/
      $item = $this->get_nestable_item();

      // Replace {item_index} with $index
      $item       = json_encode( $item );
      $item       = str_replace( '{item_index}', $i + 1, $item );
      $item       = json_decode( $item, true );
      $children[] = $item;
  }

  return $children;
}

public function enqueue_scripts() {
  wp_enqueue_script( 'bc-image-hotspots', plugin_dir_url( __FILE__ ) . 'js/bc_image_hotspots.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
}

public function render() {
  $settings = $this->settings;

  if (isset($settings['image'])) {
    $last_image = $settings['image']['url'];

    $image_dimensions = getimagesize($last_image);
    $width = $image_dimensions[0];
    $height = $image_dimensions[1];
  }else{
    $last_image = 'https://images.pexels.com/photos/45246/green-tree-python-python-tree-python-green-45246.jpeg?auto=compress&cs=tinysrgb&w=600';
    $width = null;
    $height = null;
  }
  $alt = !empty($settings['alt']) ? "alt='{$settings['alt']}'" : '';

  $this->set_attribute( '_root', 'class', 'bc-image-hotspots' );

  $output = "<div {$this->render_attributes( '_root' )}>";
  $output .= "<img class='bc-image-hotspots__img' src='$last_image' width='$width' height='$height' $alt>";
  $output .= Frontend::render_children( $this );
  $output .= '</div>';

  echo $output;
}
}