<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Image_Reveal extends \Bricks\Element {
  public $category     = 'Brickscore - Core';
  public $name         = 'imagereveal';
  public $icon         = 'fa-solid fa-photo-film';
  public $scripts      = ['image_reveal'];

  public function get_label() {
    return esc_html__( 'Image Reveal', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['animation'] = [
        'title' => esc_html__( 'Animation', 'bricks' ),
        'tab'   => 'content',
      ];
  }

  public function set_controls() {
    $this->controls['image'] = [
        'hasDynamicData' => true,
        'tab' => 'content',
        'label' => esc_html__( 'Image', 'bricks' ),
        'type' => 'image',
    ];
    $this->controls['alt'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Custom alt text', 'bricks' ),
      'type' => 'text',
      'inline' => true,
  ];
  $this->controls['width'] = [
    'hasDynamicData' => false,
    'tab' => 'content',
    'label' => esc_html__( 'Width', 'bricks' ),
    'type'  => 'number',
    'units' => true,
    'inline' => true,
    'css' => [
      [
        'property' => 'width',
        'selector' => '', 
      ]
    ],
    'placeholder' => 'auto',
];
    $this->controls['direction'] = [
        'tab'         => 'content',
        'group' => 'animation',
        'label'       => esc_html__( 'Direction', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'left' => 'left',
            'right' => 'right',
            'bottom' => 'bottom',
            'top' => 'top',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'left',
    ];
    $this->controls['scale'] = [
        'hasDynamicData' => false,
        'group' => 'animation',
        'tab' => 'content',
        'label' => esc_html__( 'Scale', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'css' => [
          [
            'property' => '--scale',
            'selector' => '.bc-img-reveal__element', 
          ]
        ],
        'placeholder' => '1.3',
    ];
    $this->controls['duration'] = [
        'hasDynamicData' => false,
        'group' => 'animation',
        'tab' => 'content',
        'label' => esc_html__( 'Duration', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '1.5',
    ];
    $this->controls['ease'] = [
        'hasDynamicData' => false,
        'group' => 'animation',
        'tab' => 'content',
        'label' => esc_html__( 'Easing', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'Sine.easeOut',
    ];

    $this->controls['scrolltrigger'] = [
      'group'   => 'animation',
      'label'      => esc_html__( 'SrollTrigger', 'bricks' ),
      'type'       => 'separator',
      'description' => sprintf(esc_html__( 'Scrolltrigger %s', 'bricks' ), '<a href="https://greensock.com/docs/v3/Plugins/ScrollTrigger" target="_blank">documentation</a>'),
    ];

    $this->controls['trigger'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Trigger', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'this',
    ];

    $this->controls['toggleActions'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'toggleActions', 'bricks' ),
      'type' => 'text',
      'group'   => 'animation',
      'placeholder' => 'play none none none',
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'imagereveal', plugin_dir_url( __FILE__ ) . 'js/bc_image_reveal.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;

    if (isset($settings['image'])) {
      $last_image = $settings['image']['url'];

      $image_dimensions = getimagesize($last_image);
      $width = $image_dimensions[0];
      $height = $image_dimensions[1];
    }else{
      $last_image = 'https://images.pexels.com/photos/17050728/pexels-photo-17050728/free-photo-of-madera-carretera-paisaje-agua.jpeg?auto=compress&cs=tinysrgb&w=1260&h=750&dpr=1';
      $width = null;
      $height = null;
    }

    $alt = !empty($settings['alt']) ? "alt='{$settings['alt']}'" : '';
    $direction    = ! empty( $settings['direction'] ) ? $settings['direction'] : 'left';
    $duration = ! empty( $settings['duration'] ) ? $settings['duration'] : 1.5;
    $ease = ! empty( $settings['ease'] ) ? $settings['ease'] : "Sine.easeOut";
    $trigger = ! empty( $settings['trigger'] ) ? $settings['trigger'] : 'this';
    $toggleActions = ! empty( $settings['toggleActions'] ) ? $settings['toggleActions'] : 'play none none none';

    $this->set_attribute( '_image', 'data-direction', "$direction" );
    $this->set_attribute( '_image', 'data-duration', "$duration");
    $this->set_attribute( '_image', 'data-ease', "$ease");
    $this->set_attribute( '_image', 'data-trigger', "$trigger");
    $this->set_attribute( '_image', 'data-toggleActions', "$toggleActions");

    $this->set_attribute( '_root', 'class', 'bc-img-reveal' );

    $output = "<div {$this->render_attributes( '_root' )}>

        <div class='bc-img-reveal__element' {$this->render_attributes( '_image' )}>
            <img class='bc-img-reveal__img' src='$last_image' width='$width' height='$height' $alt>
        </div>";

    $output .= '</div>';

	echo $output;
  }
}