<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Layerbutton extends \Bricks\Element {
  public $category     = 'Brickscore - Buttons';
  public $name         = 'layerbutton';
  public $icon         = 'fa-solid fa-square-minus';
  public $scripts      = ['layerbutton'];

  public function get_label() {
    return esc_html__( 'Layer Button', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['firstlayer'] = [
      'title' => esc_html__( 'First layer', 'bricks' ),
      'tab'   => 'content',
    ];
    $this->control_groups['secondlayer'] = [
      'title' => esc_html__( 'Second layer', 'bricks' ),
      'tab'   => 'content',
    ];
    $this->control_groups['thirdlayer'] = [
      'title' => esc_html__( 'Third layer', 'bricks' ),
      'tab'   => 'content',
    ];
    $this->control_groups['fourthlayer'] = [
      'title' => esc_html__( 'Fourth layer', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    /*ORIGINAL LAYER*/
    $this->controls['inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Original layer', 'bricks' ),
        'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['link'] = [
        'tab'   => 'content',
        'label' => esc_html__( 'Link to', 'bricks' ),
        'type'  => 'link',
    ];
    $this->controls['whitespace'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'White space', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'wrap' => 'wrap',
          'nowrap' => 'nowrap',
      ],
      'inline'      => true,
      'css'     => [
          [
            'property' => 'white-space',
            'selector' => '',
          ],
        ],
      'placeholder'        => 'wrap',
  ];
    $this->controls['typography'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Typography', 'bricks' ),
        'type'        => 'typography',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'typography',
              'selector' => '.bc-layer-button__original-layer',
            ],
          ],
    ];
    $this->controls['buttonbackground'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Button background', 'bricks' ),
        'type'        => 'background',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-layer-button__original-layer',
            ],
          ],
    ];
    $this->controls['buttonborder'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Button border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '.bc-layer-button__original-layer',
            ],
          ],
    ];
    $this->controls['padding'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Padding', 'bricks' ),
        'type'        => 'dimensions',
        'css'     => [
            [
              'property' => 'padding',
              'selector' => '.bc-layer-button__original-layer',
            ],
          ],
          'placeholder' => [
            'top' => 20,
            'right' => 40,
            'bottom' => 20,
            'left' => 40,
          ],
    ];
    $this->controls['originallayerzindex'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'zIndex', 'bricks' ),
      'type' => 'number',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'z-index',
            'selector' => '.bc-layer-button__original-layer',
          ],
        ],
  ];
  $this->controls['originallayertranslate3dpxto'] = [
    'tab'         => 'content',
    'label'       => esc_html__( '3D Translate to', 'bricks' ),
    'type'  => 'number',
    'units' => true,
    'inline'      => true,
    'css'     => [
        [
          'property' => '--translate3dpxto',
          'selector' => '.bc-layer-button__original-layer',
        ],
      ],
    'placeholder'    => esc_html__( '0px', 'bricks' ),
  ];
    $this->controls['originallayerhovercolor'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Color on hover', 'bricks' ),
      'type'        => 'color',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--color',
            'selector' => '.bc-layer-button__original-layer',
          ],
        ],
    ];
    $this->controls['originallayerhoverbackground'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Background on hover', 'bricks' ),
      'type'        => 'color',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--background',
            'selector' => '.bc-layer-button__original-layer',
          ],
        ],
    ];
    $this->controls['originallayertransitionduration'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Transition duration', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'transition-duration',
            'selector' => '.bc-layer-button__original-layer',
          ],
        ],
      'placeholder'    => esc_html__( '0.3s', 'bricks' ),
    ];
    $this->controls['originallayerzindexonhover'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'zIndex on hover', 'bricks' ),
        'type' => 'number',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--z-index',
              'selector' => '.bc-layer-button__original-layer',
            ],
          ],
        'placeholder' => '1',
    ];

    /*FIRST LAYER*/
    $this->controls['firstlayerremove'] = [
      'group'   => 'firstlayer',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Remove layer', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => false,
  ];
    $this->controls['firstlayertwidth'] = [
      'group'   => 'firstlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Width', 'bricks' ),
      'type'  => 'number',
      'units' => true,
      'inline'      => true,
      'css'     => [
          [
            'property' => 'width',
            'selector' => '.bc-layer-button__first-layer',
          ],
        ],
        'placeholder' => '100%',
    ];
    $this->controls['firstlayertheight'] = [
      'group'   => 'firstlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Height', 'bricks' ),
      'type'  => 'number',
      'units' => true,
      'inline'      => true,
      'css'     => [
          [
            'property' => 'height',
            'selector' => '.bc-layer-button__first-layer',
          ],
        ],
        'placeholder' => '100%',
    ];
    $this->controls['firstlayerinner_title'] = [
      'group'   => 'firstlayer',
      'tab'            => 'content',
      'type'           => 'text',
      'hasDynamicData' => 'text',
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
  $this->controls['firstlayertypography'] = [
    'group'   => 'firstlayer',
    'tab'         => 'content',
    'label'       => esc_html__( 'Typography', 'bricks' ),
    'type'        => 'typography',
    'inline'      => true,
    'css'     => [
        [
          'property' => 'typography',
          'selector' => '.bc-layer-button__first-layer',
        ],
      ],
];
    $this->controls['layerbackground'] = [
      'group'   => 'firstlayer',
        'tab'         => 'content',
        'label'       => esc_html__( 'Layer background', 'bricks' ),
        'type'        => 'background',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-layer-button__first-layer',
            ],
          ],
    ];
    $this->controls['layerborder'] = [
      'group'   => 'firstlayer',
        'tab'         => 'content',
        'label'       => esc_html__( 'Layer border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '.bc-layer-button__first-layer',
            ],
          ],
    ];
    $this->controls['firstlayerpadding'] = [
      'group'   => 'firstlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Padding', 'bricks' ),
      'type'        => 'dimensions',
      'css'     => [
          [
            'property' => 'padding',
            'selector' => '.bc-layer-button__first-layer',
          ],
        ],
        'placeholder' => [
          'top' => 20,
          'right' => 40,
          'bottom' => 20,
          'left' => 40,
        ],
  ];
  $this->controls['firstlayerzindex'] = [
    'group'   => 'firstlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Layer zIndex', 'bricks' ),
      'type' => 'number',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'z-index',
            'selector' => '.bc-layer-button__first-layer',
          ],
        ],
  ];
  $this->controls['translate3dpxfrom'] = [
    'group'   => 'firstlayer',
    'tab'         => 'content',
    'label'       => esc_html__( '3D Translate from', 'bricks' ),
    'type'  => 'number',
    'units' => true,
    'inline'      => true,
    'css'     => [
        [
          'property' => '--translate3dpxfrom',
          'selector' => '.bc-layer-button__first-layer',
        ],
      ],
    'placeholder'    => esc_html__( '-6px', 'bricks' ),
  ];
  $this->controls['translate3dpxto'] = [
    'group'   => 'firstlayer',
    'tab'         => 'content',
    'label'       => esc_html__( '3D Translate to', 'bricks' ),
    'type'  => 'number',
    'units' => true,
    'inline'      => true,
    'css'     => [
        [
          'property' => '--translate3dpxto',
          'selector' => '.bc-layer-button__first-layer',
        ],
      ],
    'placeholder'    => esc_html__( '-6px', 'bricks' ),
  ];
    $this->controls['firstlayerhovercolor'] = [
      'group'   => 'firstlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Color on hover', 'bricks' ),
      'type'        => 'color',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--color',
            'selector' => '.bc-layer-button__first-layer',
          ],
        ],
    ];
    $this->controls['firstlayerhoverbackground'] = [
      'group'   => 'firstlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Background on hover', 'bricks' ),
      'type'        => 'color',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--background',
            'selector' => '.bc-layer-button__first-layer',
          ],
        ],
    ];
    $this->controls['transitionduration'] = [
      'group'   => 'firstlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Transition duration', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'transition-duration',
            'selector' => '.bc-layer-button__first-layer',
          ],
        ],
      'placeholder'    => esc_html__( '0.3s', 'bricks' ),
    ];
    $this->controls['firstlayerzindexonhover'] = [
      'group'   => 'firstlayer',
        'tab'         => 'content',
        'label'       => esc_html__( 'zIndex on hover', 'bricks' ),
        'type' => 'number',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--z-index',
              'selector' => '.bc-layer-button__first-layer',
            ],
          ],
        'placeholder' => '0',
    ];

    /*SECOND LAYER*/
    $this->controls['secondlayerremove'] = [
      'group'   => 'secondlayer',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Remove layer', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => false,
  ];
    $this->controls['secondlayertwidth'] = [
      'group'   => 'secondlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Width', 'bricks' ),
      'type'  => 'number',
      'units' => true,
      'inline'      => true,
      'css'     => [
          [
            'property' => 'width',
            'selector' => '.bc-layer-button__second-layer',
          ],
        ],
        'placeholder' => '100%',
    ];
    $this->controls['secondlayertheight'] = [
      'group'   => 'secondlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Height', 'bricks' ),
      'type'  => 'number',
      'units' => true,
      'inline'      => true,
      'css'     => [
          [
            'property' => 'height',
            'selector' => '.bc-layer-button__second-layer',
          ],
        ],
        'placeholder' => '100%',
    ];
    $this->controls['secondlayerinner_title'] = [
      'group'   => 'secondlayer',
      'tab'            => 'content',
      'type'           => 'text',
      'hasDynamicData' => 'text',
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
  $this->controls['secondlayertypography'] = [
    'group'   => 'secondlayer',
    'tab'         => 'content',
    'label'       => esc_html__( 'Typography', 'bricks' ),
    'type'        => 'typography',
    'inline'      => true,
    'css'     => [
        [
          'property' => 'typography',
          'selector' => '.bc-layer-button__second-layer',
        ],
      ],
];
    $this->controls['secondlayerbackground'] = [
      'group'   => 'secondlayer',
        'tab'         => 'content',
        'label'       => esc_html__( 'Layer background', 'bricks' ),
        'type'        => 'background',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-layer-button__second-layer',
            ],
          ],
    ];
    $this->controls['secondlayerborder'] = [
      'group'   => 'secondlayer',
        'tab'         => 'content',
        'label'       => esc_html__( 'Layer border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '.bc-layer-button__second-layer',
            ],
          ],
    ];
    $this->controls['secondlayerpadding'] = [
      'group'   => 'secondlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Padding', 'bricks' ),
      'type'        => 'dimensions',
      'css'     => [
          [
            'property' => 'padding',
            'selector' => '.bc-layer-button__second-layer',
          ],
        ],
        'placeholder' => [
          'top' => 20,
          'right' => 40,
          'bottom' => 20,
          'left' => 40,
        ],
  ];
  $this->controls['secondlayerzindex'] = [
    'group'   => 'secondlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Layer zIndex', 'bricks' ),
      'type' => 'number',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'z-index',
            'selector' => '.bc-layer-button__second-layer',
          ],
        ],
  ];
  $this->controls['secondlayertranslate3dpxfrom'] = [
    'group'   => 'secondlayer',
    'tab'         => 'content',
    'label'       => esc_html__( '3D Translate from', 'bricks' ),
    'type'  => 'number',
    'units' => true,
    'inline'      => true,
    'css'     => [
        [
          'property' => '--translate3dpxfrom',
          'selector' => '.bc-layer-button__second-layer',
        ],
      ],
    'placeholder'    => esc_html__( '12px', 'bricks' ),
  ];
  $this->controls['secondlayertranslate3dpxto'] = [
    'group'   => 'secondlayer',
    'tab'         => 'content',
    'label'       => esc_html__( '3D Translate to', 'bricks' ),
    'type'  => 'number',
    'units' => true,
    'inline'      => true,
    'css'     => [
        [
          'property' => '--translate3dpxto',
          'selector' => '.bc-layer-button__second-layer',
        ],
      ],
    'placeholder'    => esc_html__( '-6px', 'bricks' ),
  ];
    $this->controls['secondlayerhovercolor'] = [
      'group'   => 'secondlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Color on hover', 'bricks' ),
      'type'        => 'color',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--color',
            'selector' => '.bc-layer-button__second-layer',
          ],
        ],
    ];
    $this->controls['secondlayerhoverbackground'] = [
      'group'   => 'secondlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Background on hover', 'bricks' ),
      'type'        => 'color',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--background',
            'selector' => '.bc-layer-button__second-layer',
          ],
        ],
    ];
    $this->controls['secondlayertransitionduration'] = [
      'group'   => 'secondlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Transition duration', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'transition-duration',
            'selector' => '.bc-layer-button__second-layer',
          ],
        ],
      'placeholder'    => esc_html__( '0.3s', 'bricks' ),
    ];
    $this->controls['secondlayerzindexonhover'] = [
      'group'   => 'secondlayer',
        'tab'         => 'content',
        'label'       => esc_html__( 'zIndex on hover', 'bricks' ),
        'type' => 'number',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--z-index',
              'selector' => '.bc-layer-button__second-layer',
            ],
          ],
        'placeholder' => '-1',
    ];

    /*THIRD LAYER*/
    $this->controls['thirdlayerremove'] = [
      'group'   => 'thirdlayer',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Remove layer', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => false,
  ];
    $this->controls['thirdlayertwidth'] = [
      'group'   => 'thirdlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Width', 'bricks' ),
      'type'  => 'number',
      'units' => true,
      'inline'      => true,
      'css'     => [
          [
            'property' => 'width',
            'selector' => '.bc-layer-button__third-layer',
          ],
        ],
        'placeholder' => '100%',
    ];
    $this->controls['thirdlayertheight'] = [
      'group'   => 'thirdlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Height', 'bricks' ),
      'type'  => 'number',
      'units' => true,
      'inline'      => true,
      'css'     => [
          [
            'property' => 'height',
            'selector' => '.bc-layer-button__third-layer',
          ],
        ],
        'placeholder' => '100%',
    ];
    $this->controls['thirdlayerinner_title'] = [
      'group'   => 'thirdlayer',
      'tab'            => 'content',
      'type'           => 'text',
      'hasDynamicData' => 'text',
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
  $this->controls['thirdlayertypography'] = [
    'group'   => 'thirdlayer',
    'tab'         => 'content',
    'label'       => esc_html__( 'Typography', 'bricks' ),
    'type'        => 'typography',
    'inline'      => true,
    'css'     => [
        [
          'property' => 'typography',
          'selector' => '.bc-layer-button__third-layer',
        ],
      ],
];
    $this->controls['thirdlayerbackground'] = [
      'group'   => 'thirdlayer',
        'tab'         => 'content',
        'label'       => esc_html__( 'Layer background', 'bricks' ),
        'type'        => 'background',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-layer-button__third-layer',
            ],
          ],
    ];
    $this->controls['thirdlayerborder'] = [
      'group'   => 'thirdlayer',
        'tab'         => 'content',
        'label'       => esc_html__( 'Layer border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '.bc-layer-button__third-layer',
            ],
          ],
    ];
    $this->controls['thirdlayerpadding'] = [
      'group'   => 'thirdlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Padding', 'bricks' ),
      'type'        => 'dimensions',
      'css'     => [
          [
            'property' => 'padding',
            'selector' => '.bc-layer-button__third-layer',
          ],
        ],
        'placeholder' => [
          'top' => 20,
          'right' => 40,
          'bottom' => 20,
          'left' => 40,
        ],
  ];
  $this->controls['thirdlayerzindex'] = [
    'group'   => 'thirdlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Layer zIndex', 'bricks' ),
      'type' => 'number',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'z-index',
            'selector' => '.bc-layer-button__third-layer',
          ],
        ],
  ];
  $this->controls['thirdlayertranslate3dpxfrom'] = [
    'group'   => 'thirdlayer',
    'tab'         => 'content',
    'label'       => esc_html__( '3D Translate from', 'bricks' ),
    'type'  => 'number',
    'units' => true,
    'inline'      => true,
    'css'     => [
        [
          'property' => '--translate3dpxfrom',
          'selector' => '.bc-layer-button__third-layer',
        ],
      ],
    'placeholder'    => esc_html__( '18px', 'bricks' ),
  ];
  $this->controls['thirdlayertranslate3dpxto'] = [
    'group'   => 'thirdlayer',
    'tab'         => 'content',
    'label'       => esc_html__( '3D Translate to', 'bricks' ),
    'type'  => 'number',
    'units' => true,
    'inline'      => true,
    'css'     => [
        [
          'property' => '--translate3dpxto',
          'selector' => '.bc-layer-button__third-layer',
        ],
      ],
    'placeholder'    => esc_html__( '-6px', 'bricks' ),
  ];
    $this->controls['thirdlayerhovercolor'] = [
      'group'   => 'thirdlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Color on hover', 'bricks' ),
      'type'        => 'color',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--color',
            'selector' => '.bc-layer-button__third-layer',
          ],
        ],
    ];
    $this->controls['thirdlayerhoverbackground'] = [
      'group'   => 'thirdlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Background on hover', 'bricks' ),
      'type'        => 'color',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--background',
            'selector' => '.bc-layer-button__third-layer',
          ],
        ],
    ];
    $this->controls['thirdlayertransitionduration'] = [
      'group'   => 'thirdlayer',
      'tab'         => 'content',
      'label'       => esc_html__( 'Transition duration', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'transition-duration',
            'selector' => '.bc-layer-button__third-layer',
          ],
        ],
      'placeholder'    => esc_html__( '0.3s', 'bricks' ),
    ];
    $this->controls['thirdlayerzindexonhover'] = [
      'group'   => 'thirdlayer',
        'tab'         => 'content',
        'label'       => esc_html__( 'zIndex on hover', 'bricks' ),
        'type' => 'number',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--z-index',
              'selector' => '.bc-layer-button__third-layer',
            ],
          ],
        'placeholder' => '-2',
    ];

        /*THIRD LAYER*/
        $this->controls['fourthlayerremove'] = [
          'group'   => 'fourthlayer',
          'hasDynamicData' => false,
          'tab' => 'content',
          'label' => esc_html__( 'Remove layer', 'bricks' ),
          'type' => 'checkbox',
          'inline' => true,
          'small' => true,
          'default' => false,
      ];
        $this->controls['fourthlayertwidth'] = [
          'group'   => 'fourthlayer',
          'tab'         => 'content',
          'label'       => esc_html__( 'Width', 'bricks' ),
          'type'  => 'number',
          'units' => true,
          'inline'      => true,
          'css'     => [
              [
                'property' => 'width',
                'selector' => '.bc-layer-button__fourth-layer',
              ],
            ],
            'placeholder' => '100%',
        ];
        $this->controls['fourthlayertheight'] = [
          'group'   => 'fourthlayer',
          'tab'         => 'content',
          'label'       => esc_html__( 'Height', 'bricks' ),
          'type'  => 'number',
          'units' => true,
          'inline'      => true,
          'css'     => [
              [
                'property' => 'height',
                'selector' => '.bc-layer-button__fourth-layer',
              ],
            ],
            'placeholder' => '100%',
        ];
        $this->controls['fourthlayerinner_title'] = [
          'group'   => 'fourthlayer',
          'tab'            => 'content',
          'type'           => 'text',
          'hasDynamicData' => 'text',
          'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
        ];
      $this->controls['fourthlayertypography'] = [
        'group'   => 'fourthlayer',
        'tab'         => 'content',
        'label'       => esc_html__( 'Typography', 'bricks' ),
        'type'        => 'typography',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'typography',
              'selector' => '.bc-layer-button__fourth-layer',
            ],
          ],
    ];
        $this->controls['fourthlayerbackground'] = [
          'group'   => 'fourthlayer',
            'tab'         => 'content',
            'label'       => esc_html__( 'Layer background', 'bricks' ),
            'type'        => 'background',
            'inline'      => true,
            'css'     => [
                [
                  'property' => 'background',
                  'selector' => '.bc-layer-button__fourth-layer',
                ],
              ],
        ];
        $this->controls['fourthlayerborder'] = [
          'group'   => 'fourthlayer',
            'tab'         => 'content',
            'label'       => esc_html__( 'Layer border', 'bricks' ),
            'type'        => 'border',
            'inline'      => true,
            'css'     => [
                [
                  'property' => 'border',
                  'selector' => '.bc-layer-button__fourth-layer',
                ],
              ],
        ];
        $this->controls['fourthlayerpadding'] = [
          'group'   => 'fourthlayer',
          'tab'         => 'content',
          'label'       => esc_html__( 'Padding', 'bricks' ),
          'type'        => 'dimensions',
          'css'     => [
              [
                'property' => 'padding',
                'selector' => '.bc-layer-button__fourth-layer',
              ],
            ],
            'placeholder' => [
              'top' => 20,
              'right' => 40,
              'bottom' => 20,
              'left' => 40,
            ],
      ];
      $this->controls['fourthlayerzindex'] = [
        'group'   => 'fourthlayer',
          'tab'         => 'content',
          'label'       => esc_html__( 'Layer zIndex', 'bricks' ),
          'type' => 'number',
          'inline'      => true,
          'css'     => [
              [
                'property' => 'z-index',
                'selector' => '.bc-layer-button__fourth-layer',
              ],
            ],
      ];
      $this->controls['fourthlayertranslate3dpxfrom'] = [
        'group'   => 'fourthlayer',
        'tab'         => 'content',
        'label'       => esc_html__( '3D Translate from', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => '--translate3dpxfrom',
              'selector' => '.bc-layer-button__fourth-layer',
            ],
          ],
        'placeholder'    => esc_html__( '24px', 'bricks' ),
      ];
      $this->controls['fourthlayertranslate3dpxto'] = [
        'group'   => 'fourthlayer',
        'tab'         => 'content',
        'label'       => esc_html__( '3D Translate to', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => '--translate3dpxto',
              'selector' => '.bc-layer-button__fourth-layer',
            ],
          ],
        'placeholder'    => esc_html__( '-6px', 'bricks' ),
      ];
        $this->controls['fourthlayerhovercolor'] = [
          'group'   => 'fourthlayer',
          'tab'         => 'content',
          'label'       => esc_html__( 'Color on hover', 'bricks' ),
          'type'        => 'color',
          'inline'      => true,
          'css'     => [
              [
                'property' => '--color',
                'selector' => '.bc-layer-button__fourth-layer',
              ],
            ],
        ];
        $this->controls['fourthlayerhoverbackground'] = [
          'group'   => 'fourthlayer',
          'tab'         => 'content',
          'label'       => esc_html__( 'Background on hover', 'bricks' ),
          'type'        => 'color',
          'inline'      => true,
          'css'     => [
              [
                'property' => '--background',
                'selector' => '.bc-layer-button__fourth-layer',
              ],
            ],
        ];
        $this->controls['fourthlayertransitionduration'] = [
          'group'   => 'fourthlayer',
          'tab'         => 'content',
          'label'       => esc_html__( 'Transition duration', 'bricks' ),
          'type' => 'number',
          'unit' => 's',
          'inline'      => true,
          'css'     => [
              [
                'property' => 'transition-duration',
                'selector' => '.bc-layer-button__fourth-layer',
              ],
            ],
          'placeholder'    => esc_html__( '0.3s', 'bricks' ),
        ];
        $this->controls['fourthlayerzindexonhover'] = [
          'group'   => 'fourthlayer',
            'tab'         => 'content',
            'label'       => esc_html__( 'zIndex on hover', 'bricks' ),
            'type' => 'number',
            'inline'      => true,
            'css'     => [
                [
                  'property' => '--z-index',
                  'selector' => '.bc-layer-button__fourth-layer',
                ],
              ],
            'placeholder' => '-3',
        ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'layerbutton', plugin_dir_url( __FILE__ ) . 'js/bc_layer_button.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $firstlayerinner_title    = ! empty( $settings['firstlayerinner_title'] ) ? $settings['firstlayerinner_title'] : '';
    $secondlayerinner_title    = ! empty( $settings['secondlayerinner_title'] ) ? $settings['secondlayerinner_title'] : '';
    $thirdlayerinner_title    = ! empty( $settings['thirdlayerinner_title'] ) ? $settings['thirdlayerinner_title'] : '';
    $fourthlayerinner_title    = ! empty( $settings['fourthlayerinner_title'] ) ? $settings['fourthlayerinner_title'] : '';
    $firstlayerremove = ! empty( $settings['firstlayerremove'] ) ? $settings['firstlayerremove'] : false;
    $secondlayerremove = ! empty( $settings['secondlayerremove'] ) ? $settings['secondlayerremove'] : false;
    $thirdlayerremove = ! empty( $settings['thirdlayerremove'] ) ? $settings['thirdlayerremove'] : false;
    $fourthlayerremove = ! empty( $settings['fourthlayerremove'] ) ? $settings['fourthlayerremove'] : false;

		if ( ! empty( $settings['link'] ) ) {
			$this->set_link_attributes( '_root', $settings['link'] );
		}

    $this->set_attribute( '_root', 'class', 'bc-layer-button' );

    $output = "<a {$this->render_attributes('_root')}>
    <div class='bc-layer-button__original-layer'>$inner_title</div>";

    if (!$firstlayerremove) {
        $output .= "<span class='bc-layer-button__first-layer'>$firstlayerinner_title</span>";
    }
    if (!$secondlayerremove) {
      $output .= "<span class='bc-layer-button__second-layer'>$secondlayerinner_title</span>";
    }
    if (!$thirdlayerremove) {
      $output .= "<span class='bc-layer-button__third-layer'>$thirdlayerinner_title</span>";
    }
    if (!$fourthlayerremove) {
      $output .= "<span class='bc-layer-button__fourth-layer'>$fourthlayerinner_title</span>";
    }

    $output .= "</a>";

	echo $output;
  }
}



