<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Letter_Launcher extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'letter-launcher';
  public $icon         = 'ti-text';
  public $tag      = 'h3';
  public $css_selector = '';
  public $scripts      = ['letter_launcher'];

  public function get_label() {
    return esc_html__( 'Letter Launcher', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['animation'] = [
      'title' => esc_html__( 'Animation', 'bricks' ),
      'tab'   => 'content',
    ];
    $this->control_groups['gradient'] = [
      'title' => esc_html__( 'Gradient', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
      'tab'            => 'content',
      'type'           => 'text',
			'hasDynamicData' => 'text',
      'default'        => esc_html__( 'Letter Launcher', 'bricks' ),
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];

    $this->controls['titleTypography'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Title typography', 'bricks' ),
        'type'    => 'typography',
        'css'     => [
          [
            'property' => 'typography',
            'selector' => '.bc-letter-launcher__span',
          ],
        ],
    ];

    $this->controls['tag'] = [
			'tab'         => 'content',
			'label'       => esc_html__( 'HTML tag', 'bricks' ),
			'type'        => 'select',
			'options'     => [
				'h1' => 'h1',
				'h2' => 'h2',
				'h3' => 'h3',
				'h4' => 'h4',
				'h5' => 'h5',
				'h6' => 'h6',
        'p' => 'p',
        'span' => 'span',
			],
			'clearable'   => false,
			'inline'      => true,
			'placeholder' => 'h3',
			'default'     => 'h3',
		];

    $this->controls['letteraltitude'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Letter altitude', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline' => true,
        'placeholder' => '20px',
    ];

    $this->controls['letterrotation'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Letter rotation', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '-30',
    ];

    $this->controls['duration'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Duration', 'bricks' ),
        'type' => 'number',
        'unit' => 's',
        'inline' => true,
        'placeholder' => '0.3s',
    ];

    $this->controls['staggervar'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Stagger', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '0.05',
    ];

    $this->controls['scrolltrigger'] = [
      'group'   => 'animation',
      'label'      => esc_html__( 'SrollTrigger', 'bricks' ),
      'type'       => 'separator',
      'description' => sprintf(esc_html__( 'Scrolltrigger %s', 'bricks' ), '<a href="https://greensock.com/docs/v3/Plugins/ScrollTrigger" target="_blank">documentation</a>'),
    ];

    $this->controls['trigger'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Trigger', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'this',
    ];

    $this->controls['start'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Start', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'top bottom',
    ];

    $this->controls['end'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'group'   => 'animation',
      'label' => esc_html__( 'End', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 'unset',
  ];

    $this->controls['delay'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Delay', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '0.2',
    ];

    $this->controls['scrub'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Scrub', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'false',
    ];

    $this->controls['toggleActions'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'group'   => 'animation',
      'label' => esc_html__( 'toggleActions', 'bricks' ),
      'type' => 'text',
      'placeholder' => 'play none none none',
    ];

    //Gradient
    $this->controls['titleGradient'] = [
      'group' => 'gradient',
      'tab' => 'content',
      'type' => 'gradient',
      'css' => [
        [
          'property' => 'background-image',
          'selector' => '.bc-letter-launcher__span .char',
        ],
      ],
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'letter_launcher', plugin_dir_url( __FILE__ ) . 'js/bc_letter_launcher.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $start = ! empty( $settings['start'] ) ? $settings['start'] : 'top bottom';
    $end = ! empty( $settings['end'] ) ? $settings['end'] : 'unset';
    $duration = ! empty( $settings['duration'] ) ? $settings['duration'] : 0.3;
    $delay = ! empty( $settings['delay'] ) ? $settings['delay'] : 0.2;
    $staggervar = ! empty( $settings['staggervar'] ) ? $settings['staggervar'] : 0.05;
    $letterrotation = ! empty( $settings['letterrotation'] ) ? $settings['letterrotation'] : -30;
    $letteraltitude = ! empty( $settings['letteraltitude'] ) ? $settings['letteraltitude'] : 20;
    $trigger = ! empty( $settings['trigger'] ) ? $settings['trigger'] : 'this';
    $scrub = ! empty( $settings['scrub'] ) ? $settings['scrub'] : 'false';
    $toggleActions = ! empty( $settings['toggleActions'] ) ? $settings['toggleActions'] : 'play none none none';

    if ( ! $inner_title ) {
      return $this->render_element_placeholder( [
        'icon-class'  => 'ti-paragraph',
        'inner_title'       => esc_html__( 'Please add a title.', 'bricks' ),
				'description' => esc_html__( 'Here goes the element placeholder description (optional).', 'bricks' ),
      ] );
    }

    $this->set_attribute( '_root', 'class', 'bc-letter-launcher' );
    $output = "<div {$this->render_attributes( '_root' )}>";

    if ( $inner_title ) {
      $this->set_attribute( 'inner_title', 'class', 'bc-letter-launcher__span' );
      $this->set_attribute( 'inner_title', 'class', 'bc-letter-launcher__to-hide' );
      $this->set_attribute( 'inner_title', 'data-start', "$start");
      $this->set_attribute( 'inner_title', 'data-end', "$end");
      $this->set_attribute( 'inner_title', 'data-duration', "$duration");
      $this->set_attribute( 'inner_title', 'data-delayvar', "$delay");
      $this->set_attribute( 'inner_title', 'data-staggervar', "$staggervar");
      $this->set_attribute( 'inner_title', 'data-letterrotation', "$letterrotation");
      $this->set_attribute( 'inner_title', 'data-letteraltitude', "$letteraltitude");
      $this->set_attribute( 'inner_title', 'data-trigger', "$trigger");
      $this->set_attribute( 'inner_title', 'data-scrub', "$scrub");
      $this->set_attribute( 'inner_title', 'data-toggleActions', "$toggleActions");


      $output .=
      "<{$this->tag} {$this->render_attributes( 'inner_title' )}>
          $inner_title
      </{$this->tag}>";
    }

    $output .= '</div>';

		echo $output;
  }
}

