<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_BC_Lottie extends \Bricks\Element {
  public $category     = 'Brickscore - Core';
  public $name         = 'bclottie';
  public $icon         = 'fa-solid fa-circle-play';
  public $css_selector = '';
  public $scripts      = ['bclottie'];

  public function get_label() {
    return esc_html__( 'Lottie', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['cursor'] = [
        'title' => esc_html__( 'Cursor', 'bricks' ),
        'tab'   => 'content',
    ];
    $this->control_groups['scroll'] = [
        'title' => esc_html__( 'Scroll', 'bricks' ),
        'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['source'] = [
      'tab'            => 'content',
      'type'           => 'text',
	  'hasDynamicData' => 'text',
      'placeholder'    => esc_html__( 'Source', 'bricks' ),
    ];

    $this->controls['width'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Width', 'bricks' ),
        'type'  => 'number',
        'units' => true,
              'css'     => [
          [
            'property' => 'width',
            'selector' => '',
          ],
        ],
        'placeholder'    => esc_html__( '350px', 'bricks' ),
        'inline' => true,
    ];

    $this->controls['autoplay'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Autoplay', 'bricks' ),
        'type' => 'checkbox',
        'inline' => true,
        'small' => true,
        'default' => true,
    ];

    $this->controls['loop'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Loop', 'bricks' ),
        'type' => 'checkbox',
        'inline' => true,
        'small' => true,
        'default' => true,
    ];

    $this->controls['speed'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Speed', 'bricks' ),
        'type'    => 'text',
        'placeholder'    => esc_html__( '1', 'bricks' ),
        'inline' => true,
    ];

    $this->controls['mode'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Mode', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'cursor' => 'cursor',
            'scroll' => 'scroll',
        ],
        'inline'      => true,
        'placeholder' => 'cursor',
    ];

    $this->controls['cursortype'] = [
        'tab'            => 'content',
        'label'          => esc_html__( 'Cursor Type', 'bricks' ),
        'type'           => 'select',
        'options'        => [
            'hover' => 'hover',
            'click' => 'click',
        ],
        'inline'      => true,
        'placeholder' => 'hover',
        'group' => 'cursor',
    ];

    $this->controls['scrolltype'] = [
        'tab'            => 'content',
        'label'          => esc_html__( 'Scroll Type', 'bricks' ),
        'type'           => 'select',
        'options'        => [
            'seek' => 'seek',
            'play' => 'play',
        ],
        'inline'      => true,
        'placeholder' => 'seek',
        'group' => 'scroll',
    ];

    $this->controls['forceflag'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Force Flag', 'bricks' ),
        'type' => 'checkbox',
        'inline' => true,
        'small' => true,
        'default' => true,
        'group' => 'cursor',
    ];

    $this->controls['startvisibility'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Start Visibility', 'bricks' ),
        'type'    => 'text',
        'placeholder'    => esc_html__( '0', 'bricks' ),
        'inline' => true,
        'group' => 'scroll',
    ];

    $this->controls['endvisibility'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'End Visibility', 'bricks' ),
        'type'    => 'text',
        'placeholder'    => esc_html__( '1', 'bricks' ),
        'inline' => true,
        'group' => 'scroll',
    ];

    $this->controls['startframe'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Start Frame', 'bricks' ),
        'type'    => 'text',
        'placeholder'    => esc_html__( '0', 'bricks' ),
        'inline' => true,
        'group' => 'scroll',
    ];

    $this->controls['endframe'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'End Frame', 'bricks' ),
        'type'    => 'text',
        'placeholder'    => esc_html__( '120', 'bricks' ),
        'inline' => true,
        'group' => 'scroll',
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'bclottie', plugin_dir_url( __FILE__ ) . 'js/bc_lottie.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);

    wp_enqueue_script( 'lottieplayer-js', plugin_dir_url( __FILE__ ) . '../local_assets/bc_lottie-player.min.js', array(), get_option('brickscore_element_version'), false);
    wp_enqueue_script( 'lottieinteractivity-js', plugin_dir_url( __FILE__ ) . '../local_assets/bc_lottie-interactivity.min.js', array(), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $source = ! empty( $settings['source'] ) ? $settings['source'] : 'https://lottie.host/2e337c0e-f196-4645-961f-fdb284b7d865/v8mS898Exa.json';
    $speed = ! empty( $settings['speed'] ) ? $settings['speed'] : 1;

    $hayautoplay = 0;
    $autoplay = ! empty( $settings['autoplay'] ) ? $settings['autoplay'] : false;
    $autoplayaux = 'autoplay';
    if($autoplay == true){
        $autoplayaux = 'autoplay';
    }else{
        $autoplayaux = '';
        $hayautoplay = 1;
    }

    $loop = ! empty( $settings['loop'] ) ? $settings['loop'] : false;
    $loopaux = 'loop';
    if($loop == true){
        $loopaux = 'loop';
    }else{
        $loopaux = '';
    }

    $forceflag = ! empty( $settings['forceflag'] ) ? $settings['forceflag'] : false;
    $forceflagaux = 0;
    if($forceflag == true){
        $forceflagaux = 1;
    }else{
        $forceflagaux = 0;
    }

    $mode = ! empty( $settings['mode'] ) ? $settings['mode'] : 'cursor';

    $cursortype = ! empty( $settings['cursortype'] ) ? $settings['cursortype'] : 'hover';
    $scrolltype = ! empty( $settings['scrolltype'] ) ? $settings['scrolltype'] : 'seek';
    $type = $cursortype . '-' . $scrolltype;

    $startvisibility = ! empty( $settings['startvisibility'] ) ? $settings['startvisibility'] : 0;
    $endvisibility = ! empty( $settings['endvisibility'] ) ? $settings['endvisibility'] : 1;
    $startframe = ! empty( $settings['startframe'] ) ? $settings['startframe'] : 0;
    $endframe = ! empty( $settings['endframe'] ) ? $settings['endframe'] : 120;

    $this->set_attribute( '_root', 'class', "bc-lottie");
    $output = "<div {$this->render_attributes( '_root' )}>";

    $this->set_attribute( 'inner_lottie', 'src', "$source");
    $this->set_attribute( 'inner_lottie', 'speed', "$speed");
    $this->set_attribute( 'inner_lottie', 'data-hayautoplay', "$hayautoplay");
    $this->set_attribute( 'inner_lottie', 'data-mode', "$mode");
    $this->set_attribute( 'inner_lottie', 'data-type', "$type");
    $this->set_attribute( 'inner_lottie', 'data-startvisibility', "$startvisibility");
    $this->set_attribute( 'inner_lottie', 'data-endvisibility', "$endvisibility");
    $this->set_attribute( 'inner_lottie', 'data-startframe', "$startframe");
    $this->set_attribute( 'inner_lottie', 'data-endframe', "$endframe");
    $this->set_attribute( 'inner_lottie', 'data-forceflag', "$forceflagaux");

    $output .=
    "
    <lottie-player $autoplayaux $loopaux class='bc-lottie__element bc-lottie__to-hide' {$this->render_attributes( 'inner_lottie' )}></lottie-player>
    ";

    $output .= '</div>';

	echo $output;
  }
}

