<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Marquee extends Element {
  public $category     = 'Brickscore - Core';
  public $name         = 'marquee';
  public $icon         = 'fa-solid fa-pallet';
  public $scripts      = ['marquee'];
  public $nestable     = true;

public function get_label() {
    return esc_html__( 'Marquee', 'bricks' );
}

public function set_control_groups() {
    $this->control_groups['default'] = [
        'title' => esc_html__( 'Default', 'bricks' ),
        'tab'   => 'content',
    ];
    $this->control_groups['scroller'] = [
        'title' => esc_html__( 'Scroller', 'bricks' ),
        'tab'   => 'content',
    ];
}

public function set_controls() {
    $this->controls['note'] = [
        'tab' => 'content',
        'description' => sprintf(html_entity_decode(esc_html__( 'NOTE: <br>Drag & Drop elements inside the marquee.<br>Elements must have fixed dimensions.<br>Reload if flickering.', 'bricks' )))
    ];
    $this->controls['apply'] = [
        'tab' => 'content',
        'type' => 'apply',
        'reload' => true,
        'label' => esc_html__( 'Reload marquee changes', 'bricks' ),
    ];

    //Default
    $this->controls['width'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'default',
        'label' => esc_html__( 'Gap', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline' => true,
        'css' => [
          [
            'property' => 'width',
            'selector' => '.bc-reel__nestable',
          ]
        ],
        'placeholder' => '1px',
    ];
    $this->controls['rotation'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'default',
        'label' => esc_html__( 'Rotate', 'bricks' ),
        'type'  => 'number',
        'unit' => 'deg',
        'inline' => true,
        'css' => [
          [
            'property' => '--rotate',
            'selector' => '',
          ]
        ],
        'placeholder' => '0deg',
    ];
    $this->controls['speed'] = [
          'hasDynamicData' => false,
          'tab' => 'content',
          'group'   => 'default',
          'label' => esc_html__( 'Speed', 'bricks' ),
          'type' => 'text',
          'inline' => true,
          'placeholder' => '3',
    ];
    $this->controls['defaultloop'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'default',
        'label' => esc_html__( 'Loop', 'bricks' ),
        'type' => 'checkbox',
        'inline' => true,
        'small' => true,
        'default' => true,
    ];
    $this->controls['defaultreverse'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'default',
        'label' => esc_html__( 'Reverse', 'bricks' ),
        'type' => 'checkbox',
        'inline' => true,
        'small' => true,
        'default' => false,
    ];
    $this->controls['pauseonhover'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'default',
        'label' => esc_html__( 'Pause on Hover', 'bricks' ),
        'type' => 'checkbox',
        'inline' => true,
        'small' => true,
        'default' => true,
    ];
    $this->controls['ease'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'default',
        'label' => esc_html__( 'GSAP easing', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'none',
    ];

    //Scroller
    $this->controls['scroller'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'scroller',
        'label' => esc_html__( 'Enable scroller', 'bricks' ),
        'type' => 'checkbox',
        'inline' => true,
        'small' => true,
        'default' => true,
    ];
    $this->controls['bothdirection'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'scroller',
        'label' => esc_html__( 'Both directions', 'bricks' ),
        'type' => 'checkbox',
        'inline' => true,
        'small' => true,
        'default' => false,
        'required' => [ 'scroller', '=', true],
    ];
    $this->controls['scrollerspeed'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'scroller',
        'label' => esc_html__( 'Speed', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '1',
        'required' => [ 'scroller', '=', true],
    ];
    $this->controls['multiplier'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'scroller',
        'label' => esc_html__( 'Multiplier', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '0.5',
        'required' => [ 'scroller', '=', true],
    ];
    $this->controls['treshold'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'scroller',
        'label' => esc_html__( 'Treshold', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '1',
        'required' => [ 'scroller', '=', true],
    ];
    $this->controls['scrollerease'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'scroller',
        'label' => esc_html__( 'GSAP easing', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'expo.out',
        'required' => [ 'scroller', '=', true],
    ];

}

public function get_nestable_item() {
    return [
        'name'     => 'heading',
        'label'    => esc_html__( 'Title', 'bricks' ),
        'settings' => [
          'text' => esc_html__( 'Bricks', 'bricks' ),
          'tag'  => 'span',
          '_cssClasses' => 'bc-reel__example-heading',
        ],
    ];
}

public function get_nestable_children() {
    $children = [];

    for ( $i = 0; $i < 1; $i++ ) { /*Cantidad de item a generar*/
        $item = $this->get_nestable_item();

        // Replace {item_index} with $index
        $item       = json_encode( $item );
        $item       = str_replace( '{item_index}', $i + 1, $item );
        $item       = json_decode( $item, true );
        $children[] = $item;
    }

    return $children;
}


public function enqueue_scripts() {
    wp_enqueue_script( 'marquee', plugin_dir_url( __FILE__ ) . 'js/bc_marquee.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);

    wp_enqueue_script( 'reeller-js', plugin_dir_url( __FILE__ ) . '../local_assets/bc_reeller.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
}

public function render() {
    $settings = $this->settings;
    $speed = ! empty( $settings['speed'] ) ? $settings['speed'] : 3;
    $defaultloop = ! empty( $settings['defaultloop'] ) ? $settings['defaultloop'] : false;
    $defaultreverse = ! empty( $settings['defaultreverse'] ) ? $settings['defaultreverse'] : false;
    $pauseonhover = ! empty( $settings['pauseonhover'] ) ? $settings['pauseonhover'] : false;
    $ease = ! empty( $settings['ease'] ) ? $settings['ease'] : 'none';

    $scroller = ! empty( $settings['scroller'] ) ? $settings['scroller'] : false;
    $bothdirection = ! empty( $settings['bothdirection'] ) ? $settings['bothdirection'] : false;
    $scrollerspeed = ! empty( $settings['scrollerspeed'] ) ? $settings['scrollerspeed'] : 1;
    $multiplier = ! empty( $settings['multiplier'] ) ? $settings['multiplier'] : 0.5;
    $treshold = ! empty( $settings['treshold'] ) ? $settings['treshold'] : 1;
    $scrollerease = ! empty( $settings['scrollerease'] ) ? $settings['scrollerease'] : 'expo.out';


    $this->set_attribute( '_root', 'class', 'bc-reel' );

    $this->set_attribute( 'inner_data', 'class', 'bc-reel__to-hide' );
    $this->set_attribute( 'inner_data', 'class', 'bc-reel__element' );
    $this->set_attribute( 'inner_data', 'data-speed', "$speed");
    $this->set_attribute( 'inner_data', 'data-defaultloop', "$defaultloop");
    $this->set_attribute( 'inner_data', 'data-defaultreverse', "$defaultreverse");
    $this->set_attribute( 'inner_data', 'data-pauseonhover', "$pauseonhover");
    $this->set_attribute( 'inner_data', 'data-ease', "$ease");

    $this->set_attribute( 'inner_data', 'data-scroller', "$scroller");
    $this->set_attribute( 'inner_data', 'data-bothdirection', "$bothdirection");
    $this->set_attribute( 'inner_data', 'data-scrollerspeed', "$scrollerspeed");
    $this->set_attribute( 'inner_data', 'data-multiplier', "$multiplier");
    $this->set_attribute( 'inner_data', 'data-treshold', "$treshold");
    $this->set_attribute( 'inner_data', 'data-scrollerease', "$scrollerease");


    $output = "<div {$this->render_attributes( '_root' )}>";

    $output .= "<div {$this->render_attributes( 'inner_data' )}>";
    $output .= "<div class='bc-reel__wrapper'>";
    $output .= "<div class='bc-reel__item'>";

    $output .= "<div class='bc-reel__nestable'></div>";
    // Render children elements (= individual items)
    $output .= Frontend::render_children( $this );

    $output .= "</div>";
    $output .= "</div>";
    $output .= "</div>";

    $output .= '</div>';

    echo $output;
}
}