<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Marqueebutton extends \Bricks\Element {
  public $category     = 'Brickscore - Buttons';
  public $name         = 'marqueebutton';
  public $icon         = 'fa-solid fa-square-minus';
  public $scripts      = ['marqueebutton'];

  public function get_label() {
    return esc_html__( 'Marquee Button', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['marquee'] = [
      'title' => esc_html__( 'Marquee', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Marquee Button', 'bricks' ),
        'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['link'] = [
        'tab'   => 'content',
        'label' => esc_html__( 'Link to', 'bricks' ),
        'type'  => 'link',
    ];
    $this->controls['whitespace'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'White space', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'wrap' => 'wrap',
          'nowrap' => 'nowrap',
      ],
      'inline'      => true,
      'css'     => [
          [
            'property' => 'white-space',
            'selector' => '',
          ],
        ],
      'placeholder'        => 'wrap',
  ];
    $this->controls['buttontypography'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Typography', 'bricks' ),
        'type'        => 'typography',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'typography',
              'selector' => '',
            ],
          ],
    ];
    $this->controls['buttonbackground'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Background', 'bricks' ),
      'type'        => 'background',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'background',
            'selector' => '',
          ],
        ],
  ];
  $this->controls['buttonborder'] = [
    'tab'         => 'content',
    'label'       => esc_html__( 'Border', 'bricks' ),
    'type'        => 'border',
    'inline'      => true,
    'css'     => [
        [
          'property' => 'border',
          'selector' => '',
        ],
      ],
];
    $this->controls['buttonpadding'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Padding', 'bricks' ),
        'type'        => 'dimensions',
        'css'     => [
            [
              'property' => 'padding',
              'selector' => '',
            ],
          ],
          'placeholder' => [
            'top' => 20,
            'right' => 50,
            'bottom' => 20,
            'left' => 50,
          ],
    ];
    $this->controls['marqueerepeats'] = [
      'group'   => 'marquee',
        'tab'         => 'content',
        'label'       => esc_html__( 'Repeats', 'bricks' ),
        'type'        => 'number',
        'inline'      => true,
        'placeholder'    => esc_html__( '8', 'bricks' ),
    ];
    $this->controls['marqueepadding'] = [
      'group'   => 'marquee',
        'tab'         => 'content',
        'label'       => esc_html__( 'Units Gap', 'bricks' ),
        'type' => 'number',
        'units' => true,
        'css'     => [
            [
              'property' => 'gap',
              'selector' => '.bc-marquee-button__units-wrapper',
            ],
          ],
          'placeholder' => '10px',
    ];
    $this->controls['animationduration'] = [
      'group'   => 'marquee',
        'tab'         => 'content',
        'label'       => esc_html__( 'Animation duration', 'bricks' ),
        'type' => 'number',
        'unit' => 's',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'animation-duration',
              'selector' => '.bc-marquee-button__units-wrapper',
            ],
          ],
        'placeholder'    => esc_html__( '1s', 'bricks' ),
    ];
    $this->controls['marqueetypography'] = [
      'group'   => 'marquee',
        'tab'         => 'content',
        'label'       => esc_html__( 'Typography', 'bricks' ),
        'type'        => 'typography',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'typography',
              'selector' => '.bc-marquee-button__unit',
            ],
          ],
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'marqueebutton', plugin_dir_url( __FILE__ ) . 'js/bc_marquee_button.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $marqueerepeats    = ! empty( $settings['marqueerepeats'] ) ? $settings['marqueerepeats'] : 8;

		if ( ! empty( $settings['link'] ) ) {
			$this->set_link_attributes( '_root', $settings['link'] );
		}


    $this->set_attribute( '_root', 'class', 'bc-marquee-button' );

    $output = "
    <a {$this->render_attributes( '_root' )}>
    <span class='bc-marquee-button__title'>$inner_title</span>
    <div class='bc-marquee-button__marquee' aria-hidden='true'>
    <div class='bc-marquee-button__units-wrapper'>";

    for ($i = 0; $i < $marqueerepeats; $i++) {
        $output .= "<span class='bc-marquee-button__unit'>$inner_title</span>";
    }

    $output .= "
    </div>
    </div>
    </a>
    ";

	echo $output;
  }
}



