<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Maskbutton extends \Bricks\Element {
  public $category     = 'Brickscore - Buttons';
  public $name         = 'maskbutton';
  public $icon         = 'fa-solid fa-square-minus';
  public $scripts      = ['maskbutton'];

  public function get_label() {
    return esc_html__( 'Mask Button', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['mask'] = [
      'title' => esc_html__( 'Mask', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Mask Button', 'bricks' ),
        'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['link'] = [
        'tab'   => 'content',
        'label' => esc_html__( 'Link to', 'bricks' ),
        'type'  => 'link',
    ];
    $this->controls['whitespace'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'White space', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'wrap' => 'wrap',
            'nowrap' => 'nowrap',
        ],
        'inline'      => true,
        'css'     => [
            [
              'property' => 'white-space',
              'selector' => '',
            ],
          ],
        'placeholder' => 'wrap',
    ];
    $this->controls['padding'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Padding', 'bricks' ),
        'type'        => 'dimensions',
        'css'     => [
            [
              'property' => 'padding',
              'selector' => '',
            ],
          ],
          'placeholder' => [
            'top' => 15,
            'right' => 30,
            'bottom' => 15,
            'left' => 30,
          ],
    ];
    $this->controls['background'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Background', 'bricks' ),
        'type'        => 'background',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--bg',
              'selector' => '',
            ],
          ],
    ];
    $this->controls['color'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Color', 'bricks' ),
        'type'        => 'color',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--fg',
              'selector' => '',
            ],
        ],
    ];
    $this->controls['typography'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Typography', 'bricks' ),
        'type'        => 'typography',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'typography',
              'selector' => '',
            ],
        ],
        'exclude' => [
            'color',
        ],
    ];
    $this->controls['border'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '',
            ],
        ],
        'exclude' => [
            'radius',
        ],
    ];
    $this->controls['borderRadius'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Border radius', 'bricks' ),
        'type'        => 'dimensions',
        'css'     => [
            [
              'property' => '--border-radius',
              'selector' => '',
            ],
        ],
        'placeholder' => [
            'top' => 0,
            'right' => 0,
            'bottom' => 0,
            'left' => 0,
        ],
    ];
    $this->controls['widthMask'] = [
        'group'         => 'mask',
        'tab'         => 'content',
        'label'       => esc_html__( 'Width', 'bricks' ),
        'type'        => 'number',
        'units'      => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => 'width',
              'selector' => '.bc-mask-button__back > span',
            ],
        ],
        'placeholder' => '50%',
    ];
    $this->controls['borderRadiusMask'] = [
        'group'         => 'mask',
        'tab'         => 'content',
        'label'       => esc_html__( 'Border radius', 'bricks' ),
        'type'        => 'dimensions',
        'css'     => [
            [
              'property' => '--border-radius2',
              'selector' => '.bc-mask-button__back > span',
            ],
        ],
        'placeholder' => [
            'top' => 100,
            'right' => 100,
            'bottom' => 100,
            'left' => 100,
        ],
    ];
    $this->controls['transitiondurationMask'] = [
        'group'         => 'mask',
        'tab'         => 'content',
        'label'       => esc_html__( 'Transition duration', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'unit'        => 's',
        'css'     => [
            [
              'property' => '--transition-duration',
              'selector' => '',
            ],
        ],
        'placeholder' => '0.5s',
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'maskbutton', plugin_dir_url( __FILE__ ) . 'js/bc_mask_button.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';

    if ( ! empty( $settings['link'] ) ) {
        $this->set_link_attributes( '_root', $settings['link'] );
    }

    $this->set_attribute( '_root', 'class', 'bc-mask-button' );

    $output = "
    <a {$this->render_attributes( '_root' )}>
        $inner_title
        <span class='bc-mask-button__back'>
            <span></span>
        </span>
    </a>
    ";

	echo $output;
  }
}