<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Mask_Hover extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'mask-hover';
  public $icon         = 'ti-layout-media-center';
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'Mask Hover', 'bricks' );
  }

  public function set_controls() {
    $this->controls['note'] = [
        'tab' => 'content',
        'description' => sprintf(html_entity_decode(esc_html__( 'NOTE: <br>Visible content must be placed inside "Content" element. Mask content must be placed at the "Mask content" element. <br>Their styles must also be applied right at them.', 'bricks' )))
    ];
    $this->controls['animationSeparator'] = [
        'label'      => esc_html__( 'Animation', 'bricks' ),
        'type'       => 'separator',
    ];
    $this->controls['duration'] = [
        'tab'     => 'content',
        'inline'    => true,
        'label'   => esc_html__( 'Duration', 'bricks' ),
        'type'    => 'number',
        'unit'    => 's',
        'css'     => [
          [
            'property' => '--duration',
            'selector' => '',
          ],
        ],
        'placeholder'    => '0.6s',
    ];
    $this->controls['easing'] = [
        'tab'     => 'content',
        'inline'    => true,
        'label'   => esc_html__( 'Easing', 'bricks' ),
        'type'    => 'text',
        'css'     => [
          [
            'property' => '--easing',
            'selector' => '',
          ],
        ],
        'placeholder'    => 'cubic-bezier(.165,.84,.44,1)',
    ];
  }

  public function get_nestable_children() {
    return [
        [
            'name'     => 'block',
            'label'    => esc_html__( 'Content', 'bricks' ),
            'settings' => [
              '_hidden'         => [
                    '_cssClasses' => 'bc-mask-hover__content',
                ],
            ],
            'children' => [
                [
                    'name'     => 'heading',
                    'label'    => esc_html__( 'Heading', 'bricks' ),
                    'settings' => [
                        'text' => esc_html__( 'Heading', 'bricks' ),
                        'tag'  => 'h3',
                        '_hidden' => [
                            '_cssClasses' => 'bc-mask-hover__title',
                        ],
                    ],
                ]
            ],
        ],

        [
            'name'     => 'block',
            'label'    => esc_html__( 'Mask Content', 'bricks' ),
            'settings' => [
              '_hidden'         => [
                    '_cssClasses' => 'bc-mask-hover__content-wrapper',
                ],
            ],
            'children' => [
                [
                    'name'     => 'heading',
                    'label'    => esc_html__( 'Mask Heading', 'bricks' ),
                    'settings' => [
                        'text' => esc_html__( 'Mask Heading', 'bricks' ),
                        'tag'  => 'h3',
                        '_hidden' => [
                            '_cssClasses' => 'bc-mask-hover__title',
                        ],
                    ],
                ]
            ],
        ],
    ];
  }

  public function render() {
    $settings = $this->settings;

    $this->set_attribute( '_root', 'class', 'bc-mask-hover' );

    $output = "<div {$this->render_attributes( '_root' )}>";
    $output .= \Bricks\Frontend::render_children( $this );
    $output .= '</div>';

	echo $output;
  }
}

