<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Microbox_Button extends \Bricks\Element {
  public $category     = 'Brickscore - Buttons';
  public $name         = 'microboxbutton';
  public $icon         = 'fa-solid fa-square-minus';
  public $scripts      = ['microbox_button'];

  public function get_label() {
    return esc_html__( 'Microbox Button', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['animation'] = [
      'title' => esc_html__( 'Animation', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Microbox Button', 'bricks' ),
        'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['link'] = [
        'tab'   => 'content',
        'label' => esc_html__( 'Link to', 'bricks' ),
        'type'  => 'link',
    ];
    $this->controls['whitespace'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'White space', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'wrap' => 'wrap',
          'nowrap' => 'nowrap',
      ],
      'inline'      => true,
      'css'     => [
          [
            'property' => 'white-space',
            'selector' => '',
          ],
        ],
      'placeholder'        => 'wrap',
  ];
    $this->controls['typography'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Typography', 'bricks' ),
        'type'        => 'typography',
        'css'     => [
            [
              'property' => 'typography',
              'selector' => '.bc-microbox-button__title',
            ],
        ],
    ];
    $this->controls['buttonbackground'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Button background', 'bricks' ),
        'type'        => 'background',
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-microbox-button__square',
            ],
        ],
    ];
    $this->controls['squarebackground'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Squares background', 'bricks' ),
        'type'        => 'background',
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-microbox-button__grid',
            ],
        ],
    ];
    $this->controls['border'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '',
            ],
          ],
    ];
    $this->controls['multiplydimensions'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Multiply dimensions', 'bricks' ),
      'type'        => 'text',
      'inline'        => true,
      'small'        => true,
      'css'     => [
          [
            'property' => '--multiply',
            'selector' => '',
          ],
        ],
        'placeholder' => '0.75',
    ];
    $this->controls['induration'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'In duration', 'bricks' ),
        'type'        => 'text',
        'inline'        => true,
        'small'        => true,
        'placeholder' => '500',
        'group' => 'animation',
    ];
    $this->controls['outduration'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Out duration', 'bricks' ),
        'type'        => 'text',
        'inline'        => true,
        'small'        => true,
        'placeholder' => '1200',
        'group' => 'animation',
    ];
    $this->controls['stagger'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Stagger', 'bricks' ),
        'type'        => 'text',
        'inline'        => true,
        'small'        => true,
        'placeholder' => '200',
        'group' => 'animation',
    ];
    $this->controls['autoplay'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Autoplay', 'bricks' ),
        'type' => 'checkbox',
        'inline' => true,
        'small' => true,
        'default' => false,
        'group' => 'animation',
    ];
    $this->controls['loop'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Loop', 'bricks' ),
        'type' => 'checkbox',
        'inline' => true,
        'small' => true,
        'default' => false,
        'group' => 'animation',
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'bc-animejs', plugin_dir_url( __FILE__ ) . '../local_assets/bc_anime.min.js', array(), get_option('brickscore_element_version'), false);
    wp_enqueue_script( 'bcmicroboxbutton', plugin_dir_url( __FILE__ ) . 'js/bc_microbox_button.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';

    if ( ! empty( $settings['link'] ) ) {
        $this->set_link_attributes( '_root', $settings['link'] );
    }

    $autoplay = ! empty( $settings['autoplay'] ) ? $settings['autoplay'] : false;
    $autoplayaux = 0;
    if($autoplay == true){
        $autoplayaux = 1;
    }else{
        $autoplayaux = 0;
    }

    $loop = ! empty( $settings['loop'] ) ? $settings['loop'] : false;
    $loopaux = 0;
    if($loop == true){
        $loopaux = 1;
    }else{
        $loopaux = 0;
    }

    $induration = ! empty( $settings['induration'] ) ? $settings['induration'] : 500;
    $outduration = ! empty( $settings['outduration'] ) ? $settings['outduration'] : 1200;
    $stagger = ! empty( $settings['stagger'] ) ? $settings['stagger'] : 200;

    $this->set_attribute( '_root', 'class', 'bc-microbox-button' );
    $this->set_attribute( '_root', 'data-induration', "$induration");
    $this->set_attribute( '_root', 'data-outduration', "$outduration");
    $this->set_attribute( '_root', 'data-stagger', "$stagger");
    $this->set_attribute( '_root', 'data-autoplay', "$autoplayaux");
    $this->set_attribute( '_root', 'data-loop', "$loopaux");

    $output = "<a {$this->render_attributes( '_root' )}>
    <div class='bc-microbox-button__grid'>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
      <div class='bc-microbox-button__square' style='transform: scale(1);'></div>
    </div>
    <span class='bc-microbox-button__title'>$inner_title</span>
    ";

    $output .= '</a>';

	echo $output;
  }
}