<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Morphing_Menu extends \Bricks\Element {
  public $category     = 'Brickscore - Menus';
  public $name         = 'morphingmenu';
  public $icon         = 'ti-menu-alt';
  public $scripts      = ['morphingmenu'];
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'Morphing Nav', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['morphingdivstyling'] = [
      'title' => esc_html__( 'Morphing Div Style', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['trigger'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Trigger', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'hover' => 'hover',
          'click' => 'click',
      ],
      'inline'      => true,
      'placeholder' => 'hover',
    ];   
    $this->controls['activeitem'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Active Item', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'placeholder' => '1',
    ];
    $this->controls['transition'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Morphing transition', 'bricks' ),
			'type'     => 'number',
			'unit'    => 's',
      'inline'      => true,
      'css'     => [
        [
          'property' => '--transition-duration',
          'selector' => '',
        ],
      ],
      'placeholder' => '0.3s',
    ];

    //Morphing Div Styling
    $this->controls['heightdiv'] = [
      'group'  => 'morphingdivstyling',
      'label'       => esc_html__( 'Height', 'bricks' ),
      'type'        => 'number',
      'units'      => true,
      'inline'      => true,
      'css'     => [
          [
            'property' => '--height',
            'selector' => '.demo-morph-bg-target',
          ],
        ],
      'placeholder' => '100%',
    ];
    $this->controls['widthdiv'] = [
      'group'  => 'morphingdivstyling',
      'label'       => esc_html__( 'Width', 'bricks' ),
      'type'        => 'number',
      'units'      => true,
      'inline'      => true,
      'css'     => [
          [
            'property' => 'width',
            'selector' => '.demo-morph-bg-target',
          ],
        ],
      'placeholder' => '100%',
    ];
    $this->controls['margindiv'] = [
      'group'  => 'morphingdivstyling',
      'label'       => esc_html__( 'Margin', 'bricks' ),
      'type'        => 'dimensions',
      'css'     => [
          [
            'property' => 'margin',
            'selector' => '.bc-morphing-menu__morphing-div',
          ],
        ],
        'placeholder' => [
          'top' => 0,
          'right' => 0,
          'bottom' => 0,
          'left' => 0,
        ],
    ];
    $this->controls['borderdiv'] = [
      'group'  => 'morphingdivstyling',
      'label'       => esc_html__( 'Border', 'bricks' ),
      'type'        => 'border',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'border',
            'selector' => '.demo-morph-bg-target',
          ],
        ],
    ];
    $this->controls['backgrounddiv'] = [
      'group'  => 'morphingdivstyling',
      'label'       => esc_html__( 'Background', 'bricks' ),
      'type'        => 'background',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'background',
            'selector' => '.bc-morphing-menu__morphing-div',
          ],
        ],
    ];

  }
  
  /*Render sliders & children*/
public function get_nestable_children() {
  return [
    [
      'name'     => 'morphingmenuitem',
      'label'    => esc_html__( 'Morphing Item', 'bricks' ),
    ],
    [
      'name'     => 'morphingmenuitem',
      'label'    => esc_html__( 'Morphing Item', 'bricks' ),
    ],
    [
      'name'     => 'morphingmenuitem',
      'label'    => esc_html__( 'Morphing Item', 'bricks' ),
    ],
  ];
}

  public function enqueue_scripts() {
    wp_enqueue_script( 'morphing-menu-js', plugin_dir_url( __FILE__ ) . 'js/bc_morphing_menu.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }



  public function render() {
    $settings = $this->settings;
    $activeitem    = ! empty( $settings['activeitem'] ) ? $settings['activeitem'] : '1';
    $trigger    = ! empty( $settings['trigger'] ) ? $settings['trigger'] : 'hover';

    $this->set_attribute( '_root', 'class', 'bc-morphing-menu' );
    $this->set_attribute( '_root', 'data-active-item', $activeitem );
    $this->set_attribute( '_root', 'data-trigger', $trigger );
    $this->set_attribute( '_root', 'data-morph-bg-preserve', '');

    $output = "<div {$this->render_attributes( '_root' )}>
    ";
    $output .= Frontend::render_children( $this ); //Morphing items
    $output .= "<span class='bc-morphing-menu__morphing-div' id='morph-bg-1' data-morph-bg-event='hover' aria-hidden='true'></span>";
    $output .= '</div>';

    echo $output;
  }
}