<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Multi_Offcanvas_Menu extends \Bricks\Element {
  public $category     = 'Brickscore - Menus';
  public $name         = 'multioffcanvasmenu';
  public $icon         = 'ti-menu-alt';
  public $scripts      = ['multioffcanvasmenu'];
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'Multi OffCanvas Menu', 'bricks' );
  }

  public function set_control_groups() {

  }

  public function set_controls() {    
    $this->controls['slidetype'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Type', 'bricks' ),
      'type'        => 'select',
      'options'     => [
        'fromRight' => 'From Right',
        'fromLeft' => 'From Left',
      ],
      'inline'      => true,
      'placeholder' => 'From Right',
      'default' => 'fromRight',
    ];
    $this->controls['slideduration'] = [
        'label'       => esc_html__( 'Duration', 'bricks' ),
        'type'        => 'number',
        'unit'        => 's',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--slide-duration',
              'selector' => '',
            ],
          ],
        'placeholder' => '1s',
    ];
    $this->controls['slideeasing'] = [
        'label'       => esc_html__( 'Easing', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--slide-easing',
              'selector' => '',
            ],
          ],
        'placeholder' => 'cubic-bezier(.33,1,.68,1)',
    ];

    $this->controls['styleSeparator'] = [
      'label'      => esc_html__( 'OffCanvas Content Style', 'bricks' ),
      'type'       => 'separator',
    ];
    $this->controls['width'] = [
      'label'       => esc_html__( 'Width', 'bricks' ),
      'type'        => 'number',
      'units'      => true,
      'inline'      => true,
      'css'     => [
          [
            'property' => 'width',
            'selector' => '.bc-multi-offcanvas-menu__items-wrapper',
          ],
      ],
      'placeholder' => '50vw',
    ];
    $this->controls['height'] = [
        'label'       => esc_html__( 'Height', 'bricks' ),
        'type'        => 'number',
        'units'      => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => 'height',
              'selector' => '.bc-multi-offcanvas-menu__items-wrapper',
            ],
        ],
        'placeholder' => '100vh',
    ];
    $this->controls['padding'] = [
        'label'       => esc_html__( 'Padding', 'bricks' ),
        'type'        => 'spacing',
        'css'     => [
            [
              'property' => 'padding',
              'selector' => '.bc-multi-offcanvas-menu__items-wrapper',
            ],
        ],
    ];
    $this->controls['background'] = [
        'label'       => esc_html__( 'Background', 'bricks' ),
        'type'        => 'color',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--background',
              'selector' => '.bc-multi-offcanvas-menu__items-wrapper',
            ],
        ],
    ];
    $this->controls['border'] = [
        'label'       => esc_html__( 'Border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '.bc-multi-offcanvas-menu__items-wrapper',
            ],
        ],
    ];
    $this->controls['boxShadow'] = [
        'label'       => esc_html__( 'Box shadow', 'bricks' ),
        'type'        => 'box-shadow',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'box-shadow',
              'selector' => '.bc-multi-offcanvas-menu__items-wrapper',
            ],
        ],
    ];

    $this->controls['separator'] = [
      'description' => sprintf(html_entity_decode(esc_html__( '<br>All elements with this Custom Toggle className will toggle the Menu alongside all its Core Burgers.', 'bricks' ))),
      'type'       => 'separator',
    ];
    $this->controls['customtoggle'] = [
      'label'       => esc_html__( 'Custom Toggle', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'placeholder' => '.bc-core-burguer',
    ];

    $this->controls['animationSeparator'] = [
      'label'      => esc_html__( 'Backdrop Animation', 'bricks' ),
      'type'       => 'separator',
    ];
    $this->controls['backdropduration'] = [
      'label'       => esc_html__( 'Duration', 'bricks' ),
      'type'        => 'number',
      'unit'      => 's',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--transition-duration-backdrop',
            'selector' => '',
          ],
        ],
      'placeholder' => '1',
    ];
    $this->controls['backdropeasing'] = [
        'label'       => esc_html__( 'Easing', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--transition-easing-backdrop',
              'selector' => '',
            ],
        ],
        'placeholder' => 'linear',
    ];
  }
  
/*Render children*/
public function get_nestable_children() {
return [
    [
      'name'     => 'coreburguer',
      'label'    => esc_html__( 'Opening Burguer', 'bricks' ),
      'settings' => [
        '_hidden' => [
            '_cssClasses' => 'bc-core-burguer--multi-offcanvas-menu',
        ],
      ],
    ],

    [
      'name'     => 'block',
      'label'    => esc_html__( 'OffCanvas Content', 'bricks' ),
      'settings' => [
        '_hidden'  => [
            '_cssClasses' => 'bc-multi-offcanvas-menu__items-wrapper',
        ],
      ],
      'children' => [
      [
        'name'     => 'coreburguer',
        'label'    => esc_html__( 'Closing Burguer', 'bricks' ),
        'settings' => [
          '_hidden' => [
              '_cssClasses' => 'bc-core-burguer--multi-offcanvas-menu',
          ],
        ],
      ],
      [
          'name'     => 'swap-hover',
      ],
      [
          'name'     => 'swap-hover',
      ],
      [
          'name'     => 'swap-hover',
      ],
      [
        'name'     => 'suboffcanvas',
        'children' => [
          [
            'name'     => 'swap-hover',
          ],
        ],
      ],
      ],
    ],

    [
      'name'     => 'block',
      'label'    => esc_html__( 'Backdrop', 'bricks' ),
      'settings' => [
        '_hidden'  => [
            '_cssClasses' => 'bc-multi-offcanvas-menu__backdrop',
        ],
      ],
    ],
];
}

  public function enqueue_scripts() {
    wp_enqueue_script( 'multioffcanvas-menu-js', plugin_dir_url( __FILE__ ) . 'js/bc_multioffcanvas.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $slidetype = ! empty( $settings['slidetype'] ) ? $settings['slidetype'] : 'fromRight';
    $customtoggle = ! empty( $settings['customtoggle'] ) ? $settings['customtoggle'] : '';

    $this->set_attribute( '_root', 'class', 'bc-core-menu' );
    $this->set_attribute( '_root', 'class', 'bc-multi-offcanvas-menu' );
    $this->set_attribute( '_root', 'data-type', "$slidetype" );
    $this->set_attribute( '_root', 'data-customtoggle', $customtoggle );

    if($slidetype === 'fromRight'){
      $this->set_attribute( '_root', 'data-classtype', 'bc-multi-offcanvas-menu--fromright' );
    }else if($slidetype === 'fromLeft'){
      $this->set_attribute( '_root', 'data-classtype', 'bc-multi-offcanvas-menu--fromleft' );
    }

    $output = "<div {$this->render_attributes( '_root' )}>";
    $output .= Frontend::render_children( $this ); //Menu items
    $output .= '</div>';

    echo $output;
  }
}