<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Neumorphic_Button extends \Bricks\Element {
  public $category     = 'Brickscore - Buttons';
  public $name         = 'neumorphicbutton';
  public $icon         = 'fa-solid fa-square-minus';

  public function get_label() {
    return esc_html__( 'Neumorphic Button', 'bricks' );
  }

  public function set_control_groups() {

  }

  public function set_controls() {
    $this->controls['inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Neumorphic Button', 'bricks' ),
        'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['link'] = [
        'tab'   => 'content',
        'label' => esc_html__( 'Link to', 'bricks' ),
        'type'  => 'link',
    ];
    $this->controls['whitespace'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'White space', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'wrap' => 'wrap',
          'nowrap' => 'nowrap',
      ],
      'inline'      => true,
      'css'     => [
          [
            'property' => 'white-space',
            'selector' => '',
          ],
        ],
      'placeholder'        => 'wrap',
    ];
    $this->controls['separator'] = [
        'type'       => 'separator',
    ];
    $this->controls['padding'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Padding', 'bricks' ),
        'type'        => 'spacing',
        'css'     => [
            [
              'property' => 'padding',
              'selector' => '',
            ],
        ],
    ];
    $this->controls['typography'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Typography', 'bricks' ),
        'type'        => 'typography',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'typography',
              'selector' => '',
            ],
        ],
    ];
    $this->controls['border'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '',
            ],
        ],
    ];
    $this->controls['leftcolor'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Left color', 'bricks' ),
        'type'        => 'color',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--right-color',
              'selector' => '',
            ],
        ],
    ];
    $this->controls['rightcolor'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Right color', 'bricks' ),
        'type'        => 'color',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--left-color',
              'selector' => '',
            ],
        ],
    ];
    $this->controls['spread'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Spread', 'bricks' ),
        'type'        => 'number',
        'units'      => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => '--spread',
              'selector' => '',
            ],
        ],
        'placeholder' => '2px',
    ];

    $this->controls['animationSeparator'] = [
        'label'      => esc_html__( 'Animation', 'bricks' ),
        'type'       => 'separator',
    ];

    $this->controls['duration'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Duration', 'bricks' ),
        'type'        => 'number',
        'unit'      => 's',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--duration',
              'selector' => '',
            ],
        ],
        'placeholder' => '0.3s',
    ];
    $this->controls['easing'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Easing', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--ease',
              'selector' => '',
            ],
        ],
        'placeholder' => 'ease-in-out',
    ];
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';

    if ( ! empty( $settings['link'] ) ) {
        $this->set_link_attributes( '_root', $settings['link'] );
    }

    $this->set_attribute( '_root', 'class', 'bc-neumorphic-button' );

    $output = "
    <a {$this->render_attributes( '_root' )}>
      <span class='bc-neumorphic-button__title'>$inner_title</span>
    </a>
    ";

	echo $output;
  }
}