<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Offcanvas_Menu extends \Bricks\Element {
  public $category     = 'Brickscore - Menus';
  public $name         = 'offcanvasmenu';
  public $icon         = 'ti-menu-alt';
  public $scripts      = ['offcanvasmenu'];
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'OffCanvas Menu', 'bricks' );
  }

  public function set_control_groups() {

  }

  public function set_controls() {    
    $this->controls['slidetype'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Type', 'bricks' ),
      'type'        => 'select',
      'options'     => [
        'fromLeft' => 'From Left',
        'fromRight' => 'From Right',
        'fromTop' => 'From Top',
      ],
      'inline'      => true,
      'placeholder' => 'From Top',
      'default' => 'fromLeft',
    ];
    $this->controls['slideduration'] = [
        'label'       => esc_html__( 'Duration', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'placeholder' => '1',
    ];
    $this->controls['slideeasing'] = [
        'label'       => esc_html__( 'Easing', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'placeholder' => 'power2.out',
    ];
    $this->controls['overflow'] = [
      'label'       => esc_html__( 'Overflow', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'css'     => [
          [
            'property' => 'overflow',
            'selector' => '.bc-offcanvas-menu__items-wrapper',
          ],
        ],
      'placeholder' => 'auto',
    ];

    $this->controls['separator'] = [
      'description' => sprintf(html_entity_decode(esc_html__( '<br>All elements with this Custom Toggle className will toggle the Menu alongside all its Core Burgers.', 'bricks' ))),
      'type'       => 'separator',
    ];
    $this->controls['customtoggle'] = [
      'label'       => esc_html__( 'Custom Toggle', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'placeholder' => '.bc-core-burguer',
    ];

    $this->controls['animationSeparator'] = [
      'label'      => esc_html__( 'Backdrop Animation', 'bricks' ),
      'type'       => 'separator',
    ];
    $this->controls['backdropduration'] = [
      'label'       => esc_html__( 'Duration', 'bricks' ),
      'type'        => 'number',
      'unit'      => 's',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--transition-duration-backdrop',
            'selector' => '',
          ],
        ],
      'placeholder' => '1',
    ];
    $this->controls['backdropeasing'] = [
        'label'       => esc_html__( 'Easing', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--transition-easing-backdrop',
              'selector' => '',
            ],
        ],
        'placeholder' => 'linear',
    ];
  }
  
/*Render children*/
public function get_nestable_children() {
return [
    [
      'name'     => 'coreburguer',
      'label'    => esc_html__( 'Opening Burguer', 'bricks' ),
      'settings' => [
        '_hidden' => [
            '_cssClasses' => 'bc-core-burguer--offcanvas-menu',
        ],
      ],
    ],

    [
      'name'     => 'block',
      'label'    => esc_html__( 'OffCanvas Content', 'bricks' ),
      'settings' => [
        '_hidden'  => [
            '_cssClasses' => 'bc-offcanvas-menu__items-wrapper',
        ],
      ],
      'children' => [
      [
        'name'     => 'coreburguer',
        'label'    => esc_html__( 'Closing Burguer', 'bricks' ),
        'settings' => [
          '_hidden' => [
              '_cssClasses' => 'bc-core-burguer--offcanvas-menu',
          ],
        ],
      ],
      [
          'name'     => 'swap-hover',
      ],
      [
          'name'     => 'swap-hover',
      ],
      [
          'name'     => 'swap-hover',
      ],
      ],
    ],

    [
      'name'     => 'block',
      'label'    => esc_html__( 'Backdrop', 'bricks' ),
      'settings' => [
        '_hidden'  => [
            '_cssClasses' => 'bc-offcanvas-menu__backdrop',
        ],
      ],
    ],
];
}

  public function enqueue_scripts() {
    wp_enqueue_script( 'offcanvas-menu-js', plugin_dir_url( __FILE__ ) . 'js/bc_offcanvas_menu.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $slidetype = ! empty( $settings['slidetype'] ) ? $settings['slidetype'] : 'From Top';
    $slideduration = ! empty( $settings['slideduration'] ) ? $settings['slideduration'] : 1;
    $slideeasing = ! empty( $settings['slideeasing'] ) ? $settings['slideeasing'] : 'power2.out';
    $customtoggle = ! empty( $settings['customtoggle'] ) ? $settings['customtoggle'] : '';

    $this->set_attribute( '_root', 'class', 'bc-core-menu' );
    $this->set_attribute( '_root', 'class', 'bc-offcanvas-menu' );
    $this->set_attribute( '_root', 'data-type', "$slidetype" );
    $this->set_attribute( '_root', 'data-duration', $slideduration );
    $this->set_attribute( '_root', 'data-easing', $slideeasing );
    $this->set_attribute( '_root', 'data-customtoggle', $customtoggle );

    if($slidetype === 'fromTop'){
      $this->set_attribute( '_root', 'data-classtype', 'bc-offcanvas-menu--fromtop' );
    }else if($slidetype === 'fromLeft'){
      $this->set_attribute( '_root', 'data-classtype', 'bc-offcanvas-menu--fromleft' );
    }else if($slidetype === 'fromRight'){
      $this->set_attribute( '_root', 'data-classtype', 'bc-offcanvas-menu--fromright' );
    }

    $output = "<div {$this->render_attributes( '_root' )}>";
    $output .= Frontend::render_children( $this ); //Menu items
    $output .= '</div>';

    echo $output;
  }
}