<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Overlay_Menu extends \Bricks\Element {
  public $category     = 'Brickscore - Menus';
  public $name         = 'overlaymenu';
  public $icon         = 'ti-menu-alt';
  public $scripts      = ['overlaymenu'];
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'Overlay Menu', 'bricks' );
  }

  public function set_control_groups() {
  }

  public function set_controls() {    
    $this->controls['scale'] = [
      'label'       => esc_html__( 'Overlay Scale', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'placeholder' => '0.925',
    ];
    $this->controls['top'] = [
      'label'       => esc_html__( 'Overlay Top Distance', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'placeholder' => '70vh',
    ];
    $this->controls['duration'] = [
      'label'       => esc_html__( 'Duration', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'placeholder' => '1',
    ];
    $this->controls['easing'] = [
      'label'       => esc_html__( 'Easing', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'placeholder' => 'power4.out',
    ];
    
    $this->controls['separator'] = [
      'description' => sprintf(html_entity_decode(esc_html__( '<br>All elements with this Custom Toggle className will toggle the Menu alongside all its Core Burgers.', 'bricks' ))),
      'type'       => 'separator',
    ];
    $this->controls['customtoggle'] = [
      'label'       => esc_html__( 'Custom Toggle', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'placeholder' => '.bc-core-burguer',
    ];
  }
  
/*Render children*/
public function get_nestable_children() {
return [
    [
        'name'     => 'coreburguer',
        'label'    => esc_html__( 'Core Burguer', 'bricks' ),
        'settings' => [
          '_hidden' => [
              '_cssClasses' => 'bc-core-burguer--overlay-menu',
          ],
        ],
    ],

    [
        'name'     => 'block',
        'label'    => esc_html__( 'Overlay Content', 'bricks' ),
        'settings' => [
          '_hidden'  => [
              '_cssClasses' => 'bc-overlay-menu__items-wrapper',
          ],
        ],
        'children' => [
        [
            'name'     => 'swap-hover',
        ],
        [
            'name'     => 'swap-hover',
        ],
        [
            'name'     => 'swap-hover',
        ],
        ],
    ],

    [
      'name'     => 'block',
      'label'    => esc_html__( 'Body Root', 'bricks' ),
      'settings' => [
        '_hidden' => [
            '_cssClasses' => 'bc-overlay-menu__content',
        ],
      ],
      'children' => [
        [
          'name'     => 'swap-hover',
      ],
      ],
    ],
];
}

  public function enqueue_scripts() {
    wp_enqueue_script( 'overlay-menu-js', plugin_dir_url( __FILE__ ) . 'js/bc_overlay_menu.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $duration = ! empty( $settings['duration'] ) ? $settings['duration'] : 1;
    $top = ! empty( $settings['top'] ) ? $settings['top'] : '70vh';
    $scale = ! empty( $settings['scale'] ) ? $settings['scale'] : 0.925;
    $easing = ! empty( $settings['easing'] ) ? $settings['easing'] : 'power4.out';
    $customtoggle = ! empty( $settings['customtoggle'] ) ? $settings['customtoggle'] : '';

    $this->set_attribute( '_root', 'class', 'bc-core-menu' );
    $this->set_attribute( '_root', 'class', 'bc-overlay-menu' );
    $this->set_attribute( '_root', 'data-duration', $duration );
    $this->set_attribute( '_root', 'data-top', $top );
    $this->set_attribute( '_root', 'data-scale', $scale );
    $this->set_attribute( '_root', 'data-easing', $easing );
    $this->set_attribute( '_root', 'data-customtoggle', $customtoggle );

    $output = "<div {$this->render_attributes( '_root' )}>";
    $output .= Frontend::render_children( $this ); //Menu items
    $output .= '</div>';

    echo $output;
  }
}