<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Parallax extends \Bricks\Element {
  public $category     = 'Brickscore - Core';
  public $name         = 'parallax';
  public $icon         = 'fa-regular fa-clone';
  public $scripts      = ['parallax'];

  public function get_label() {
    return esc_html__( 'Parallax', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['parallax'] = [
        'title' => esc_html__( 'Parallax', 'bricks' ),
        'tab'   => 'content',
      ];
  }

  public function set_controls() {
    $this->controls['image'] = [
        'hasDynamicData' => true,
        'tab' => 'content',
        'label' => esc_html__( 'Image', 'bricks' ),
        'type' => 'image',
    ];
    $this->controls['alt'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Custom alt text', 'bricks' ),
        'type' => 'text',
        'inline' => true,
    ];
    $this->controls['width'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Width', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline' => true,
        'css' => [
          [
            'property' => 'width',
            'selector' => '', /*el hijo y su wrapper*/
          ]
        ],
        'placeholder' => 'auto',
    ];
    $this->controls['orientation'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Orientation', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'down' => 'down',
            'right' => 'right',
            'up' => 'up',
            'left' => 'left',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'down',
        'group'        => 'parallax',
    ];
    $this->controls['scale'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Scale', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '1.2',
        'group'        => 'parallax',
    ];
    $this->controls['overflow'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Overflow', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'true' => 'true',
            'false' => 'false',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'true',
        'group'        => 'parallax',
    ];
    $this->controls['delay'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Delay', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '1.6',
        'group'        => 'parallax',
    ];
    $this->controls['ease'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Ease', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'cubic-bezier(0,0,0,1)',
        'group'        => 'parallax',
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'parallax', plugin_dir_url( __FILE__ ) . 'js/bc_parallax.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);

    wp_enqueue_script( 'parallax-js', plugin_dir_url( __FILE__ ) . '../local_assets/bc_simpleparallax.min.js', array(), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;

    if (isset($settings['image'])) {
        $last_image = $settings['image']['url'];

        $image_dimensions = getimagesize($last_image);
        $width = $image_dimensions[0];
        $height = $image_dimensions[1];
    } else {
        $last_image = 'https://images.pexels.com/photos/17050728/pexels-photo-17050728/free-photo-of-madera-carretera-paisaje-agua.jpeg?auto=compress&cs=tinysrgb&w=1260&h=750&dpr=1';
        $width = null;
        $height = null;
    }

    $alt = !empty($settings['alt']) ? "alt='{$settings['alt']}'" : '';
    $orientation = !empty($settings['orientation']) ? $settings['orientation'] : 'down';
    $scale = !empty($settings['scale']) ? $settings['scale'] : 1.2;
    $overflow = !empty($settings['overflow']) ? $settings['overflow'] : 'true';
    $delay = !empty($settings['delay']) ? $settings['delay'] : 1.6;
    $ease = !empty($settings['ease']) ? $settings['ease'] : 'cubic-bezier(0,0,0,1)';

    $this->set_attribute('_image', 'data-orientation', $orientation);
    $this->set_attribute('_image', 'data-scale', $scale);
    $this->set_attribute('_image', 'data-overflow', $overflow);
    $this->set_attribute('_image', 'data-delay', $delay);
    $this->set_attribute('_image', 'data-ease', $ease);

    $this->set_attribute('_root', 'class', 'bc-parallax');

    $output = "<div {$this->render_attributes('_root')}>
    <img class='bc-parallax__element bc-parallax__to-hide' src='$last_image' width='$width' height='$height' $alt {$this->render_attributes('_image')}>";
    $output .= '</div>';

    echo $output;
}

}