<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Particles extends Element {
  public $category     = 'Brickscore - Core';
  public $name         = 'particles';
  public $icon         = 'fa-brands fa-medium fa-rotate-90';
  public $scripts      = ['particles'];
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'Particles', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['animation'] = [
        'title' => esc_html__( 'Animation', 'bricks' ),
        'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['note'] = [
        'tab' => 'content',
        'description' => sprintf(html_entity_decode(esc_html__( 'NOTE: <br>Drag & Drop elements inside particles.<br>Reload if flickering.', 'bricks' )))
    ];
    $this->controls['apply'] = [
        'tab' => 'content',
        'type' => 'apply',
        'reload' => true,
        'label' => esc_html__( 'Reload particles changes', 'bricks' ),
    ];
    $this->controls['background'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Background', 'bricks' ),
        'type' => 'background',
        'inline' => true,
        'css' => [
          [
            'property' => 'background',
            'selector' => '.bc-particles__element',
          ]
        ],
    ];
    $this->controls['height'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Height', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline' => true,
        'css' => [
          [
            'property' => 'height',
            'selector' => '.bc-particles__element',
          ]
        ],
        'placeholder' => '300px',
    ];
    $this->controls['speed'] = [
        'group'   => 'animation',
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Speed', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '1',
    ];
    $this->controls['randomminduration'] = [
        'group'   => 'animation',
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Random min duration', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '5',
    ];
    $this->controls['randommaxduration'] = [
        'group'   => 'animation',
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Random max duration', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '10',
    ];
    $this->controls['ease'] = [
        'group'   => 'animation',
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'GSAP easing', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'none',
    ];
  }

  public function get_nestable_item() {
    return [
        'name'     => 'heading',
        'label'    => esc_html__( 'Title', 'bricks' ),
        'settings' => [
          'text' => esc_html__( 'Bricks', 'bricks' ),
          'tag'  => 'span',
          '_cssClasses' => 'bc-particles__example-heading',
        ],
    ];
  }

  public function get_nestable_children() {
      $children = [];

      for ( $i = 0; $i < 1; $i++ ) { /*Cantidad de item a generar*/
          $item = $this->get_nestable_item();

          // Replace {item_index} with $index
          $item       = json_encode( $item );
          $item       = str_replace( '{item_index}', $i + 1, $item );
          $item       = json_decode( $item, true );
          $children[] = $item;
      }

      return $children;
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'particles', plugin_dir_url( __FILE__ ) . 'js/bc_particles.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $speed = ! empty( $settings['speed'] ) ? $settings['speed'] : 1;
    $ease = ! empty( $settings['ease'] ) ? $settings['ease'] : "none";
    $randomminduration = ! empty( $settings['randomminduration'] ) ? $settings['randomminduration'] : 5;
    $randommaxduration = ! empty( $settings['randommaxduration'] ) ? $settings['randommaxduration'] : 10;

    $this->set_attribute( 'inner_data', 'data-speed', "$speed");
    $this->set_attribute( 'inner_data', 'data-ease', "$ease");
    $this->set_attribute( 'inner_data', 'data-randomminduration', "$randomminduration");
    $this->set_attribute( 'inner_data', 'data-randommaxduration', "$randommaxduration");

    $output = "<div {$this->render_attributes( '_root' )}>";

    $output .= "<div class='bc-particles__element bc-particles__to-hide' {$this->render_attributes( 'inner_data' )}>";

    $output .= Frontend::render_children( $this );

    $output .= "</div>";

    $output .= '</div>';

	echo $output;
  }
}

