<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Prism_Button extends \Bricks\Element {
  public $category     = 'Brickscore - Buttons';
  public $name         = 'prismbutton';
  public $icon         = 'fa-solid fa-square-minus';
  public $scripts      = ['prismbutton'];

  public function get_label() {
    return esc_html__( 'Prism Button', 'bricks' );
  }

  public function set_control_groups() {

  }

  public function set_controls() {
    $this->controls['link'] = [
        'tab'   => 'content',
        'label' => esc_html__( 'Link to', 'bricks' ),
        'type'  => 'link',
    ];
    $this->controls['whitespace'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'White space', 'bricks' ),
      'type'        => 'select',
      'inline'      => true,
      'options'     => [
          'wrap' => 'wrap',
          'nowrap' => 'nowrap',
      ],
      'css'     => [
          [
            'property' => 'white-space',
            'selector' => '',
          ],
        ],
      'placeholder'        => 'nowrap',
    ];
    $this->controls['from'] = [
      'hasDynamicData' => false,
      'tab'         => 'content',
      'label'       => esc_html__( 'From', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'data-from-top' => 'top',
          'data-from-bottom' => 'bottom',
      ],
      'clearable'   => false,
      'inline'      => true,
      'placeholder' => 'top',
    ];
    $this->controls['padding'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Padding', 'bricks' ),
        'type'        => 'spacing',
        'css'     => [
            [
              'property' => '--padding-prism',
              'selector' => '',
            ],
        ],
        'placeholder'     => [
          'top' => 10,
          'bottom' => 10,
          'left' => 10,
          'right' => 10,
        ],
    ];
    $this->controls['font_size'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Font size', 'bricks' ),
        'type'        => 'number',
        'units'      => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => '--font-size',
              'selector' => '',
            ],
        ],
        'placeholder'        => '27px',
    ];
    $this->controls['perspective'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Perspective', 'bricks' ),
      'type'        => 'number',
      'units'      => true,
      'inline'      => true,
      'css'     => [
          [
            'property' => '--perspective',
            'selector' => '',
          ],
      ],
      'placeholder'        => '1000px',
    ];
    $this->controls['transition_duration'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Transition duration', 'bricks' ),
        'type'        => 'number',
        'unit'      => 's',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--transition-duration',
              'selector' => '',
            ],
          ],
        'placeholder'        => '0.25s',
    ];
    $this->controls['easing'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'Easing', 'bricks' ),
      'type'        => 'text',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--ease',
            'selector' => '',
          ],
        ],
      'placeholder'        => 'cubic-bezier(0.645, 0.045, 0.355, 1)',
    ];

    $this->controls['frontSeparator'] = [
        'label'      => esc_html__( 'Front', 'bricks' ),
        'type'       => 'separator',
    ];
    $this->controls['front_inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Prism Button', 'bricks' ),
        'placeholder'    => esc_html__( 'Prism Button', 'bricks' ),
    ];
    $this->controls['front_typography'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Typography', 'bricks' ),
        'type'        => 'typography',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'typography',
              'selector' => '.bc-prism-button__front-text',
            ],
        ],
        'exclude' => [
          'font-size',
          'line-height',
        ],
    ];
    $this->controls['front_background'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Background', 'bricks' ),
        'type'        => 'background',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-prism-button__front-text',
            ],
        ],
    ];
    $this->controls['front_border'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '.bc-prism-button__front-text',
            ],
        ],
    ];
    $this->controls['backSeparator'] = [
        'label'      => esc_html__( 'Back', 'bricks' ),
        'type'       => 'separator',
    ];
    $this->controls['back_inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Button Prism', 'bricks' ),
        'placeholder'    => esc_html__( 'Button Prism', 'bricks' ),
    ];
    $this->controls['back_typography'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Typography', 'bricks' ),
        'type'        => 'typography',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'typography',
              'selector' => '.bc-prism-button__back-text',
            ],
        ],
        'exclude' => [
          'font-size',
          'line-height',
        ],
    ];
    $this->controls['back_background'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Background', 'bricks' ),
        'type'        => 'background',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-prism-button__back-text',
            ],
        ],
    ];
    $this->controls['back_border'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '.bc-prism-button__back-text',
            ],
        ],
    ];
  }

  public function render() {
    $settings = $this->settings;
    $front_inner_title    = ! empty( $settings['front_inner_title'] ) ? $settings['front_inner_title'] : 'Prism Button';
    $back_inner_title    = ! empty( $settings['back_inner_title'] ) ? $settings['back_inner_title'] : 'Button Prism';
    $from    = ! empty( $settings['from'] ) ? $settings['from'] : 'data-from-top';

    if ( ! empty( $settings['link'] ) ) {
        $this->set_link_attributes( '_root', $settings['link'] );
    }
    if (  $from == 'data-from-top' ) {
      $this->set_attribute( '_root', 'data-from-top', '' );
    }else if (  $from == 'data-from-bottom' ) {
      $this->set_attribute( '_root', 'data-from-bottom', '' );
    }

    $this->set_attribute( '_root', 'class', 'bc-prism-button' );

    $output = "
    <a {$this->render_attributes( '_root' )}>
        <div class='bc-prism-button__wrapper'>
            <span class='bc-prism-button__front-text'>$front_inner_title</span>
            <span class='bc-prism-button__back-text'>$back_inner_title</span>
        </div>
    </a>
    ";

	echo $output;
  }
}