<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Random_Letters extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'random-letters';
  public $icon         = 'ti-text';
  public $tag      = 'h3';
  public $css_selector = '';
  public $scripts      = ['random_letters'];

  public function get_label() {
    return esc_html__( 'Random Letters', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['animation'] = [
        'title' => esc_html__( 'Animation', 'bricks' ),
        'tab'   => 'content',
    ];
    $this->control_groups['gradient'] = [
      'title' => esc_html__( 'Gradient', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
      'tab'            => 'content',
      'type'           => 'text',
	  'hasDynamicData' => 'text',
      'default'        => esc_html__( 'Random Letters', 'bricks' ),
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];

    $this->controls['titleTypography'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Title typography', 'bricks' ),
        'type'    => 'typography',
              'css'     => [
          [
            'property' => 'typography',
            'selector' => '.bc-random-letters',
          ],
        ],
    ];

    $this->controls['tag'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'HTML tag', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'h1' => 'h1',
            'h2' => 'h2',
            'h3' => 'h3',
            'h4' => 'h4',
            'h5' => 'h5',
            'h6' => 'h6',
            'p' => 'p',
            'span' => 'span',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'h3',
        'default'     => 'h3',
    ];

    $this->controls['scale'] = [
        'hasDynamicData' => false,
          'tab' => 'content',
          'group'   => 'animation',
          'label' => esc_html__( 'Scale', 'bricks' ),
          'type' => 'text',
          'inline' => true,
          'placeholder' => '1.2',
      ];

    $this->controls['duration'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Duration', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '1.4',
    ];

    $this->controls['scrolltrigger'] = [
      'group'   => 'animation',
      'label'      => esc_html__( 'SrollTrigger', 'bricks' ),
      'type'       => 'separator',
      'description' => sprintf(esc_html__( 'Scrolltrigger %s', 'bricks' ), '<a href="https://greensock.com/docs/v3/Plugins/ScrollTrigger" target="_blank">documentation</a>'),
    ];

    $this->controls['trigger'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Trigger', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'this',
    ];

    $this->controls['start'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Start', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'top bottom',
    ];

    $this->controls['end'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'group'   => 'animation',
      'label' => esc_html__( 'End', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 'unset',
    ];

    $this->controls['scrub'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Scrub', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'false',
    ];

    $this->controls['toggleActions'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'toggleActions', 'bricks' ),
        'type' => 'text',
        'placeholder' => 'play none none none',
    ];

    //Gradient
    $this->controls['titleGradient'] = [
      'group' => 'gradient',
      'tab' => 'content',
      'type' => 'gradient',
      'css' => [
        [
          'property' => 'background-image',
          'selector' => '.char',
        ],
      ],
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'bcrandomletters', plugin_dir_url( __FILE__ ) . 'js/bc_random_letters.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $start = ! empty( $settings['start'] ) ? $settings['start'] : 'top bottom';
    $end = ! empty( $settings['end'] ) ? $settings['end'] : 'unset';
    $duration = ! empty( $settings['duration'] ) ? $settings['duration'] : 1.4;
    $scale = ! empty( $settings['scale'] ) ? $settings['scale'] : 1.2;
    $trigger = ! empty( $settings['trigger'] ) ? $settings['trigger'] : 'this';
    $scrub = ! empty( $settings['scrub'] ) ? $settings['scrub'] : 'false';
    $toggleActions = ! empty( $settings['toggleActions'] ) ? $settings['toggleActions'] : 'play none none none';

    $this->set_attribute( '_root', 'class', 'bc-random-letters-wrapper' );
    $output = "<div {$this->render_attributes( '_root' )}>";

    if ( $inner_title ) {
      $this->set_attribute( 'inner_title', 'class', 'bc-random-letters' );
      $this->set_attribute( 'inner_title', 'class', 'bc-to-hide' );
      $this->set_attribute( 'inner_title', 'data-start', "$start");
      $this->set_attribute( 'inner_title', 'data-end', "$end");
      $this->set_attribute( 'inner_title', 'data-duration', "$duration");
      $this->set_attribute( 'inner_title', 'data-scale', "$scale");
      $this->set_attribute( 'inner_title', 'data-trigger', "$trigger");
      $this->set_attribute( 'inner_title', 'data-scrub', "$scrub");
      $this->set_attribute( 'inner_title', 'data-toggleActions', "$toggleActions");


      $output .=
      "<{$this->tag} {$this->render_attributes( 'inner_title' )}>$inner_title</{$this->tag}>";
    }
    $output .= '</div>';


		echo $output;
  }
}

