<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Ripplebutton extends \Bricks\Element {
  public $category     = 'Brickscore - Buttons';
  public $name         = 'ripplebutton';
  public $icon         = 'fa-solid fa-square-minus';
  public $scripts      = ['ripplebutton'];

  public function get_label() {
    return esc_html__( 'Ripple Button', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['mask'] = [
      'title' => esc_html__( 'Mask', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Ripple Button', 'bricks' ),
        'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['link'] = [
      'tab'   => 'content',
      'label' => esc_html__( 'Link to', 'bricks' ),
      'type'  => 'link',
  ];
    $this->controls['typography'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Typography', 'bricks' ),
        'type'        => 'typography',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'typography',
              'selector' => '',
            ],
          ],
    ];
    $this->controls['padding'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Padding', 'bricks' ),
        'type'        => 'dimensions',
        'css'     => [
            [
              'property' => 'padding',
              'selector' => '',
            ],
          ],
          'placeholder' => [
            'top' => 15,
            'right' => 50,
            'bottom' => 15,
            'left' => 50,
          ],
    ];
    $this->controls['border'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '',
            ],
          ],
    ];
    $this->controls['background'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Background', 'bricks' ),
        'type'        => 'background',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'background',
              'selector' => '',
            ],
          ],
    ];

    /*MASK*/
    $this->controls['side'] = [
      'hasDynamicData' => false,
      'group'			=> 'mask',
      'tab'         => 'content',
      'label'       => esc_html__( 'Side', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'From top' => 'From top',
          'From bottom' => 'From bottom',
          'From left' => 'From left',
          'From right' => 'From right',
      ],
      'clearable'   => false,
      'inline'      => true,
      'small'      => true,
      'placeholder' => 'From top',
  ];
    $this->controls['textskew'] = [
      'hasDynamicData' => false,
      'group'   => 'mask',
        'tab'         => 'content',
        'label'       => esc_html__( 'Text skew', 'bricks' ),
        'type' => 'number',
        'unit' => 'deg',
        'inline'      => true,
        'small'      => true,
        'css'     => [
            [
              'property' => '--skew-text',
              'selector' => '',
            ],
          ],
          'placeholder'    => esc_html__( '10', 'bricks' ),
    ];
    $this->controls['masktypography'] = [
      'group'   => 'mask',
        'tab'         => 'content',
        'label'       => esc_html__( 'Mask color', 'bricks' ),
        'type'        => 'color',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'color',
              'selector' => '.bc-ripple-button__pseudo::after',
            ],
          ],
    ];
    $this->controls['maskbackground'] = [
      'group'   => 'mask',
        'tab'         => 'content',
        'label'       => esc_html__( 'Mask background', 'bricks' ),
        'type'        => 'background',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-ripple-button__hover-fill',
            ],
          ],
    ];
    $this->controls['intransitionduration'] = [
      'group'   => 'mask',
      'tab'         => 'content',
      'label'       => esc_html__( 'In transition duration', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'inline'      => true,
      'small'      => true,
      'css'     => [
          [
            'property' => '--transition-duration-in',
            'selector' => '',
          ],
      ],
      'placeholder'    => esc_html__( '0.8s', 'bricks' ),
    ];
    $this->controls['transitionduration'] = [
      'group'   => 'mask',
      'tab'         => 'content',
      'label'       => esc_html__( 'Out transition duration', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'inline'      => true,
      'small'      => true,
      'css'     => [
          [
            'property' => '--transition-duration',
            'selector' => '',
          ],
      ],
      'placeholder'    => esc_html__( '0.8s', 'bricks' ),
    ];
    $this->controls['transitionease'] = [
      'group'   => 'mask',
      'tab'         => 'content',
      'label'       => esc_html__( 'Transition ease', 'bricks' ),
      'type' => 'text',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--transition-ease',
            'selector' => '',
          ],
        ],
        'placeholder'    => esc_html__( 'cubic-bezier(0.22, 1, 0.36, 1)', 'bricks' ),
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'ripplebutton', plugin_dir_url( __FILE__ ) . 'js/bc_ripple_button.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $side    = ! empty( $settings['side'] ) ? $settings['side'] : 'From top';

    if ( ! empty( $settings['link'] ) ) {
			$this->set_link_attributes( '_root', $settings['link'] );
		}

    $additionalClasses = '';
    if ($side === 'From bottom') {
        $additionalClasses = 'bc-ripple-button--from-bottom';
    } elseif ($side === 'From left') {
        $additionalClasses = 'bc-ripple-button--from-left';
    } elseif ($side === 'From right') {
        $additionalClasses = 'bc-ripple-button--from-right';
    }
    
    $this->set_attribute( '_root', 'class', "bc-ripple-button" );
    $output = "
    <a {$this->render_attributes( '_root' )} data-type='$additionalClasses'>
        <span class='bc-ripple-button__hover-fill'></span>
        <span class='bc-ripple-button__pseudo' data-content='$inner_title'>
          <span class='bc-ripple-button__text'>
          $inner_title
          </span>
        </span>
    </a>
    ";

    $output .= '</a>';

	echo $output;
  }
}



