<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Scroll_Reading extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'scroll reading';
  public $icon         = 'fa-solid fa-align-center';
  public $tag      = 'p';
  public $css_selector = '';
  public $scripts      = ['scroll_reading'];

  public function get_label() {
    return esc_html__( 'Scroll Reading', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['animation'] = [
      'title' => esc_html__( 'Animation', 'bricks' ),
      'tab'   => 'content',
    ];
    $this->control_groups['gradient'] = [
      'title' => esc_html__( 'Gradient', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['tag'] = [
      'tab'         => 'content',
      'label'       => esc_html__( 'HTML tag', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'h1' => 'h1',
          'h2' => 'h2',
          'h3' => 'h3',
          'h4' => 'h4',
          'h5' => 'h5',
          'h6' => 'h6',
          'p' => 'p',
          'span' => 'span',
      ],
      'clearable'   => false,
      'inline'      => true,
      'placeholder' => 'p',
      'default'     => 'p',
  ];

  $this->controls['inner_title'] = [
    'tab'            => 'content',
    'type'           => 'textarea',
    'default'        => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis nec leo et mi mollis dictum. Vivamus bibendum est vel elit eleifend sodales. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis nec leo et mi mollis dictum. Vivamus bibendum est vel elit eleifend sodales. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis nec leo et mi mollis dictum. Vivamus bibendum est vel elit eleifend sodales. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis nec leo et mi mollis dictum. Vivamus bibendum est vel elit eleifend sodales.', 'bricks' ),
    'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
  ];

  $this->controls['titleTypography'] = [
    'tab'     => 'content',
    'label'   => esc_html__( 'Typography', 'bricks' ),
    'type'    => 'typography',
    'css'     => [
      [
        'property' => 'typography',
        'selector' => '.bc-scroll-reading__element',
      ],
    ],
  ];

  $this->controls['MaskColor'] = [
    'tab'     => 'content',
    'label'   => esc_html__( 'Mask color', 'bricks' ),
    'type'    => 'color',
    'css'     => [
      [
        'property' => 'background',
        'selector' => '.bc-scroll-reading__line-mask',
      ],
    ],
  ];

  $this->controls['Opacity'] = [
    'tab'     => 'content',
    'label'   => esc_html__( 'Text opacity', 'bricks' ),
    'type'    => 'text',
    'placeholder' => '0.1',
    'inline' => true,
    'css'     => [
      [
        'property' => '--opacity',
        'selector' => '.bc-scroll-reading__line-mask',
      ],
    ],
  ];

    $this->controls['duration'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Duration', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => '1',
    ];

    $this->controls['scroller'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Scroller', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'body',
    ];

    $this->controls['scrolltrigger'] = [
      'group'   => 'animation',
      'label'      => esc_html__( 'SrollTrigger', 'bricks' ),
      'type'       => 'separator',
      'description' => sprintf(esc_html__( 'Scrolltrigger %s', 'bricks' ), '<a href="https://greensock.com/docs/v3/Plugins/ScrollTrigger" target="_blank">documentation</a>'),
    ];

    $this->controls['start'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Start', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'top center',
    ];

    //Gradient
    $this->controls['titleGradient'] = [
      'group' => 'gradient',
      'tab' => 'content',
      'type' => 'gradient',
      'css' => [
        [
          'property' => 'background-image',
          'selector' => '.word',
        ],
      ],
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'scrollreading', plugin_dir_url( __FILE__ ) . 'js/bc_scroll_reading.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $start = ! empty( $settings['start'] ) ? $settings['start'] : 'top center';
    $duration = ! empty( $settings['duration'] ) ? $settings['duration'] : 1;
    $scroller = ! empty( $settings['scroller'] ) ? $settings['scroller'] : 'body';

    $this->set_attribute( '_root', 'class', 'bc-scroll-reading' );
    $output = "<div {$this->render_attributes( '_root' )}>";

    if ( $inner_title ) {
      $this->set_attribute( 'inner_title', 'class', 'bc-scroll-reading__element' );
      $this->set_attribute( 'inner_title', 'class', 'bc-scroll-reading__to-hide' );
      $this->set_attribute( 'inner_title', 'data-start', "$start");
      $this->set_attribute( 'inner_title', 'data-duration', "$duration");
      $this->set_attribute( 'inner_title', 'data-scroller', "$scroller");

      $output .=
      "<{$this->tag} {$this->render_attributes( 'inner_title' )}>$inner_title</{$this->tag}>";
    }

    $output .= '</div>';


		echo $output;
  }
}

