<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Sharer extends \Bricks\Element {
  public $category     = 'Brickscore - Core';
  public $name         = 'sharer';
  public $icon         = 'fa-solid fa-hashtag';
  public $scripts      = ['sharer'];

  public function get_label() {
    return esc_html__( 'Sharer', 'bricks' );
  }

  public function set_control_groups() {

  }

  public function set_controls() {
    $this->controls['inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Share on social media', 'bricks' ),
        'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['type'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Type', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'twitter' => 'twitter',
            'facebook' => 'facebook',
            'whatsapp' => 'whatsapp',
            'telegram' => 'telegram',
            'reddit' => 'reddit',
            'skype' => 'skype',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'twitter',
    ];
    $this->controls['title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Just a text to share', 'bricks' ),
        'placeholder'    => esc_html__( 'Title to share', 'bricks' ),
    ];
    $this->controls['url'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'https://brickscore.io', 'bricks' ),
        'placeholder'    => esc_html__( 'Url to share', 'bricks' ),
    ];
    $this->controls['width'] = [
      'tab'            => 'content',
      'inline'            => true,
      'type'  => 'number',
      'units' => true,
      'hasDynamicData' => 'text',
      'placeholder'        => esc_html__( '500px', 'bricks' ),
      'label'    => esc_html__( 'Pop up width', 'bricks' ),
  ];
  $this->controls['height'] = [
    'tab'            => 'content',
    'inline'            => true,
    'type'  => 'number',
    'units' => true,
    'hasDynamicData' => 'text',
    'placeholder'        => esc_html__( '500px', 'bricks' ),
    'label'    => esc_html__( 'Pop up height', 'bricks' ),
];
$this->controls['tab'] = [
  'tab'         => 'content',
  'label'       => esc_html__( 'Open as a tab', 'bricks' ),
  'type'        => 'select',
  'options'     => [
      'true' => 'true',
      'false' => 'false',
  ],
  'clearable'   => false,
  'inline'      => true,
  'placeholder' => 'false',
];
$this->controls['hashtags'] = [
  'tab'         => 'content',
  'type'           => 'text',
  'hasDynamicData' => 'text',
  'default'        => esc_html__( 'awesome, brickscore', 'bricks' ),
  'placeholder'    => esc_html__( 'Twitter hashtags (awesome,brickscore)', 'bricks' ),
];
$this->controls['username'] = [
  'tab'         => 'content',
  'type'           => 'text',
  'hasDynamicData' => 'text',
  'default'        => esc_html__( 'brickscore', 'bricks' ),
  'placeholder'    => esc_html__( 'Twitter username', 'bricks' ),
];
$this->controls['facebookhashtag'] = [
  'tab'         => 'content',
  'type'           => 'text',
  'hasDynamicData' => 'text',
  'default'        => esc_html__( 'brickscore', 'bricks' ),
  'placeholder'    => esc_html__( 'Facebook hashtag', 'bricks' ),
];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'sharer', plugin_dir_url( __FILE__ ) . 'js/bc_sharer.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);

    wp_enqueue_script( 'sharer-js', plugin_dir_url( __FILE__ ) . '../local_assets/bc_sharer.min.js', array(), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Share on social media';
    $datasharer = ! empty( $settings['type'] ) ? $settings['type'] : 'twitter';
    $datatitle    = ! empty( $settings['title'] ) ? $settings['title'] : 'Just a title to share';
    $dataurl    = ! empty( $settings['url'] ) ? $settings['url'] : 'https://brickscore.io';
    $datawidth   = ! empty( $settings['width'] ) ? $settings['width'] : '500px';
    $dataheight    = ! empty( $settings['height'] ) ? $settings['height'] : '500px';
    $datatab    = ! empty( $settings['tab'] ) ? $settings['tab'] : 'false';
    $datahashtags   = ! empty( $settings['hashtags'] ) ? $settings['hashtags'] : 'awesome,brickscore';
    $datausername   = ! empty( $settings['username'] ) ? $settings['username'] : 'brickscore';
    $datafacebookhashtag   = ! empty( $settings['facebookhashtag'] ) ? $settings['facebookhashtag'] : 'brickscore';

    $this->set_attribute( '_root', 'data-sharer', "$datasharer" );
    $this->set_attribute( '_root', 'data-title', "$datatitle" );
    $this->set_attribute( '_root', 'data-url', "$dataurl" );
    $this->set_attribute( '_root', 'data-width', "$datawidth" );
    $this->set_attribute( '_root', 'data-height', "$dataheight" );
    $this->set_attribute( '_root', 'data-link', "$datatab" );
    $this->set_attribute( '_root', 'data-blank', "$datatab" );
    $this->set_attribute( '_root', 'data-hashtags', "$datahashtags" );
    $this->set_attribute( '_root', 'data-via', "$datausername" );
    $this->set_attribute( '_root', 'data-hashtag', "$datafacebookhashtag" );


    $this->set_attribute( '_root', 'class', 'bc-sharer' );

    $output = "<span {$this->render_attributes( '_root' )}>$inner_title";
    $output .= '</span>';

	echo $output;
  }
}
