<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Simple_Menu extends \Bricks\Element {
  public $category     = 'Brickscore - Menus';
  public $name         = 'simplemenu';
  public $icon         = 'ti-menu-alt';
  public $scripts      = ['simple_menu'];
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'Simple Menu', 'bricks' );
  }

  public function set_controls() {    
    $this->controls['duration'] = [
        'label'       => esc_html__( 'Duration', 'bricks' ),
        'type'        => 'number',
        'unit'      => 's',
        'inline'      => true,
        'placeholder' => '.4s',
    ];
    $this->controls['easing'] = [
        'label'       => esc_html__( 'Easing', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'placeholder' => 'none',
    ];
    $this->controls['enablefade'] = [
        'label' => esc_html__( 'Enable fade', 'bricks' ),
        'type' => 'checkbox',
        'inline' => true,
        'small' => true,
        'default' => true,
    ];

    $this->controls['separator'] = [
        'description' => sprintf(html_entity_decode(esc_html__( '<br>All elements with this Custom Toggle className will toggle the Menu alongside all its Core Burgers.', 'bricks' ))),
        'type'       => 'separator',
    ];
    $this->controls['customtoggle'] = [
        'label'       => esc_html__( 'Custom Toggle', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'placeholder' => '.bc-core-burguer',
    ];

    $this->controls['contentseparator'] = [
        'label'       => esc_html__( 'Content Style', 'bricks' ),
        'description' => sprintf(html_entity_decode(esc_html__( 'Edit Content styles at its element or directly from here.', 'bricks' ))),
        'type'       => 'separator',
    ];
    $this->controls['margin'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Margin', 'bricks' ),
        'type'  => 'spacing',
        'units' => true,
        'css'     => [
          [
              'property' => 'margin',
              'selector' => '.bc-simple-menu__content',
          ],
        ],
    ];
    $this->controls['padding'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Padding', 'bricks' ),
        'type'  => 'spacing',
        'units' => true,
        'css'     => [
          [
              'property' => 'padding',
              'selector' => '.bc-simple-menu__content',
          ],
        ],
    ];
    $this->controls['width'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Width', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline' => true,
        'css'     => [
          [
              'property' => 'width',
              'selector' => '.bc-simple-menu__content',
          ],
        ],
        'placeholder' => 'fit-content',
    ];
    $this->controls['height'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Height', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'inline' => true,
        'css'     => [
          [
              'property' => 'height',
              'selector' => '.bc-simple-menu__content',
          ],
        ],
        'placeholder' => 'fit-content',
    ];
    $this->controls['background'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Background', 'bricks' ),
        'type'  => 'background',
        'units' => true,
        'css'     => [
          [
              'property' => 'background',
              'selector' => '.bc-simple-menu__content',
          ],
        ],
    ];
    $this->controls['border'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Border', 'bricks' ),
        'type'  => 'border',
        'units' => true,
        'css'     => [
          [
              'property' => 'border',
              'selector' => '.bc-simple-menu__content',
          ],
        ],
    ];
  }
  
/*Render children*/
public function get_nestable_children() {
return [
    [
      'name'     => 'coreburguer',
      'label'    => esc_html__( 'Core Burguer', 'bricks' ),
      'settings' => [
        '_hidden' => [
            '_cssClasses' => 'bc-core-burguer--simple-menu',
        ],
      ],
    ],

    [
        'name'     => 'block',
        'label'    => esc_html__( 'Content', 'bricks' ),
        'settings' => [
          '_hidden'  => [
              '_cssClasses' => 'bc-simple-menu__content',
          ],
        ],
        'children' => [
            [
                'name'     => 'swap-hover',
            ],
            [
                'name'     => 'swap-hover',
            ],
            [
                'name'     => 'swap-hover',
            ],
        ],

    ]
];
}

  public function enqueue_scripts() {
    wp_enqueue_script( 'simple-menu-js', plugin_dir_url( __FILE__ ) . 'js/bc_simple_menu.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $duration = ! empty( $settings['duration'] ) ? $settings['duration'] : '0.4s';
    $easing = ! empty( $settings['easing'] ) ? $settings['easing'] : 'none';
    $enablefade = ! empty( $settings['enablefade'] ) ? $settings['enablefade'] : 0;
    $customtoggle = ! empty( $settings['customtoggle'] ) ? $settings['customtoggle'] : '';

    $this->set_attribute( '_root', 'class', 'bc-core-menu' );
    $this->set_attribute( '_root', 'class', 'bc-simple-menu' );
    $this->set_attribute( '_root', 'data-duration', $duration );
    $this->set_attribute( '_root', 'data-easing', $easing );
    $this->set_attribute( '_root', 'data-fade', $enablefade );
    $this->set_attribute( '_root', 'data-customtoggle', $customtoggle );

    $output = "<div {$this->render_attributes( '_root' )}>";
    $output .= Frontend::render_children( $this );
    $output .= '</div>';

    echo $output;
  }
}