<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Stickynav_Menu extends \Bricks\Element {
  public $category     = 'Brickscore - Menus';
  public $name         = 'stickynav';
  public $icon         = 'ti-menu-alt';
  public $scripts      = ['stickynavmenu'];
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'Sticky Header', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['responsive'] = [
      'title' => esc_html__( 'Responsive', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['enableoffset'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label'    => esc_html__( 'Enable Offset', 'bricks' ),
      'type'     => 'checkbox',
      'default'      => true,
    ];
    $this->controls['offset'] = [
      'label'       => esc_html__( 'Offset Scrolling', 'bricks' ),
      'type'        => 'text',
      'hasDynamicData' => false,
      'small'      => true,
      'units'      => true,
      'inline'      => true,
      'placeholder' => '100',
      'required' => [ 'enableoffset', '=', true],
    ];
    $this->controls['animationSeparator'] = [
      'label'      => esc_html__( 'Offset Animation', 'bricks' ),
      'type'       => 'separator',
      'required' => [ 'enableoffset', '=', true],
    ];
    $this->controls['animationduration'] = [
      'label'       => esc_html__( 'Duration', 'bricks' ),
      'type'        => 'number',
      'unit'      => 's',
      'inline'      => true,
      'css'     => [
          [
            'property' => '--transition-duration',
            'selector' => '',
          ],
        ],
      'placeholder' => '0.5s',
      'required' => [ 'enableoffset', '=', true],
    ];
    $this->controls['animationeasing'] = [
        'label'       => esc_html__( 'Easing', 'bricks' ),
        'type'        => 'text',
        'hasDynamicData' => false,
        'inline'      => true,
        'css'     => [
            [
              'property' => '--transition-easing',
              'selector' => '',
            ],
        ],
        'placeholder' => 'ease',
        'required' => [ 'enableoffset', '=', true],
    ];

    //Responsive
    $this->controls['enablemobilemenu'] = [
      'group'       => 'responsive',
      'label' => esc_html__( 'Enable Mobile Menu', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => false,
    ];

    $this->controls['note'] = [
      'group'       => 'responsive',
      'description' => sprintf(html_entity_decode(esc_html__( 'Select a breakpoint to determine at which pixel to display Core Burguer and hide Items Wrapper.', 'bricks' ))),
      'required' => [ 'enablemobilemenu', '=', true],
    ];

    //Breakpoints control
		$breakpoints        = Breakpoints::$breakpoints;
		$breakpoint_options = [];

		foreach ( $breakpoints as $index => $breakpoint ) {
			$breakpoint_options[ $breakpoint['key'] ] = $breakpoint['label'];
		}

		$this->controls['mobileMenu'] = [
			'group'       => 'responsive',
			'type'        => 'select',
			'options'     => $breakpoint_options,
			'rerender'    => true,
			'placeholder' => esc_html__( 'Mobile landscape', 'bricks' ),
      'required' => [ 'enablemobilemenu', '=', true],
		];

    $this->controls['showonresponsivemedia'] = [
      'group'       => 'responsive',
      'label' => esc_html__( 'Show Items Wrapper', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => false,
      'required' => [ 'enablemobilemenu', '=', true],
    ];

    $this->controls['noteanimationtype'] = [
      'group'       => 'responsive',
      'description' => sprintf(html_entity_decode(esc_html__( 'Select an animation to display at mobile', 'bricks' ))),
      'required' => [ 'enablemobilemenu', '=', true],
    ];
    $this->controls['animationtype'] = [
      'group'			=> 'responsive',
      'tab'         => 'content',
      'label'       => esc_html__( 'Animation Type', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'opacity' => 'Opacity',
          'translatexleft' => 'From Left',
          'translatexright' => 'From Right',
      ],
      'inline'      => true,
      'placeholder' => 'Opacity',
      'required' => [ 'enablemobilemenu', '=', true],
    ];
    $this->controls['animationdurationresponsive'] = [
      'group'			=> 'responsive',
      'label'       => esc_html__( 'Animation Duration', 'bricks' ),
      'type'     => 'number',
      'unit'    => 's',
      'inline'      => true,
      'css'     => [
        [
          'property' => '--transition-duration-responsive',
          'selector' => '',
        ],
      ],
      'placeholder' => '0.3s',
      'required' => [ 'enablemobilemenu', '=', true],
    ];
    $this->controls['animationdelayresponsive'] = [
      'group'			=> 'responsive',
      'label'       => esc_html__( 'Animation Delay', 'bricks' ),
      'type'     => 'number',
      'unit'    => 's',
      'inline'      => true,
      'css'     => [
        [
          'property' => '--transition-delay-responsive',
          'selector' => '',
        ],
      ],
      'placeholder' => '0s',
      'required' => [ 'enablemobilemenu', '=', true],
    ];
    $this->controls['animationeaseresponsive'] = [
      'group'			=> 'responsive',
      'label'       => esc_html__( 'Animation Easing', 'bricks' ),
      'type'     => 'text',
      'inline'      => true,
      'css'     => [
        [
          'property' => '--transition-ease-responsive',
          'selector' => '',
        ],
      ],
      'placeholder' => 'ease',
      'required' => [ 'enablemobilemenu', '=', true],
    ];
  }
  
/*Render children*/
public function get_nestable_children() {
return [
    [
        'name'     => 'coreburguer',
        'label'    => esc_html__( 'Core Burguer', 'bricks' ),
        'settings' => [
          '_hidden' => [
              '_cssClasses' => 'bc-core-burguer--stickynav-menu',
          ],
        ],
    ],

    [
        'name'     => 'block',
        'label'    => esc_html__( 'Nav', 'bricks' ),
        'settings' => [
          '_hidden'  => [
              '_cssClasses' => 'bc-stickynav-menu__items-wrapper',
          ],
        ],
        'children' => [
        [
            'name'     => 'swap-hover',
        ],
        [
            'name'     => 'swap-hover',
        ],
        [
            'name'     => 'swap-hover',
        ],
        ],
    ],
];
}

  public function enqueue_scripts() {
    wp_enqueue_script( 'stickynav-menu-js', plugin_dir_url( __FILE__ ) . 'js/bc_sticky_nav.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $enableoffset = ! empty( $settings['enableoffset'] ) ? $settings['enableoffset'] : false;
    $offset = ! empty( $settings['offset'] ) ? $settings['offset'] : 100;

    $this->set_attribute( '_root', 'class', 'bc-core-menu' );
    $this->set_attribute( '_root', 'class', 'bc-stickynav-menu' );
    $this->set_attribute( '_root', 'data-enableoffset', $enableoffset );
    $this->set_attribute( '_root', 'data-offset', $offset );


    $enablemobilemenu = ! empty( $settings['enablemobilemenu'] ) ? $settings['enablemobilemenu'] : false;
    $showonresponsivemedia = ! empty( $settings['showonresponsivemedia'] ) ? $settings['showonresponsivemedia'] : false;
    $animationtype = ! empty( $settings['animationtype'] ) ? $settings['animationtype'] : 'opacity';

    $show_nav_button_at = ! empty( $settings['mobileMenu'] ) ? $settings['mobileMenu'] : 'mobile_landscape';
    $breakpoint = Breakpoints::get_breakpoint_by( 'key', $show_nav_button_at );
    $breakpoint_width    = ! empty( $breakpoint['width'] ) ? intval( $breakpoint['width'] ) : 0;

    $this->set_attribute( '_root', 'data-enable-mobile-menu', $enablemobilemenu );
    $this->set_attribute( '_root', 'data-breakpoint', $breakpoint_width );
    $this->set_attribute( '_root', 'data-animationtype', $animationtype );
    if($showonresponsivemedia && $enablemobilemenu){
      $this->set_attribute( '_root', 'data-class', 'bc-stickynav-menu--responsive-media' );
    }

    $output = "<div {$this->render_attributes( '_root' )}>";
    $output .= Frontend::render_children( $this ); //Menu items
    $output .= '</div>';





    $animationtype_inline_css = '';
    if($animationtype == 'opacity'){
      $animationtype_inline_css = 'transition: opacity var(--transition-duration-responsive) var(--transition-delay-responsive); transition-timing-function: var(--transition-delay-ease); opacity: 0;';
    }
    if($animationtype == 'translatexleft'){
      $animationtype_inline_css = "transition: left var(--transition-duration-responsive) var(--transition-delay-responsive); transition-timing-function: var(--transition-delay-ease); left: -100svw;";
    }
    if($animationtype == 'translatexright'){
      $animationtype_inline_css = "transition: left var(--transition-duration-responsive) var(--transition-delay-responsive); transition-timing-function: var(--transition-delay-ease); left: 100svw;";
    }

    //Media Query en el Front (no flick ya que se carga primero)
    //Hay que hacer Media Query en el JS igual a este mediante data-atributo ya que no se carga en el builder
    $nav_menu_inline_css = '';

    if($enablemobilemenu){
      $nav_menu_inline_css .= "@media (max-width: {$breakpoint_width}px) {";
      $nav_menu_inline_css .= "[data-script-id={$this->id}] .bc-core-burguer--stickynav-menu { display: flex; }";
      $nav_menu_inline_css .= "[data-script-id={$this->id}] .bc-stickynav-menu__items-wrapper { pointer-events: none; $animationtype_inline_css }";
      $nav_menu_inline_css .= '}';
  
      $output .= "<style>$nav_menu_inline_css</style>";
    }

    echo $output;
  }
}