<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Stripe_megaMenu extends Element {
  public $category     = 'Brickscore - Menus';
  public $name         = 'stripemegamenu';
  public $icon         = 'ti-layout-media-right';
  public $scripts      = ['stripemegamenu'];
  public $nestable     = true;

public function get_label() {
    return esc_html__( 'Stripe megaMenu', 'bricks' );
}

public function set_control_groups() {
    $this->control_groups['responsive'] = [
        'title' => esc_html__( 'Responsive', 'bricks' ),
        'tab'   => 'content',
    ];
}

public function set_controls() {
    $this->controls['arrowSeparator'] = [
        'label'      => esc_html__( 'Arrow', 'bricks' ),
        'type'       => 'separator',
    ];
    $this->controls['enablearrow'] = [
        'label' => esc_html__( 'Enable arrow', 'bricks' ),
        'type' => 'checkbox',
        'inline' => true,
        'small' => true,
        'default' => true,
    ];
    $this->controls['arrowsize'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Arrow size', 'bricks' ),
        'type'        => 'number',
        'units'        => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => '--arrow-size',
              'selector' => '',
            ],
        ],
        'placeholder' => '8px',
        'required' => [ 'enablearrow', '=', true],
    ];
    $this->controls['arrowcolor'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Arrow color', 'bricks' ),
        'type'        => 'color',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--arrow-color',
              'selector' => '',
            ],
        ],
        'required' => [ 'enablearrow', '=', true],
    ];

    $this->controls['dropdownSeparator'] = [
        'label'      => esc_html__( 'Dropdown', 'bricks' ),
        'type'       => 'separator',
    ];
    $this->controls['dropdownpadding'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Padding', 'bricks' ),
        'type'        => 'spacing',
        'css'     => [
            [
              'property' => 'padding',
              'selector' => '.bc-stripe__dropdown-list .bc-stripe__content',
            ],
        ],
    ];
    $this->controls['dropdownbackground'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Background', 'bricks' ),
        'type'        => 'background',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'background',
              'selector' => '.bc-stripe__dropdown-list',
            ],
        ],
    ];
    $this->controls['dropdownborder'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '.bc-stripe__dropdown-list',
            ],
        ],
    ];
    $this->controls['dropdownboxshadow'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Box shadow', 'bricks' ),
        'type'        => 'box-shadow',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'box-shadow',
              'selector' => '.bc-stripe__dropdown-list',
            ],
        ],
    ];
    $this->controls['topdistance'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Top distance', 'bricks' ),
        'type'        => 'number',
        'units'        => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => '--top-distance',
              'selector' => '',
            ],
        ],
        'placeholder' => '60px',
    ];
    $this->controls['fromtranslation'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'From translation', 'bricks' ),
        'type'        => 'number',
        'units'        => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => '--from-distance',
              'selector' => '',
            ],
        ],
        'placeholder' => '20px',
    ];
    $this->controls['fromduration'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'From duration', 'bricks' ),
        'type'        => 'number',
        'unit'        => 's',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--from-duration',
              'selector' => '',
            ],
        ],
        'placeholder' => '0.3s',
    ];
    $this->controls['stripeSeparator'] = [
        'label'      => esc_html__( 'Stripe', 'bricks' ),
        'type'       => 'separator',
    ];
    $this->controls['stripedistance'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Stripe path', 'bricks' ),
        'type'        => 'number',
        'units'        => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => '--stripe-distance',
              'selector' => '',
            ],
        ],
        'placeholder' => '100px',
    ];
    $this->controls['stripeduration'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Stripe duration', 'bricks' ),
        'type'        => 'number',
        'unit'        => 's',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--stripe-duration',
              'selector' => '',
            ],
        ],
        'placeholder' => '0.3s',
    ];
    $this->controls['opacityduration'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'Opacity duration', 'bricks' ),
        'type'        => 'number',
        'unit'        => 's',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--opacity-duration',
              'selector' => '',
            ],
        ],
        'placeholder' => '0.3s',
    ];

    //Responsive
    $this->controls['enablemobilemenu'] = [
      'group'       => 'responsive',
      'label' => esc_html__( 'Enable Mobile Menu', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'small' => true,
      'default' => false,
    ];

    $this->controls['note'] = [
        'group'       => 'responsive',
        'description' => sprintf(html_entity_decode(esc_html__( 'Select a breakpoint to determine at which pixel to display Core Burguer and Menu.', 'bricks' ))),
        'required' => [ 'enablemobilemenu', '=', true],
    ];

    //Breakpoints control
    $breakpoints        = Breakpoints::$breakpoints;
    $breakpoint_options = [];

    foreach ( $breakpoints as $index => $breakpoint ) {
        $breakpoint_options[ $breakpoint['key'] ] = $breakpoint['label'];
    }

    $this->controls['mobileMenu'] = [
        'group'       => 'responsive',
        'type'        => 'select',
        'options'     => $breakpoint_options,
        'rerender'    => true,
        'placeholder' => esc_html__( 'Mobile landscape', 'bricks' ),
        'required' => [ 'enablemobilemenu', '=', true],
    ];
}

public function get_nestable_children() {
    return [
        [
            'name'     => 'coreburguer',
            'settings' => [
                '_hidden'  => [
                    '_cssClasses' => 'bc-stripe__coreburguer',
                ],
              ],
        ],

        [
            'name'     => 'block',
            'label'    => esc_html__( 'Nav', 'bricks' ),
            'settings' => [
              '_hidden'  => [
                  '_cssClasses' => 'bc-stripe__main-nav',
              ],
            ],
            'children' => [
            [
                'name'     => 'heading',
                'label'    => esc_html__( 'Nav Item', 'bricks' ),
                'settings' => [
                    'text' => esc_html__( 'About', 'bricks' ),
                    'tag'  => 'span',
                    '_hidden'  => [
                        '_cssClasses' => 'bc-stripe__has-dropdown',
                    ],
                    '_attributes' => [
                        [
                        'name' => 'tabindex',
                        'value' => '0',
                        ],
                    ]
                ],
            ],
            [
                'name'     => 'heading',
                'label'    => esc_html__( 'Nav Item', 'bricks' ),
                'settings' => [
                    'text' => esc_html__( 'Stories', 'bricks' ),
                    'tag'  => 'span',
                    '_hidden'  => [
                        '_cssClasses' => 'bc-stripe__has-dropdown',
                    ],
                    '_attributes' => [
                        [
                        'name' => 'tabindex',
                        'value' => '0',
                        ],
                    ]
                ],
            ],
            [
                'name'     => 'heading',
                'label'    => esc_html__( 'Nav Item', 'bricks' ),
                'settings' => [
                    'text' => esc_html__( 'Contact', 'bricks' ),
                    'tag'  => 'span',
                    '_hidden'  => [
                        '_cssClasses' => 'bc-stripe__has-dropdown',
                    ],
                    '_attributes' => [
                        [
                        'name' => 'tabindex',
                        'value' => '0',
                        ],
                    ]
                ],
            ],
            ],
        ],
    
        [
            'name' => 'stripemmdropdownlist',
            'children' => [
                [
                    'name'     => 'stripemmdropdownitem',
                    'label'    => esc_html__( 'Dropdown', 'bricks' ),
                    'children' => [
                        [
                            'name'     => 'heading',
                            'label'    => esc_html__( 'Mobile Nav Item', 'bricks' ),
                            'settings' => [
                                'text' => esc_html__( 'About', 'bricks' ),
                                'tag'  => 'span',
                                '_hidden'  => [
                                    '_cssClasses' => 'bc-stripe__label',
                                ],
                            ],
                        ],
                        [
                            'name'     => 'text-basic',
                            'label'    => esc_html__( 'Basic Text', 'bricks' ),
                            'settings' => [
                                'text' => esc_html__( 'Place the content you want at the Dropdown without deleting its Mobile Nav Item', 'bricks' ),
                                'tag'  => 'p',
                                '_hidden'  => [
                                    '_cssClasses' => 'bc-stripe__paragraph-test',
                                ],
                            ],
                        ],
                    ],
                ],
                [
                    'name'     => 'stripemmdropdownitem',
                    'label'    => esc_html__( 'Dropdown', 'bricks' ),
                    'children' => [
                        [
                            'name'     => 'heading',
                            'label'    => esc_html__( 'Mobile Nav Item', 'bricks' ),
                            'settings' => [
                                'text' => esc_html__( 'Stories', 'bricks' ),
                                'tag'  => 'span',
                                '_hidden'  => [
                                    '_cssClasses' => 'bc-stripe__label',
                                ],
                            ],
                        ],
                        [
                            'name'     => 'text-basic',
                            'label'    => esc_html__( 'Basic Text', 'bricks' ),
                            'settings' => [
                                'text' => esc_html__( 'Place the content you want at the Dropdown without deleting its Mobile Nav Item', 'bricks' ),
                                'tag'  => 'p',
                                '_hidden'  => [
                                    '_cssClasses' => 'bc-stripe__paragraph-test bc-stripe__paragraph-test--v2',
                                ],
                            ],
                        ],
                    ],
                ],
                [
                    'name'     => 'stripemmdropdownitem',
                    'label'    => esc_html__( 'Dropdown', 'bricks' ),
                    'children' => [
                        [
                            'name'     => 'heading',
                            'label'    => esc_html__( 'Mobile Nav Item', 'bricks' ),
                            'settings' => [
                                'text' => esc_html__( 'Contact', 'bricks' ),
                                'tag'  => 'span',
                                '_hidden'  => [
                                    '_cssClasses' => 'bc-stripe__label',
                                ],
                            ],
                        ],
                        [
                            'name'     => 'text-basic',
                            'label'    => esc_html__( 'Basic Text', 'bricks' ),
                            'settings' => [
                                'text' => esc_html__( 'Place the content you want at the Dropdown without deleting its Mobile Nav Item.', 'bricks' ),
                                'tag'  => 'p',
                                '_hidden'  => [
                                    '_cssClasses' => 'bc-stripe__paragraph-test',
                                ],
                            ],
                        ],
                    ],
                ],
            ],
        ],
    ];
}

public function enqueue_scripts() {
    wp_enqueue_script( 'stripe-megamenu', plugin_dir_url( __FILE__ ) . 'js/bc_stripe_megamenu.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);

    wp_enqueue_script( 'brickscore-jquery', plugin_dir_url( __FILE__ ) . '../local_assets/bc_jquery.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
}

public function render() {
    $settings = $this->settings;
    $enablearrow = ! empty( $settings['enablearrow'] ) ? $settings['enablearrow'] : false;
    $enablemobilemenu = ! empty( $settings['enablemobilemenu'] ) ? $settings['enablemobilemenu'] : false;
    $show_nav_button_at = ! empty( $settings['mobileMenu'] ) ? $settings['mobileMenu'] : 'mobile_landscape';
    $breakpoint = Breakpoints::get_breakpoint_by( 'key', $show_nav_button_at );
    $breakpoint_width    = ! empty( $breakpoint['width'] ) ? intval( $breakpoint['width'] ) : 0;

    $this->set_attribute( '_root', 'class', 'bc-stripe' );
    $this->set_attribute( '_root', 'data-enablemobilemenu', $enablemobilemenu );
    $this->set_attribute( '_root', 'data-breakpoint', $breakpoint_width );

    if($enablearrow){
        $this->set_attribute( '_root', 'data-arrow', 'arrow-enable' );
    }

    $output = "
    <div {$this->render_attributes( '_root' )}>
    <a href='#0' class='bc-stripe__nav-trigger'>Open Nav<span aria-hidden='true'></span></a>";
    $output .= Frontend::render_children( $this );
    $output .= "</div>";

    $nav_menu_inline_css = '';
    if($enablemobilemenu){
        $nav_menu_inline_css .= "@media (max-width: {$breakpoint_width}px) {";
        $nav_menu_inline_css .= "
        [data-script-id={$this->id}] .bc-stripe__dropdown-list, 
        [data-script-id={$this->id}] .bc-stripe__dropdown, 
        [data-script-id={$this->id}] .bc-stripe__morph-dropdown-wrapper{ 
          all: unset;
        }
        [data-script-id={$this->id}] .bc-stripe::before{
          content: 'mobile';
          display: none;
        }
        [data-script-id={$this->id}] .bc-stripe__main-nav{
          display: none;
        }
        [data-script-id={$this->id}] .bc-stripe__content .bc-stripe__dropdown::after{
          clear: both;
          content: '';
        }
        [data-script-id={$this->id}][data-open='bc-stripe--opened'] .bc-stripe__morph-dropdown-wrapper{
          display: block;
        }
        [data-script-id={$this->id}] .bc-stripe__morph-dropdown-wrapper{
          display: none;
          position: absolute;
    
          top: 0;
          left: 0;
          width: 100%;
        }
        [data-script-id={$this->id}] .bc-stripe__label{
          display: block;
        }
        [data-script-id={$this->id}] .bc-stripe__coreburguer{
          display: flex;
  
          position: absolute;
          z-index: 10;
          top: 10px;
          right: 10px;
        }
        ";
        $nav_menu_inline_css .= '}';
    
        $output .= "<style>$nav_menu_inline_css</style>";
    }

    echo $output;
}
}