<?php
namespace Bricks;
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Sub_Offcanvas extends \Bricks\Element {
  public $name         = 'suboffcanvas';
  public $icon         = 'ti-layout-width-full';
  public $scripts      = ['multioffcanvasmenu'];
  public $nestable     = true;

  public function get_label() {
    return esc_html__( 'Sub OffCanvas', 'bricks' );
  }

  public function set_controls() {    
    $this->controls['opentoggle'] = [
        'label'       => esc_html__( 'Open toggle', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'placeholder' => '.className',
    ];
    $this->controls['closetoggle'] = [
        'label'       => esc_html__( 'Close toggle', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'placeholder' => '.className',
    ];

    $this->controls['styleSeparator'] = [
        'label'      => esc_html__( 'Style', 'bricks' ),
        'type'       => 'separator',
    ];
    $this->controls['width'] = [
        'label'       => esc_html__( 'Width', 'bricks' ),
        'type'        => 'number',
        'units'      => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => 'width',
              'selector' => '',
            ],
        ],
        'placeholder' => '50vw',
    ];
    $this->controls['height'] = [
        'label'       => esc_html__( 'Height', 'bricks' ),
        'type'        => 'number',
        'units'      => true,
        'inline'      => true,
        'css'     => [
            [
              'property' => 'height',
              'selector' => '',
            ],
        ],
        'placeholder' => '100vh',
    ];
    $this->controls['padding'] = [
        'label'       => esc_html__( 'Padding', 'bricks' ),
        'type'        => 'spacing',
        'css'     => [
            [
              'property' => 'padding',
              'selector' => '',
            ],
        ],
    ];
    $this->controls['background'] = [
        'label'       => esc_html__( 'Background', 'bricks' ),
        'type'        => 'background',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'background',
              'selector' => '',
            ],
        ],
    ];
    $this->controls['border'] = [
        'label'       => esc_html__( 'Border', 'bricks' ),
        'type'        => 'border',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'border',
              'selector' => '',
            ],
        ],
    ];
    $this->controls['boxShadow'] = [
        'label'       => esc_html__( 'Box shadow', 'bricks' ),
        'type'        => 'box-shadow',
        'inline'      => true,
        'css'     => [
            [
              'property' => 'box-shadow',
              'selector' => '',
            ],
        ],
    ];

    $this->controls['animationSeparator'] = [
        'label'      => esc_html__( 'Animation', 'bricks' ),
        'type'       => 'separator',
    ];
    $this->controls['subcanvasduration'] = [
        'label'       => esc_html__( 'Duration', 'bricks' ),
        'type'        => 'number',
        'unit'        => 's',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--subcanvas-duration',
              'selector' => '',
            ],
          ],
        'placeholder' => '1s',
    ];
    $this->controls['subcanvaseasing'] = [
        'label'       => esc_html__( 'Easing', 'bricks' ),
        'type'        => 'text',
        'inline'      => true,
        'css'     => [
            [
              'property' => '--subcanvas-easing',
              'selector' => '',
            ],
          ],
        'placeholder' => 'cubic-bezier(.33,1,.68,1)',
    ];
  }

  public function enqueue_scripts() {
    wp_enqueue_script( 'multioffcanvas-menu-js', plugin_dir_url( __FILE__ ) . 'js/bc_multioffcanvas.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $opentoggle = ! empty( $settings['opentoggle'] ) ? $settings['opentoggle'] : '';
    $closetoggle = ! empty( $settings['closetoggle'] ) ? $settings['closetoggle'] : '';

    $this->set_attribute( '_root', 'class', 'bc-multi-offcanvas-menu__subcanvas' );
    $this->set_attribute( '_root', 'tabindex', '0' );
    $this->set_attribute( '_root', 'data-opentoggle', $opentoggle );
    $this->set_attribute( '_root', 'data-closetoggle', $closetoggle );

    $output = "<div {$this->render_attributes( '_root' )}>";
    $output .= Frontend::render_children( $this ); //Menu items
    $output .= '</div>';

    echo $output;
  }
}