<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_SVG_Title extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'svgtitle';
  public $icon         = 'ti-text';
  public $tag      = 'h3';
  public $css_selector = '';
  public $scripts      = ['svgtitle'];

  public function get_label() {
    return esc_html__( 'SVG Reveal', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['animation'] = [
        'title' => esc_html__( 'Animation', 'bricks' ),
        'tab'   => 'content',
      ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
      'tab'            => 'content',
      'type'           => 'text',
	  'hasDynamicData' => 'text',
      'default'        => esc_html__( 'SVG Reveal', 'bricks' ),
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['tag'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'HTML tag', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'h1' => 'h1',
            'h2' => 'h2',
            'h3' => 'h3',
            'h4' => 'h4',
            'h5' => 'h5',
            'h6' => 'h6',
            'p' => 'p',
            'span' => 'span',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'h3',
        'default'     => 'h3',
    ];
    $this->controls['titleTypography'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Title typography', 'bricks' ),
        'type'    => 'typography',
        'css'     => [
          [
            'property' => 'typography',
            'selector' => '.bc-svg-title__element text',
          ],
        ],
    ];
    $this->controls['fill'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Fill', 'bricks' ),
        'type'    => 'color',
        'css'     => [
          [
            'property' => 'fill',
            'selector' => '.bc-svg-title__element text',
          ],
        ],
    ];
    $this->controls['strokecolor'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Stroke color', 'bricks' ),
        'type'    => 'color',
        'css'     => [
          [
            'property' => 'stroke',
            'selector' => '.bc-svg-title__element text',
          ],
        ],
    ];
    $this->controls['strokewidth'] = [
        'inline' => true,
        'tab'     => 'content',
        'label'   => esc_html__( 'Stroke width', 'bricks' ),
        'type'    => 'text',
        'css'     => [
          [
            'property' => 'stroke-width',
            'selector' => '.bc-svg-title__element text',
          ],
        ],
        'placeholder' => '1',
    ];
    $this->controls['width'] = [
        'inline' => true,
        'tab'     => 'content',
        'label'   => esc_html__( 'Width', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'css'     => [
          [
            'property' => 'width',
            'selector' => '.bc-svg-title__element',
          ],
        ],
        'placeholder' => '450px',
    ];
    $this->controls['height'] = [
        'inline' => true,
        'tab'     => 'content',
        'label'   => esc_html__( 'Height', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'css'     => [
          [
            'property' => 'height',
            'selector' => '.bc-svg-title__element',
          ],
        ],
        'placeholder' => 'auto',
    ];
    $this->controls['animationduration'] = [
        'inline' => true,
        'group'   => 'animation',
        'tab'     => 'content',
        'label'   => esc_html__( 'Animation duration', 'bricks' ),
        'type' => 'number',
        'unit' => 's',
        'css'     => [
          [
            'property' => '--animation-duration',
            'selector' => '',
          ],
        ],
        'placeholder' => '5s',
    ];

    $this->controls['animationdelay'] = [
      'inline' => true,
      'group'   => 'animation',
      'tab'     => 'content',
      'label'   => esc_html__( 'Animation delay', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'css'     => [
        [
          'property' => '--animation-delay',
          'selector' => '',
        ],
      ],
      'placeholder' => '0.2s',
    ];

    $this->controls['scrolltrigger'] = [
      'group'   => 'animation',
      'label'      => esc_html__( 'SrollTrigger', 'bricks' ),
      'type'       => 'separator',
      'description' => sprintf(esc_html__( 'Scrolltrigger %s', 'bricks' ), '<a href="https://greensock.com/docs/v3/Plugins/ScrollTrigger" target="_blank">documentation</a>'),
    ];

    $this->controls['start'] = [
      'hasDynamicData' => false,
        'tab' => 'content',
        'group'   => 'animation',
        'label' => esc_html__( 'Start', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'top bottom',
    ];
    $this->controls['replay'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label'    => esc_html__( 'Replay on enter back', 'bricks' ),
      'type'     => 'checkbox',
      'group'   => 'animation',
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'svgtitle', plugin_dir_url( __FILE__ ) . 'js/bc_svg_title.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Bricks';
    $start = ! empty( $settings['start'] ) ? $settings['start'] : 'top bottom';
    $replay = ! empty( $settings['replay'] ) ? $settings['replay'] : 0;

    $this->set_attribute( 'inner_title', 'data-start', "$start");

    if ( ! $inner_title ) {
      return $this->render_element_placeholder( [
        'icon-class'  => 'ti-paragraph',
        'inner_title'       => esc_html__( 'Please add a title.', 'bricks' ),
		    'description' => esc_html__( 'Here goes the element placeholder description (optional).', 'bricks' ),
      ] );
    }

    $this->set_attribute( '_root', 'class', 'bc-svg-title' );
    $this->set_attribute( 'inner_title', 'data-replay', "$replay");
    $output = "<div {$this->render_attributes( '_root' )}>";

    $output .=
    "<{$this->tag}>
      <svg class='bc-svg-title__element' {$this->render_attributes( 'inner_title' )}>
        <text text-anchor='middle' alignment-baseline='middle' x='50%' y='50%'>
          $inner_title
        </text>
      </svg>
    </{$this->tag}>";

    $output .= '</div>';


		echo $output;
  }
}
