<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Swap_Hover extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'swap-hover';
  public $icon         = 'ti-text';
  public $tag      = 'h3';
  public $css_selector = '';
  public $scripts      = ['swap_hover'];

  public function get_label() {
    return esc_html__( 'Swap Hover', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['animation'] = [
      'title' => esc_html__( 'Animation', 'bricks' ),
      'tab'   => 'content',
    ];
    $this->control_groups['gradient'] = [
      'title' => esc_html__( 'Gradient', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
      'label'       => esc_html__( 'Title', 'bricks' ),
      'tab'            => 'content',
      'type'           => 'text',
      'hasDynamicData' => 'text',
      'default'        => esc_html__( 'Swap Hover', 'bricks' ),
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['tag'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'HTML tag', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'h1' => 'h1',
            'h2' => 'h2',
            'h3' => 'h3',
            'h4' => 'h4',
            'h5' => 'h5',
            'h6' => 'h6',
            'p' => 'p',
            'span' => 'span',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'h3',
        'default'     => 'h3',
    ];
    $this->controls['link'] = [
			'tab'   => 'content',
			'label' => esc_html__( 'Link to', 'bricks' ),
			'type'  => 'link',
		];
    $this->controls['titleTypography'] = [
      'tab'     => 'content',
      'label'   => esc_html__( 'Typography', 'bricks' ),
      'type'    => 'typography',
			'css'     => [
        [
          'property' => 'typography',
          'selector' => '.bc-swap-title__element',
        ],
      ],
    ];
    $this->controls['titlepadding'] = [
      'hasDynamicData' => false,
      'tab'     => 'content',
      'label'   => esc_html__( 'Swap padding', 'bricks' ),
      'type'        => 'dimensions',
      'css'     => [
          [
            'property' => 'padding',
            'selector' => '.bc-swap-title__element',
          ],
        ],
        'placeholder' => [
          'top' => 0,
          'right' => 0,
          'bottom' => 0,
          'left' => 0,
        ],
    ];
    $this->controls['type'] = [
      'group'   => 'animation',
      'hasDynamicData' => false,
      'tab'         => 'content',
      'label'       => esc_html__( 'Type', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'line' => 'line',
          'words' => 'words',
          'chars' => 'chars',
      ],
      'clearable'   => false,
      'inline'      => true,
      'placeholder' => 'line',
      'default' => 'line',
  ];
  $this->controls['swap_title'] = [
    'group'   => 'animation',
    'label'       => esc_html__( 'Custom Swap title', 'bricks' ),
    'tab'            => 'content',
    'type'           => 'text',
    'hasDynamicData' => 'text',
    'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    'required' => [ 'type', '=', 'line'],
  ];
  $this->controls['from'] = [
    'group'   => 'animation',
    'hasDynamicData' => false,
    'tab'         => 'content',
    'label'       => esc_html__( 'From', 'bricks' ),
    'type'        => 'select',
    'options'     => [
        '-1' => 'top',
        '1' => 'bottom',
    ],
    'css'     => [
      [
        'property' => '--fromtype',
        'selector' => '.bc-swap-title__span, .bc-swap-title__span .char, .bc-swap-title__span .word',
      ],
    ],
    'clearable'   => false,
    'inline'      => true,
    'placeholder' => 'bottom',
    'default' => '1',
];
  $this->controls['skew'] = [
    'group'   => 'animation',
    'hasDynamicData' => false,
    'tab' => 'content',
    'label' => esc_html__( 'Skew', 'bricks' ),
    'type' => 'number',
    'unit' => 'deg',
    'small' => true,
    'inline' => true,
    'css'     => [
      [
        'property' => '--skew',
        'selector' => '.bc-swap-title__span, .bc-swap-title__span .char, .bc-swap-title__span .word',
      ],
    ],
    'placeholder' => '0',
  ];
  $this->controls['stagger'] = [
    'group'   => 'animation',
    'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Stagger', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'small' => true,
      'placeholder' => '0.25',
  ];
    $this->controls['duration'] = [
      'group'   => 'animation',
      'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Duration', 'bricks' ),
        'type' => 'number',
        'unit' => 's',
        'small' => true,
        'inline' => true,
        'css'     => [
          [
            'property' => '--duration',
            'selector' => '.bc-swap-title__span, .bc-swap-title__span .char, .bc-swap-title__span .word',
          ],
        ],
        'placeholder' => '1s',
    ];
    $this->controls['ease'] = [
      'group'   => 'animation',
      'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Ease', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'css'     => [
          [
            'property' => '--ease',
            'selector' => '.bc-swap-title__span, .bc-swap-title__span .char, .bc-swap-title__span .word',
          ],
        ],
        'placeholder' => 'cubic-bezier(0.19, 1, 0.22, 1)',
    ];

    //Gradient
    $this->controls['titleGradient'] = [
      'group' => 'gradient',
      'tab' => 'content',
      'type' => 'gradient',
      'css' => [
        [
          'property' => 'background-image',
          'selector' => '.bc-swap-title__span, .bc-swap-title__span::after',
        ],
      ],
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'swap_title', plugin_dir_url( __FILE__ ) . 'js/bc_swap_title.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $swap_title    = ! empty( $settings['swap_title'] ) ? $settings['swap_title'] : '';
    $type    = ! empty( $settings['type'] ) ? $settings['type'] : 'line';
    $stagger    = ! empty( $settings['stagger'] ) ? $settings['stagger'] : '0.25';

		if ( ! empty( $settings['link'] ) ) {
			$this->set_link_attributes( '_root', $settings['link'] );
		}

    $this->set_attribute( '_root', 'class', 'bc-swap-title' );
    $output = "<a {$this->render_attributes( '_root' )}>";

    if ( $inner_title ) {
      $this->set_attribute( 'inner_title', 'class', 'bc-swap-title__element' );
      $this->set_attribute( 'inner_title', 'data-inner', "$swap_title" );
      $this->set_attribute( 'inner_title', 'data-type', "$type" );
      $this->set_attribute( 'inner_title', 'data-stagger', "$stagger" );

      if ($type === 'words' || $type === 'chars') {
        $this->set_attribute('inner_title', 'class', 'bc-swap-title__remove-line');
      }

      $output .=
      "<{$this->tag} {$this->render_attributes( 'inner_title' )}>
        <span class='bc-swap-title__span-wrapper'>
            <span class='bc-swap-title__span'>$inner_title</span>
        </span>
      </{$this->tag}>";
    }
    $output .= '</a>';

	echo $output;
  }
}

