<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Twist_Title extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = '3d-title';
  public $icon         = 'ti-text';
  public $tag      = 'h3';
  public $css_selector = '';
	public $scripts      = ['twist_title'];

  public function get_label() {
    return esc_html__( 'Twist Reveal', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['animation'] = [
      'title' => esc_html__( 'Animation', 'bricks' ),
      'tab'   => 'content',
    ];
    $this->control_groups['gradient'] = [
      'title' => esc_html__( 'Gradient', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
      'tab'            => 'content',
      'type'           => 'text',
			'hasDynamicData' => 'text',
      'default'        => esc_html__( 'Twist Reveal', 'bricks' ),
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];

    $this->controls['tag'] = [
			'tab'         => 'content',
			'label'       => esc_html__( 'HTML tag', 'bricks' ),
			'type'        => 'select',
			'options'     => [
				'h1' => 'h1',
				'h2' => 'h2',
				'h3' => 'h3',
				'h4' => 'h4',
				'h5' => 'h5',
				'h6' => 'h6',
        'p' => 'p',
        'span' => 'span',
			],
			'clearable'   => false,
			'inline'      => true,
			'placeholder' => 'h3',
			'default'     => 'h3',
		];

    $this->controls['titleTypography'] = [
      'tab'     => 'content',
      'label'   => esc_html__( 'Title typography', 'bricks' ),
      'type'    => 'typography',
			'css'     => [
        [
          'property' => 'typography',
          'selector' => '.bc-twist-title__element',
        ],
      ],
    ];

    $this->controls['perspective'] = [
      'tab' => 'content',
      'group'   => 'animation',
      'label' => esc_html__( 'Perspective', 'bricks' ),
      'type' => 'number',
      'unit' => 'px',
      'inline' => true,
      'placeholder' => '200px',
    ];

    $this->controls['duration'] = [
      'tab' => 'content',
      'group'   => 'animation',
      'label' => esc_html__( 'Duration', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'inline' => true,
      'placeholder' => '1s',
    ];

    $this->controls['scrolltrigger'] = [
      'group'   => 'animation',
      'label'      => esc_html__( 'SrollTrigger', 'bricks' ),
      'type'       => 'separator',
      'description' => sprintf(esc_html__( 'Scrolltrigger %s', 'bricks' ), '<a href="https://greensock.com/docs/v3/Plugins/ScrollTrigger" target="_blank">documentation</a>'),
    ];

    $this->controls['start'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'group'   => 'animation',
      'label' => esc_html__( 'Start', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 'top bottom',
    ];

    $this->controls['delay'] = [
      'tab' => 'content',
      'group'   => 'animation',
      'label' => esc_html__( 'Delay', 'bricks' ),
      'type' => 'number',
      'unit' => 's',
      'inline' => true,
      'placeholder' => '0.2s',
    ];

    $this->controls['replay'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label'    => esc_html__( 'Replay on enter back', 'bricks' ),
      'type'     => 'checkbox',
      'group'   => 'animation',
    ];

    //Gradient
    $this->controls['titleGradient'] = [
      'group' => 'gradient',
      'tab' => 'content',
      'type' => 'gradient',
      'css' => [
        [
          'property' => 'background-image',
          'selector' => '.bc-twist-title__span span',
        ],
      ],
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'twist_title', plugin_dir_url( __FILE__ ) . 'js/bc_twist_title.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $perspective = ! empty( $settings['perspective'] ) ? $settings['perspective'] : 200;
    $duration = ! empty( $settings['duration'] ) ? $settings['duration'] : 1;
    $delay = ! empty( $settings['delay'] ) ? $settings['delay'] : 0.2;
    $start = ! empty( $settings['start'] ) ? $settings['start'] : 'top bottom';
    $replay = ! empty( $settings['replay'] ) ? $settings['replay'] : 0;

    if ( ! $inner_title ) {
      return $this->render_element_placeholder( [
        'icon-class'  => 'ti-paragraph',
        'inner_title'       => esc_html__( 'Please add a title.', 'bricks' ),
				'description' => esc_html__( 'Here goes the element placeholder description (optional).', 'bricks' ),
      ] );
    }

    $this->set_attribute( '_root', 'class', 'bc-twist-title' );
    $output = "<div {$this->render_attributes( '_root' )}>";

    if ( $inner_title ) {
      $this->set_attribute( 'inner_title', 'class', 'bc-twist-title__element' );
      $this->set_attribute( 'inner_title', 'style', "perspective: " . intval($perspective) . "px;");
      $this->set_attribute( 'inner_title', 'data-start', "$start");
      $this->set_attribute( 'inner_title', 'data-replay', "$replay");
      $this->set_attribute( 'spanwrapper', 'class', 'bc-twist-title__span' );
      $this->set_attribute( 'spanwrapper', 'style', "transition-duration: " . floatval($duration) . "s;");
      $this->set_attribute( 'spanwrapper', 'style', "transition-delay: " . floatval($delay) . "s");


      $output .= //*cuerpo HTML
      "<{$this->tag} {$this->render_attributes( 'inner_title' )}>
        <span {$this->render_attributes( 'spanwrapper' )}>
          <span>$inner_title</span>
        </span>
      </{$this->tag}>";
    }

    $output .= '</div>';

		echo $output;
  }
}

