<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Underlined_Hover extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'underlined-hover';
  public $icon         = 'fa-solid fa-underline';
  public $tag      = 'h3';
  public $css_selector = '';
  public $scripts      = ['underlined_hover'];

  public function get_label() {
    return esc_html__( 'Underline Hover', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['underlinedgroup'] = [
      'title' => esc_html__( 'Underline', 'bricks' ),
      'tab'   => 'content',
    ];
    $this->control_groups['gradient'] = [
      'title' => esc_html__( 'Gradient', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
        'tab'            => 'content',
        'type'           => 'text',
        'hasDynamicData' => 'text',
        'default'        => esc_html__( 'Underline Hover', 'bricks' ),
        'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['tag'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'HTML tag', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'h1' => 'h1',
            'h2' => 'h2',
            'h3' => 'h3',
            'h4' => 'h4',
            'h5' => 'h5',
            'h6' => 'h6',
            'p' => 'p',
            'span' => 'span',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'h3',
        'default'     => 'h3',
    ];
    $this->controls['link'] = [
      'tab'   => 'content',
      'label' => esc_html__( 'Link to', 'bricks' ),
      'type'  => 'link',
    ];
    $this->controls['titleTypography'] = [
      'tab'     => 'content',
      'label'   => esc_html__( 'Title typography', 'bricks' ),
      'type'    => 'typography',
			'css'     => [
        [
          'property' => 'typography',
          'selector' => '.bc-underlined-title__element',
        ],
      ],
    ];
    $this->controls['type'] = [
        'group'			=> 'underlinedgroup',
        'tab'         => 'content',
        'label'       => esc_html__( 'Type', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'Side to Side' => 'Side to Side',
            'One Sided' => 'One Sided',
            'Two Sided' => 'Two Sided',
            'Full Sided' => 'Full Sided',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'Side to Side',
    ];
    $this->controls['colorunderline'] = [
      'group'			=> 'underlinedgroup',
      'tab'     => 'content',
      'label'   => esc_html__( 'Color', 'bricks' ),
      'type'    => 'color',
			'css'     => [
        [
          'property' => '--background',
          'selector' => '.bc-underlined-title__element',
        ],
      ],
    ];
    $this->controls['initialwidth'] = [
      'group'			=> 'underlinedgroup',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Initial width', 'bricks' ),
      'type'  => 'number',
      'units' => true,
      'inline' => true,
      'css'     => [
        [
          'property' => '--width',
          'selector' => '.bc-underlined-title__element',
        ],
      ],
      'placeholder' => '0px',
      'required' => [ 'type', '=', [ 'One Sided', 'Two Sided' ] ],
    ];
    $this->controls['height'] = [
      'group'			=> 'underlinedgroup',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Thickness', 'bricks' ),
      'type'  => 'number',
      'units' => true,
      'inline' => true,
      'css'     => [
        [
          'property' => '--height',
          'selector' => '.bc-underlined-title__element',
        ],
      ],
      'placeholder' => '1px',
    ];
    $this->controls['bottom'] = [
      'group'			=> 'underlinedgroup',
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Bottom distance', 'bricks' ),
      'type'  => 'number',
      'units' => true,
      'inline' => true,
      'css'     => [
        [
          'property' => '--bottom-distance',
          'selector' => '.bc-underlined-title__element',
        ],
      ],
      'placeholder' => '0px',
    ];
    $this->controls['duration'] = [
        'group'			=> 'underlinedgroup',
        'hasDynamicData' => false,
          'tab' => 'content',
          'label' => esc_html__( 'Duration', 'bricks' ),
          'type'  => 'number',
          'unit' => 's',
          'inline' => true,
          'css'     => [
            [
              'property' => '--duration',
              'selector' => '.bc-underlined-title__element',
            ],
          ],
          'placeholder' => '0.7s',
      ];
      $this->controls['ease'] = [
        'group'			=> 'underlinedgroup',
        'hasDynamicData' => false,
          'tab' => 'content',
          'label' => esc_html__( 'Ease', 'bricks' ),
          'type'  => 'text',
          'inline' => true,
          'css'     => [
            [
              'property' => '--ease',
              'selector' => '.bc-underlined-title__element',
            ],
          ],
          'placeholder' => 'cubic-bezier(0.16, 1, 0.3, 1)',
    ];

    //Gradient
    $this->controls['titleGradient'] = [
      'group' => 'gradient',
      'tab' => 'content',
      'type' => 'gradient',
      'css' => [
        [
          'property' => 'background-image',
          'selector' => '.bc-underlined-title__element',
        ],
      ],
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'underline_title', plugin_dir_url( __FILE__ ) . 'js/bc_underline_title.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $type    = ! empty( $settings['type'] ) ? $settings['type'] : 'Side to Side';

		if ( ! empty( $settings['link'] ) ) {
			$this->set_link_attributes( '_root', $settings['link'] );
		}


    $this->set_attribute( '_root', 'class', 'bc-underlined-title' );

    $output = "<a {$this->render_attributes( '_root' )}>";

    if ( $inner_title ) {
      $this->set_attribute( 'inner_title', 'class', 'bc-underlined-title__element' );
      if ($type === 'Side to Side') {
        $this->set_attribute( 'inner_title', 'class', 'bc-underlined-title__side-to-side' );
      }
      if ($type === 'One Sided') {
        $this->set_attribute( 'inner_title', 'class', 'bc-underlined-title__one-sided' );
      }
      if ($type === 'Two Sided') {
        $this->set_attribute( 'inner_title', 'class', 'bc-underlined-title__two-sided' );
      }
      if ($type === 'Full Sided') {
        $this->set_attribute( 'inner_title', 'class', 'bc-underlined-title__full-sided' );
      }

      $output .=
      "<{$this->tag} {$this->render_attributes( 'inner_title' )}>$inner_title</{$this->tag}>";
    }
    $output .= '</a>';

    echo $output;
  }
}

