<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class Bc_Unfold_Reveal extends \Bricks\Element {
  public $category     = 'Brickscore - Titles';
  public $name         = 'unfold-reveal';
  public $icon         = 'ti-text';
  public $tag      = 'h3';
  public $css_selector = '';
  public $scripts      = ['unfoldreveal'];

  public function get_label() {
    return esc_html__( 'Unfold Reveal', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['gradient'] = [
      'title' => esc_html__( 'Gradient', 'bricks' ),
      'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['inner_title'] = [
      'tab'            => 'content',
      'type'           => 'text',
	    'hasDynamicData' => 'text',
      'default'        => esc_html__( 'Unfold Reveal', 'bricks' ),
      'placeholder'    => esc_html__( 'Title goes here ..', 'bricks' ),
    ];
    $this->controls['titleTypography'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Typography', 'bricks' ),
        'type'    => 'typography',
              'css'     => [
          [
            'property' => 'typography',
            'selector' => '',
          ],
        ],
    ];
    $this->controls['tag'] = [
        'tab'         => 'content',
        'label'       => esc_html__( 'HTML tag', 'bricks' ),
        'type'        => 'select',
        'options'     => [
            'h1' => 'h1',
            'h2' => 'h2',
            'h3' => 'h3',
            'h4' => 'h4',
            'h5' => 'h5',
            'h6' => 'h6',
            'p' => 'p',
            'span' => 'span',
        ],
        'clearable'   => false,
        'inline'      => true,
        'placeholder' => 'h3',
        'default'     => 'h3',
    ];

    $this->controls['animationSeparator'] = [
        'label'      => esc_html__( 'Animation', 'bricks' ),
        'type'       => 'separator',
    ];

    $this->controls['type'] = [
      'hasDynamicData' => false,
      'tab'         => 'content',
      'label'       => esc_html__( 'Type', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'lines' => 'lines',
          'words' => 'words',
      ],
      'clearable'   => false,
      'inline'      => true,
      'placeholder' => 'lines',
    ];
    $this->controls['from'] = [
      'hasDynamicData' => false,
      'tab'         => 'content',
      'label'       => esc_html__( 'From', 'bricks' ),
      'type'        => 'select',
      'options'     => [
          'left' => 'left',
          'right' => 'right',
      ],
      'clearable'   => false,
      'inline'      => true,
      'placeholder' => 'left',
    ];
    $this->controls['unfold_intensity'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Unfold Intensity', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => '300',
    ];
    $this->controls['duration'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Duration', 'bricks' ),
        'type' => 'number',
        'unit' => 's',
        'inline' => true,
        'placeholder' => '0.3s',
    ];
    $this->controls['delay'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'Delay', 'bricks' ),
        'type' => 'number',
        'unit' => 's',
        'inline' => true,
        'placeholder' => '0s',
    ];
    $this->controls['ease'] = [
        'hasDynamicData' => false,
        'tab' => 'content',
        'label' => esc_html__( 'GSAP easing', 'bricks' ),
        'type' => 'text',
        'inline' => true,
        'placeholder' => 'expo',
    ];
    $this->controls['stagger'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Stagger', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => '0.06',
    ];

    $this->controls['scrolltrigger'] = [
      'label'      => esc_html__( 'SrollTrigger', 'bricks' ),
      'type'       => 'separator',
      'description' => sprintf(esc_html__( 'Scrolltrigger %s', 'bricks' ), '<a href="https://greensock.com/docs/v3/Plugins/ScrollTrigger" target="_blank">documentation</a>'),
    ];
  
    $this->controls['trigger'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Trigger', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 'this',
    ];
  
    $this->controls['start'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Start', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 'top bottom',
    ];

    $this->controls['end'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'End', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 'false',
    ];
  
    $this->controls['scrub'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Scrub', 'bricks' ),
      'type' => 'checkbox',
      'inline' => true,
      'placeholder' => false,
      'default' => false,
    ];

    $this->controls['scroller'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Scroller', 'bricks' ),
      'type' => 'text',
      'inline' => true,
      'placeholder' => 'body',
    ];

    $this->controls['toggleActions'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'toggleActions', 'bricks' ),
      'type' => 'text',
      'placeholder' => 'play none none none',
    ];

    //Gradient
    $this->controls['titleGradient'] = [
      'group' => 'gradient',
      'tab' => 'content',
      'type' => 'gradient',
      'css' => [
        [
          'property' => 'background-image',
          'selector' => '.char',
        ],
      ],
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'bc-unfold-reveal', plugin_dir_url( __FILE__ ) . 'js/bc_unfold_reveal.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;
    $inner_title    = ! empty( $settings['inner_title'] ) ? $settings['inner_title'] : 'Brickscore';
    $intensity    = ! empty( $settings['unfold_intensity'] ) ? $settings['unfold_intensity'] : 300;
    $delay    = ! empty( $settings['delay'] ) ? $settings['delay'] : 0;
    $duration    = ! empty( $settings['duration'] ) ? $settings['duration'] : 0.3;
    $stagger    = ! empty( $settings['stagger'] ) ? $settings['stagger'] : 0.06;
    $ease    = ! empty( $settings['ease'] ) ? $settings['ease'] : 'expo';
    $from    = ! empty( $settings['from'] ) ? $settings['from'] : 'left';
    $type    = ! empty( $settings['type'] ) ? $settings['type'] : 'lines';
    $toggleActions = ! empty( $settings['toggleActions'] ) ? $settings['toggleActions'] : 'play none none none';

    $trigger    = ! empty( $settings['trigger'] ) ? $settings['trigger'] : 'this';
    $start    = ! empty( $settings['start'] ) ? $settings['start'] : 'top bottom';
    $end    = ! empty( $settings['end'] ) ? $settings['end'] : 'false';
    $scrub    = ! empty( $settings['scrub'] ) ? $settings['scrub'] : false;
    $scroller    = ! empty( $settings['scroller'] ) ? $settings['scroller'] : 'body';

    $this->set_attribute( '_root', 'class', 'bc-unfold-reveal' );
    $this->set_attribute( '_root', 'data-hide', '' );
    $this->set_attribute( '_root', 'data-type', $type );
    $this->set_attribute( '_root', 'data-intensity', $intensity );
    $this->set_attribute( '_root', 'data-delay', $delay );
    $this->set_attribute( '_root', 'data-duration', $duration );
    $this->set_attribute( '_root', 'data-stagger', $stagger );
    $this->set_attribute( '_root', 'data-ease', $ease );
    $this->set_attribute( '_root', 'data-from', $from );
    $this->set_attribute( '_root', 'data-scroller', $scroller );
    $this->set_attribute( '_root', 'data-toggleActions', $toggleActions);

    $this->set_attribute( '_root', 'data-trigger', $trigger );
    $this->set_attribute( '_root', 'data-start', $start );
    $this->set_attribute( '_root', 'data-end', $end );
    $this->set_attribute( '_root', 'data-scrub', $scrub );

    $output = "<{$this->tag} {$this->render_attributes( '_root' )}>$inner_title</{$this->tag}>";

	  echo $output;
  }
}