<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class B_Zoom_Lens extends \Bricks\Element {
  public $category     = 'Brickscore - Core';
  public $name         = 'zoomlens';
  public $icon         = 'fa-solid fa-magnifying-glass';
  public $scripts      = ['zoom_lens'];

  public function get_label() {
    return esc_html__( 'Zoom Lens', 'bricks' );
  }

  public function set_control_groups() {
    $this->control_groups['animation'] = [
        'title' => esc_html__( 'Animation', 'bricks' ),
        'tab'   => 'content',
    ];
  }

  public function set_controls() {
    $this->controls['image'] = [
      'hasDynamicData' => true,
      'tab' => 'content',
      'label' => esc_html__( 'Image', 'bricks' ),
      'type' => 'image',
  ];
    $this->controls['alt'] = [
      'hasDynamicData' => false,
      'tab' => 'content',
      'label' => esc_html__( 'Custom alt text', 'bricks' ),
      'type' => 'text',
      'inline' => true,
  ];
    $this->controls['dimensions'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Lens dimensions', 'bricks' ),
        'type'  => 'number',
        'units' => true,
        'placeholder' => '50px',
        'inline' => true,
        'css'     => [
          [
            'property' => '--width',
            'selector' => '.bc-zoom-lens__glass',
          ],
        ],
    ];
    $this->controls['border'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Lens border', 'bricks' ),
        'type'    => 'border',
        'inline' => true,
        'css'     => [
          [
            'property' => 'border',
            'selector' => '.bc-zoom-lens__glass',
          ],
        ],
    ];

    $this->controls['scalezoom'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Lens zoom', 'bricks' ),
        'type'    => 'text',
        'placeholder' => '2',
        'group'    => 'animation',
        'inline' => true,
        'small' => true,
        'css'     => [
          [
            'property' => '--scale',
            'selector' => '.bc-zoom-lens__show',
          ],
        ],
    ];
    $this->controls['scaleinduration'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Scale in duration', 'bricks' ),
        'type' => 'number',
        'unit' => 'ms',
        'placeholder' => '200',
        'group'    => 'animation',
        'inline' => true,
        'small' => true,
        'css'     => [
          [
            'property' => '--scale-duration',
            'selector' => '.bc-zoom-lens__glass',
          ],
        ],
    ];
    $this->controls['scaleoutduration'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Scale out duration', 'bricks' ),
        'type'    => 'number',
        'small' => true,
        'placeholder' => '200',
        'group'    => 'animation',
        'inline' => true,
    ];
    $this->controls['opacityduration'] = [
        'tab'     => 'content',
        'label'   => esc_html__( 'Cursor attachment', 'bricks' ),
        'type'    => 'number',
        'small' => true,
        'placeholder' => '100',
        'group'    => 'animation',
        'inline' => true,
    ];
  }


  public function enqueue_scripts() {
    wp_enqueue_script( 'bczoomlens', plugin_dir_url( __FILE__ ) . 'js/bc_zoom_lens.min.js', array('bricks-scripts'), get_option('brickscore_element_version'), false);
  }

  public function render() {
    $settings = $this->settings;

    if (isset($settings['image'])) {
        $last_image = $settings['image']['url'];

        $image_dimensions = getimagesize($last_image);
        $width = $image_dimensions[0];
        $height = $image_dimensions[1];
    }else{
        $last_image = 'https://images.pexels.com/photos/17050728/pexels-photo-17050728/free-photo-of-madera-carretera-paisaje-agua.jpeg?auto=compress&cs=tinysrgb&w=1260&h=750&dpr=1';
        $width = null;
        $height = null;
    }

    $alt = !empty($settings['alt']) ? "alt='{$settings['alt']}'" : '';
    $scaleout = ! empty( $settings['scaleoutduration'] ) ? $settings['scaleoutduration'] : 200;
    $opacity = ! empty( $settings['opacityduration'] ) ? $settings['opacityduration'] : 100;

    $this->set_attribute( '_root', 'class', 'bc-zoom-lens' );
    $this->set_attribute( '_root', 'style', "--bgimage: url('$last_image');");
    $this->set_attribute( '_root', 'data-scaleout', "$scaleout" );
    $this->set_attribute( '_root', 'data-opacity', "$opacity" );

    $output = "<div {$this->render_attributes( '_root' )} width='$width' height='$height' >
    <img src='$last_image' class='bc-zoom-lens__image' $alt> ";
    $output .= '</div>';

	echo $output;
  }
}



